@@ -44,13 +44,13 @@ int up_process_event_object(struct glusterfs_fs *gl_fs,
 			    struct glfs_object *object,
 			    enum glfs_upcall_reason reason)
 {
-	int	     rc                             = -1;
-	glfs_t          *fs                         = NULL;
-	char            vol_uuid[GLAPI_UUID_LENGTH] = {'\0'};
-	unsigned char   globjhdl[GLAPI_HANDLE_LENGTH];
-	struct gsh_buffdesc         key;
+	int rc = -1;
+	glfs_t *fs = NULL;
+	char vol_uuid[GLAPI_UUID_LENGTH] = { '\0' };
+	unsigned char globjhdl[GLAPI_HANDLE_LENGTH];
+	struct gsh_buffdesc key;
 	const struct fsal_up_vector *event_func;
-	fsal_status_t fsal_status = {0, 0};
+	fsal_status_t fsal_status = { 0, 0 };
 #ifdef USE_GLUSTER_DELEGATION
 	state_status_t rc_s;
 #endif
@@ -58,26 +58,21 @@ int up_process_event_object(struct glusterfs_fs *gl_fs,
 	fs = gl_fs->fs;
 	if (!fs) {
 		LogCrit(COMPONENT_FSAL_UP,
-			"Invalid fs object of the glusterfs_fs(%p)",
-			 gl_fs);
+			"Invalid fs object of the glusterfs_fs(%p)", gl_fs);
 		goto out;
 	}
 
-	rc = glfs_h_extract_handle(object, globjhdl+GLAPI_UUID_LENGTH,
+	rc = glfs_h_extract_handle(object, globjhdl + GLAPI_UUID_LENGTH,
 				   GFAPI_HANDLE_LENGTH);
 	if (rc < 0) {
-		LogDebug(COMPONENT_FSAL_UP,
-			 "glfs_h_extract_handle failed %p",
+		LogDebug(COMPONENT_FSAL_UP, "glfs_h_extract_handle failed %p",
 			 fs);
 		goto out;
 	}
 
-	rc = glfs_get_volumeid(fs, vol_uuid,
-			       GLAPI_UUID_LENGTH);
+	rc = glfs_get_volumeid(fs, vol_uuid, GLAPI_UUID_LENGTH);
 	if (rc < 0) {
-		LogDebug(COMPONENT_FSAL_UP,
-			 "glfs_get_volumeid failed %p",
-			 fs);
+		LogDebug(COMPONENT_FSAL_UP, "glfs_get_volumeid failed %p", fs);
 		goto out;
 	}
 
@@ -85,36 +80,32 @@ int up_process_event_object(struct glusterfs_fs *gl_fs,
 	key.addr = &globjhdl;
 	key.len = GLAPI_HANDLE_LENGTH;
 
-	LogDebug(COMPONENT_FSAL_UP, "Received event to process for %p",
-		 fs);
+	LogDebug(COMPONENT_FSAL_UP, "Received event to process for %p", fs);
 
 	event_func = gl_fs->up_ops;
 
-
 	switch (reason) {
 	case GLFS_EVENT_INODE_INVALIDATE:
-	fsal_status = event_func->invalidate_close(
-					event_func,
-					&key,
-					FSAL_UP_INVALIDATE_CACHE);
+		fsal_status = event_func->invalidate_close(
+			event_func, &key, FSAL_UP_INVALIDATE_CACHE);
 		rc = fsal_status.major;
 		if (FSAL_IS_ERROR(fsal_status) &&
-			 fsal_status.major != ERR_FSAL_NOENT) {
+		    fsal_status.major != ERR_FSAL_NOENT) {
 			LogWarn(COMPONENT_FSAL_UP,
-			"UP event:GLFS_EVENT_INODE_INVALIDATE could not be processed for fs (%p), rc(%d)",
-			gl_fs->fs, rc);
+				"UP event:GLFS_EVENT_INODE_INVALIDATE could not be processed for fs (%p), rc(%d)",
+				gl_fs->fs, rc);
 		}
-	break;
+		break;
 #ifdef USE_GLUSTER_DELEGATION
 	case GLFS_EVENT_RECALL_LEASE:
 		rc_s = event_func->delegrecall(event_func, &key);
 		if (rc_s != STATE_SUCCESS) {
 			LogWarn(COMPONENT_FSAL_UP,
-			"UP event:GLFS_EVENT_RECALL_LEASE could not be processed for fs(%p), reason(%s)",
-			gl_fs->fs, state_err_str(rc_s));
+				"UP event:GLFS_EVENT_RECALL_LEASE could not be processed for fs(%p), reason(%s)",
+				gl_fs->fs, state_err_str(rc_s));
 			rc = -1;
 		}
-	break;
+		break;
 #endif
 	default:
 		/* invalid reason */
@@ -130,26 +121,24 @@ out:
 
 void *GLUSTERFSAL_UP_Thread(void *Arg)
 {
-	struct glusterfs_fs         *gl_fs              = Arg;
+	struct glusterfs_fs *gl_fs = Arg;
 	struct fsal_up_vector *event_func;
-	char                        thr_name[16];
-	int                         rc                  = 0;
-	struct glfs_upcall          *cbk                = NULL;
-	enum glfs_upcall_reason     reason              = 0;
-	int                         retry               = 0;
-	int                         errsv               = 0;
-	struct glfs_object          *object             = NULL;
-	struct glfs_object          *p_object           = NULL;
-	struct glfs_object          *oldp_object        = NULL;
-	struct glfs_upcall_inode    *in_arg             = NULL;
+	char thr_name[16];
+	int rc = 0;
+	struct glfs_upcall *cbk = NULL;
+	enum glfs_upcall_reason reason = 0;
+	int retry = 0;
+	int errsv = 0;
+	struct glfs_object *object = NULL;
+	struct glfs_object *p_object = NULL;
+	struct glfs_object *oldp_object = NULL;
+	struct glfs_upcall_inode *in_arg = NULL;
 #ifdef USE_GLUSTER_DELEGATION
-	struct glfs_upcall_lease    *lease_arg          = NULL;
+	struct glfs_upcall_lease *lease_arg = NULL;
 #endif
 
 	rcu_register_thread();
-	(void) snprintf(thr_name, sizeof(thr_name),
-			"fsal_up_%p",
-			gl_fs->fs);
+	(void)snprintf(thr_name, sizeof(thr_name), "fsal_up_%p", gl_fs->fs);
 	SetNameFunction(thr_name);
 
 	/* Set the FSAL UP functions that will be used to process events. */
@@ -163,8 +152,7 @@ void *GLUSTERFSAL_UP_Thread(void *Arg)
 	}
 
 	LogFullDebug(COMPONENT_FSAL_UP,
-		     "Initializing FSAL Callback context for %p.",
-		     gl_fs->fs);
+		     "Initializing FSAL Callback context for %p.", gl_fs->fs);
 
 	if (!gl_fs->fs) {
 		LogCrit(COMPONENT_FSAL_UP,
@@ -178,9 +166,10 @@ void *GLUSTERFSAL_UP_Thread(void *Arg)
 	/* Start querying for events and processing. */
 	/** @todo : Do batch processing instead */
 	while (!atomic_fetch_int8_t(&gl_fs->destroy_mode)) {
-		LogFullDebug(COMPONENT_FSAL_UP,
-			     "Requesting event from FSAL Callback interface for %p.",
-			     gl_fs->fs);
+		LogFullDebug(
+			COMPONENT_FSAL_UP,
+			"Requesting event from FSAL Callback interface for %p.",
+			gl_fs->fs);
 
 		reason = 0;
 
@@ -198,15 +187,17 @@ void *GLUSTERFSAL_UP_Thread(void *Arg)
 			} else {
 				switch (errsv) {
 				case ENOMEM:
-					LogMajor(COMPONENT_FSAL_UP,
-						 "Memory allocation failed during poll_upcall for (%p).",
-						 gl_fs->fs);
+					LogMajor(
+						COMPONENT_FSAL_UP,
+						"Memory allocation failed during poll_upcall for (%p).",
+						gl_fs->fs);
 					abort();
 
 				case ENOTSUP:
-					LogEvent(COMPONENT_FSAL_UP,
-						 "Upcall feature is not supported for (%p).",
-						 gl_fs->fs);
+					LogEvent(
+						COMPONENT_FSAL_UP,
+						"Upcall feature is not supported for (%p).",
+						gl_fs->fs);
 					break;
 				default:
 					LogCrit(COMPONENT_FSAL_UP,
@@ -221,8 +212,7 @@ void *GLUSTERFSAL_UP_Thread(void *Arg)
 		retry = 0;
 
 		LogFullDebug(COMPONENT_FSAL_UP,
-			     "Received upcall event: reason(%d)",
-			     reason);
+			     "Received upcall event: reason(%d)", reason);
 
 		if (!cbk) {
 			usleep(gl_fs->up_poll_usec);
@@ -287,19 +277,19 @@ void *GLUSTERFSAL_UP_Thread(void *Arg)
 out:
 	rcu_unregister_thread();
 	return NULL;
-}				/* GLUSTERFSFSAL_UP_Thread */
+} /* GLUSTERFSFSAL_UP_Thread */
 
 void gluster_process_upcall(struct glfs_upcall *cbk, void *data)
 {
-	struct glusterfs_fs         *gl_fs              = data;
+	struct glusterfs_fs *gl_fs = data;
 	struct fsal_up_vector *event_func;
-	enum glfs_upcall_reason     reason              = 0;
-	struct glfs_object          *object             = NULL;
-	struct glfs_object          *p_object           = NULL;
-	struct glfs_object          *oldp_object        = NULL;
-	struct glfs_upcall_inode    *in_arg             = NULL;
+	enum glfs_upcall_reason reason = 0;
+	struct glfs_object *object = NULL;
+	struct glfs_object *p_object = NULL;
+	struct glfs_object *oldp_object = NULL;
+	struct glfs_upcall_inode *in_arg = NULL;
 #ifdef USE_GLUSTER_DELEGATION
-	struct glfs_upcall_lease    *lease_arg          = NULL;
+	struct glfs_upcall_lease *lease_arg = NULL;
 #endif
 
 	if (!cbk) {
