@@ -50,10 +50,10 @@ gpfs_acl_2_fsal_acl(struct fsal_attrlist *p_object_attributes,
  *  Same function as posixstat64_2_fsal_attributes. When NFS4 ACL support
  *  is enabled, this will replace posixstat64_2_fsal_attributes.
  */
-fsal_status_t
-gpfsfsal_xstat_2_fsal_attributes(gpfsfsal_xstat_t *gpfs_buf,
-				 struct fsal_attrlist *fsal_attr,
-				 gpfs_acl_t *acl_buf, bool use_acl)
+fsal_status_t gpfsfsal_xstat_2_fsal_attributes(gpfsfsal_xstat_t *gpfs_buf,
+					       struct fsal_attrlist *fsal_attr,
+					       gpfs_acl_t *acl_buf,
+					       bool use_acl)
 {
 	struct stat *p_buffstat;
 
@@ -71,8 +71,7 @@ gpfsfsal_xstat_2_fsal_attributes(gpfsfsal_xstat_t *gpfs_buf,
 	if (FSAL_TEST_MASK(fsal_attr->request_mask, ATTR_TYPE)) {
 		fsal_attr->type = posix2fsal_type(p_buffstat->st_mode);
 		fsal_attr->valid_mask |= ATTR_TYPE;
-		LogFullDebug(COMPONENT_FSAL, "type = 0x%x",
-			     fsal_attr->type);
+		LogFullDebug(COMPONENT_FSAL, "type = 0x%x", fsal_attr->type);
 	}
 	if (FSAL_TEST_MASK(fsal_attr->request_mask, ATTR_SIZE)) {
 		fsal_attr->filesize = p_buffstat->st_size;
@@ -84,9 +83,8 @@ gpfsfsal_xstat_2_fsal_attributes(gpfsfsal_xstat_t *gpfs_buf,
 		fsal_attr->fsid = gpfs_buf->fsal_fsid;
 		fsal_attr->valid_mask |= ATTR_FSID;
 		LogFullDebug(COMPONENT_FSAL,
-			     "fsid=0x%016"PRIx64".0x%016"PRIx64,
-			     fsal_attr->fsid.major,
-			     fsal_attr->fsid.minor);
+			     "fsid=0x%016" PRIx64 ".0x%016" PRIx64,
+			     fsal_attr->fsid.major, fsal_attr->fsid.minor);
 	}
 	if (FSAL_TEST_MASK(fsal_attr->request_mask, ATTR_ACL)) {
 		if (fsal_attr->acl != NULL) {
@@ -105,8 +103,8 @@ gpfsfsal_xstat_2_fsal_attributes(gpfsfsal_xstat_t *gpfs_buf,
 
 		if (use_acl && gpfs_buf->attr_valid & XATTR_ACL) {
 			/* ACL is valid, so try to convert fsal acl. */
-			fsal_status_t status = gpfs_acl_2_fsal_acl(fsal_attr,
-								   acl_buf);
+			fsal_status_t status =
+				gpfs_acl_2_fsal_acl(fsal_attr, acl_buf);
 			if (!FSAL_IS_ERROR(status)) {
 				/* Only mark ACL valid if we actually provide
 				 * one in fsal_attr.
@@ -122,7 +120,7 @@ gpfsfsal_xstat_2_fsal_attributes(gpfsfsal_xstat_t *gpfs_buf,
 		LogFullDebug(COMPONENT_FSAL, "acl = %p", fsal_attr->acl);
 	}
 	if (FSAL_TEST_MASK(fsal_attr->request_mask, ATTR_FILEID)) {
-		fsal_attr->fileid = (uint64_t) (p_buffstat->st_ino);
+		fsal_attr->fileid = (uint64_t)(p_buffstat->st_ino);
 		fsal_attr->valid_mask |= ATTR_FILEID;
 		LogFullDebug(COMPONENT_FSAL, "fileid = %" PRIu64,
 			     fsal_attr->fileid);
@@ -131,7 +129,7 @@ gpfsfsal_xstat_2_fsal_attributes(gpfsfsal_xstat_t *gpfs_buf,
 	if (FSAL_TEST_MASK(fsal_attr->request_mask, ATTR_MODE)) {
 		fsal_attr->mode = unix2fsal_mode(p_buffstat->st_mode);
 		fsal_attr->valid_mask |= ATTR_MODE;
-		LogFullDebug(COMPONENT_FSAL, "mode = %"PRIu32,
+		LogFullDebug(COMPONENT_FSAL, "mode = %" PRIu32,
 			     fsal_attr->mode);
 	}
 	if (FSAL_TEST_MASK(fsal_attr->request_mask, ATTR_NUMLINKS)) {
@@ -153,26 +151,23 @@ gpfsfsal_xstat_2_fsal_attributes(gpfsfsal_xstat_t *gpfs_buf,
 			     fsal_attr->group);
 	}
 	if (FSAL_TEST_MASK(fsal_attr->request_mask, ATTR_ATIME)) {
-		fsal_attr->atime =
-		    posix2fsal_time(p_buffstat->st_atime,
-				    p_buffstat->st_atim.tv_nsec);
+		fsal_attr->atime = posix2fsal_time(p_buffstat->st_atime,
+						   p_buffstat->st_atim.tv_nsec);
 		fsal_attr->valid_mask |= ATTR_ATIME;
 		LogFullDebug(COMPONENT_FSAL, "atime = %lu",
 			     fsal_attr->atime.tv_sec);
 	}
 
 	if (FSAL_TEST_MASK(fsal_attr->request_mask, ATTR_CTIME)) {
-		fsal_attr->ctime =
-		    posix2fsal_time(p_buffstat->st_ctime,
-				    p_buffstat->st_ctim.tv_nsec);
+		fsal_attr->ctime = posix2fsal_time(p_buffstat->st_ctime,
+						   p_buffstat->st_ctim.tv_nsec);
 		fsal_attr->valid_mask |= ATTR_CTIME;
 		LogFullDebug(COMPONENT_FSAL, "ctime = %lu",
 			     fsal_attr->ctime.tv_sec);
 	}
 	if (FSAL_TEST_MASK(fsal_attr->request_mask, ATTR_MTIME)) {
-		fsal_attr->mtime =
-		    posix2fsal_time(p_buffstat->st_mtime,
-				    p_buffstat->st_mtim.tv_nsec);
+		fsal_attr->mtime = posix2fsal_time(p_buffstat->st_mtime,
+						   p_buffstat->st_mtim.tv_nsec);
 		fsal_attr->valid_mask |= ATTR_MTIME;
 		LogFullDebug(COMPONENT_FSAL, "mtime = %lu",
 			     fsal_attr->mtime.tv_sec);
@@ -183,27 +178,26 @@ gpfsfsal_xstat_2_fsal_attributes(gpfsfsal_xstat_t *gpfs_buf,
 			if (p_buffstat->st_mtim.tv_nsec >
 			    p_buffstat->st_ctim.tv_nsec) {
 				fsal_attr->change =
-					(uint64_t) p_buffstat->st_mtim.tv_sec +
-					(uint64_t) p_buffstat->st_mtim.tv_nsec;
+					(uint64_t)p_buffstat->st_mtim.tv_sec +
+					(uint64_t)p_buffstat->st_mtim.tv_nsec;
 			} else {
 				fsal_attr->change =
-					(uint64_t) p_buffstat->st_ctim.tv_sec +
-					(uint64_t) p_buffstat->st_ctim.tv_nsec;
+					(uint64_t)p_buffstat->st_ctim.tv_sec +
+					(uint64_t)p_buffstat->st_ctim.tv_nsec;
 			}
 		} else if (p_buffstat->st_mtime > p_buffstat->st_ctime) {
 			fsal_attr->change =
-				(uint64_t) p_buffstat->st_mtim.tv_sec +
-				(uint64_t) p_buffstat->st_mtim.tv_nsec;
+				(uint64_t)p_buffstat->st_mtim.tv_sec +
+				(uint64_t)p_buffstat->st_mtim.tv_nsec;
 		} else {
 			fsal_attr->change =
-				(uint64_t) p_buffstat->st_ctim.tv_sec +
-				(uint64_t) p_buffstat->st_ctim.tv_nsec;
+				(uint64_t)p_buffstat->st_ctim.tv_sec +
+				(uint64_t)p_buffstat->st_ctim.tv_nsec;
 		}
 
 		fsal_attr->valid_mask |= ATTR_CHANGE;
-		LogFullDebug(COMPONENT_FSAL, "change = %"PRIu64,
+		LogFullDebug(COMPONENT_FSAL, "change = %" PRIu64,
 			     fsal_attr->change);
-
 	}
 
 	if (FSAL_TEST_MASK(fsal_attr->request_mask, ATTR_SPACEUSED)) {
@@ -244,7 +238,7 @@ gpfs_acl_2_fsal_acl(struct fsal_attrlist *p_object_attributes,
 
 	/* Create fsal acl data. */
 	acldata.naces = p_gpfsacl->acl_nace;
-	acldata.aces = (fsal_ace_t *) nfs4_ace_alloc(acldata.naces);
+	acldata.aces = (fsal_ace_t *)nfs4_ace_alloc(acldata.naces);
 
 	/* Fill fsal acl data from gpfs acl. */
 	for (pace = acldata.aces, pace_gpfs = p_gpfsacl->ace_v4;
@@ -259,25 +253,25 @@ gpfs_acl_2_fsal_acl(struct fsal_attrlist *p_object_attributes,
 		} else {
 			if (IS_FSAL_ACE_GROUP_ID(*pace))
 				pace->who.gid = pace_gpfs->aceWho;
-			else	/* Record user. */
+			else /* Record user. */
 				pace->who.uid = pace_gpfs->aceWho;
 		}
 
-		LogMidDebug(COMPONENT_FSAL,
-			 "fsal ace: type = 0x%x, flag = 0x%x, perm = 0x%x, special = %d, %s = 0x%x",
-			 pace->type, pace->flag, pace->perm,
-			 IS_FSAL_ACE_SPECIAL_ID(*pace),
-			 GET_FSAL_ACE_WHO_TYPE(*pace), GET_FSAL_ACE_WHO(*pace));
+		LogMidDebug(
+			COMPONENT_FSAL,
+			"fsal ace: type = 0x%x, flag = 0x%x, perm = 0x%x, special = %d, %s = 0x%x",
+			pace->type, pace->flag, pace->perm,
+			IS_FSAL_ACE_SPECIAL_ID(*pace),
+			GET_FSAL_ACE_WHO_TYPE(*pace), GET_FSAL_ACE_WHO(*pace));
 	}
 
 	/* Create a new hash table entry for fsal acl. */
 	pacl = nfs4_acl_new_entry(&acldata, &status);
 	LogMidDebug(COMPONENT_FSAL, "fsal acl = %p, fsal_acl_status = %u", pacl,
-		 status);
+		    status);
 
 	if (pacl == NULL) {
-		LogCrit(COMPONENT_FSAL,
-			"failed to create a new acl entry");
+		LogCrit(COMPONENT_FSAL, "failed to create a new acl entry");
 		return fsalstat(ERR_FSAL_FAULT, 0);
 	}
 
@@ -298,10 +292,10 @@ gpfs_acl_2_fsal_acl(struct fsal_attrlist *p_object_attributes,
  *
  *  @brief Convert FSAL ACLs to GPFS NFS4 ACLs.
  */
-fsal_status_t
-fsal_acl_2_gpfs_acl(struct fsal_obj_handle *dir_hdl, fsal_acl_t *fsal_acl,
-		    gpfsfsal_xstat_t *gpfs_buf, gpfs_acl_t *acl_buf,
-		    unsigned int acl_buflen)
+fsal_status_t fsal_acl_2_gpfs_acl(struct fsal_obj_handle *dir_hdl,
+				  fsal_acl_t *fsal_acl,
+				  gpfsfsal_xstat_t *gpfs_buf,
+				  gpfs_acl_t *acl_buf, unsigned int acl_buflen)
 {
 	int i;
 	fsal_ace_t *pace;
@@ -336,35 +330,39 @@ fsal_acl_2_gpfs_acl(struct fsal_obj_handle *dir_hdl, fsal_acl_t *fsal_acl,
 				acl_buf->ace_v4[i].aceWho = pace->who.uid;
 		}
 
-		LogMidDebug(COMPONENT_FSAL,
-			 "gpfs ace: type = 0x%x, flag = 0x%x, perm = 0x%x, special = %d, %s = 0x%x",
-			 acl_buf->ace_v4[i].aceType,
-			 acl_buf->ace_v4[i].aceFlags,
-			 acl_buf->ace_v4[i].aceMask,
-			 (acl_buf->ace_v4[i].aceIFlags &
-					FSAL_ACE_IFLAG_SPECIAL_ID) ? 1 : 0,
-			 (acl_buf->ace_v4[i].aceFlags & FSAL_ACE_FLAG_GROUP_ID)
-				? "gid" : "uid",
-			 acl_buf->ace_v4[i].aceWho);
+		LogMidDebug(
+			COMPONENT_FSAL,
+			"gpfs ace: type = 0x%x, flag = 0x%x, perm = 0x%x, special = %d, %s = 0x%x",
+			acl_buf->ace_v4[i].aceType, acl_buf->ace_v4[i].aceFlags,
+			acl_buf->ace_v4[i].aceMask,
+			(acl_buf->ace_v4[i].aceIFlags &
+			 FSAL_ACE_IFLAG_SPECIAL_ID) ?
+				1 :
+				0,
+			(acl_buf->ace_v4[i].aceFlags & FSAL_ACE_FLAG_GROUP_ID) ?
+				"gid" :
+				"uid",
+			acl_buf->ace_v4[i].aceWho);
 
 		/* It is invalid to set inherit flags on non dir objects */
 		if (dir_hdl->type != DIRECTORY &&
-		    (acl_buf->ace_v4[i].aceFlags &
-		    FSAL_ACE_FLAG_INHERIT) != 0) {
-			LogMidDebug(COMPONENT_FSAL,
-			   "attempt to set inherit flag to non dir object");
+		    (acl_buf->ace_v4[i].aceFlags & FSAL_ACE_FLAG_INHERIT) !=
+			    0) {
+			LogMidDebug(
+				COMPONENT_FSAL,
+				"attempt to set inherit flag to non dir object");
 			return fsalstat(ERR_FSAL_INVAL, 0);
 		}
 
 		/* It is invalid to set inherit only with
 		 * out an actual inherit flag */
 		if ((acl_buf->ace_v4[i].aceFlags & FSAL_ACE_FLAG_INHERIT) ==
-			FSAL_ACE_FLAG_INHERIT_ONLY) {
-			LogMidDebug(COMPONENT_FSAL,
-			   "attempt to set inherit only without an inherit flag");
+		    FSAL_ACE_FLAG_INHERIT_ONLY) {
+			LogMidDebug(
+				COMPONENT_FSAL,
+				"attempt to set inherit only without an inherit flag");
 			return fsalstat(ERR_FSAL_INVAL, 0);
 		}
-
 	}
 
 	return fsalstat(ERR_FSAL_NO_ERROR, 0);
@@ -446,9 +444,10 @@ fsal_status_t fsal_mode_2_gpfs_mode(mode_t fsal_mode, fsal_accessflags_t v4mask,
 		gpfs_mode = fsal_mode >> 24;
 	}
 
-	LogMidDebug(COMPONENT_FSAL,
-		 "fsal_mode 0x%x, v4mask 0x%x, is_dir %d converted to gpfs_mode 0x%x",
-		 fsal_mode, v4mask, is_dir, gpfs_mode);
+	LogMidDebug(
+		COMPONENT_FSAL,
+		"fsal_mode 0x%x, v4mask 0x%x, is_dir %d converted to gpfs_mode 0x%x",
+		fsal_mode, v4mask, is_dir, gpfs_mode);
 
 	*p_gpfsmode = gpfs_mode;
 
