@@ -45,19 +45,18 @@
  *        - ERR_FSAL_NO_ERROR     (no error)
  *        - Another error code if an error occurred.
  */
-fsal_status_t
-GPFSFSAL_unlink(struct fsal_obj_handle *dir_hdl, const char *object_name)
+fsal_status_t GPFSFSAL_unlink(struct fsal_obj_handle *dir_hdl,
+			      const char *object_name)
 {
-
 	fsal_status_t status;
 	gpfsfsal_xstat_t buffxstat;
 	struct gpfs_fsal_obj_handle *gpfs_hdl;
-	struct gpfs_fsal_export *exp = container_of(op_ctx->fsal_export,
-					struct gpfs_fsal_export, export);
+	struct gpfs_fsal_export *exp = container_of(
+		op_ctx->fsal_export, struct gpfs_fsal_export, export);
 	int export_fd = exp->export_fd;
 
 	gpfs_hdl =
-	    container_of(dir_hdl, struct gpfs_fsal_obj_handle, obj_handle);
+		container_of(dir_hdl, struct gpfs_fsal_obj_handle, obj_handle);
 
 	/* get file metadata */
 	status = fsal_internal_stat_name(export_fd, gpfs_hdl->handle,
@@ -65,11 +64,11 @@ GPFSFSAL_unlink(struct fsal_obj_handle *dir_hdl, const char *object_name)
 	if (FSAL_IS_ERROR(status))
 		return status;
 
-  /******************************
+	/******************************
    * DELETE FROM THE FILESYSTEM *
    ******************************/
-	status = fsal_internal_unlink(export_fd, gpfs_hdl->handle,
-				      object_name, &buffxstat.buffstat);
+	status = fsal_internal_unlink(export_fd, gpfs_hdl->handle, object_name,
+				      &buffxstat.buffstat);
 
 	if (FSAL_IS_ERROR(status))
 		return status;
