@@ -65,60 +65,52 @@ static void valgrind_kganesha(struct kxArgs *args)
 	int op = (int)args->arg1;
 
 	switch (op) {
-	case OPENHANDLE_STATFS_BY_FH:
-	{
+	case OPENHANDLE_STATFS_BY_FH: {
 		struct statfs_arg *arg = (void *)args->arg2;
 
 		VALGRIND_MAKE_MEM_DEFINED(arg->buf, sizeof(*arg->buf));
 		break;
 	}
-	case OPENHANDLE_READ_BY_FD:
-	{
+	case OPENHANDLE_READ_BY_FD: {
 		struct read_arg *arg = (void *)args->arg2;
 
 		VALGRIND_MAKE_MEM_DEFINED(arg->bufP, arg->length);
 		break;
 	}
-	case OPENHANDLE_NAME_TO_HANDLE:
-	{
+	case OPENHANDLE_NAME_TO_HANDLE: {
 		struct name_handle_arg *arg = (void *)args->arg2;
 
 		VALGRIND_MAKE_MEM_DEFINED(arg->handle,
 					  sizeof(struct gpfs_file_handle));
 		break;
 	}
-	case OPENHANDLE_GET_HANDLE:
-	{
+	case OPENHANDLE_GET_HANDLE: {
 		struct get_handle_arg *arg = (void *)args->arg2;
 
 		VALGRIND_MAKE_MEM_DEFINED(arg->out_fh,
 					  sizeof(struct gpfs_file_handle));
 		break;
 	}
-	case OPENHANDLE_STAT_BY_NAME:
-	{
+	case OPENHANDLE_STAT_BY_NAME: {
 		struct stat_name_arg *arg = (void *)args->arg2;
 
 		VALGRIND_MAKE_MEM_DEFINED(arg->buf, sizeof(*arg->buf));
 		break;
 	}
-	case OPENHANDLE_CREATE_BY_NAME:
-	{
+	case OPENHANDLE_CREATE_BY_NAME: {
 		struct create_name_arg *arg = (void *)args->arg2;
 
 		VALGRIND_MAKE_MEM_DEFINED(arg->new_fh,
 					  sizeof(struct gpfs_file_handle));
 		break;
 	}
-	case OPENHANDLE_READLINK_BY_FH:
-	{
+	case OPENHANDLE_READLINK_BY_FH: {
 		struct readlink_fh_arg *arg = (void *)args->arg2;
 
 		VALGRIND_MAKE_MEM_DEFINED(arg->buffer, arg->size);
 		break;
 	}
-	case OPENHANDLE_GET_XSTAT:
-	{
+	case OPENHANDLE_GET_XSTAT: {
 		struct xstat_arg *arg = (void *)args->arg2;
 
 		VALGRIND_MAKE_MEM_DEFINED(arg->buf, sizeof(*arg->buf));
@@ -134,13 +126,12 @@ static void valgrind_kganesha(struct kxArgs *args)
 			 */
 			gacl = arg->acl;
 			outlen = gacl->acl_len -
-				offsetof(struct gpfs_acl, acl_nace);
+				 offsetof(struct gpfs_acl, acl_nace);
 			VALGRIND_MAKE_MEM_DEFINED(&gacl->acl_nace, outlen);
 		}
 		break;
 	}
-	case OPENHANDLE_WRITE_BY_FD:
-	{
+	case OPENHANDLE_WRITE_BY_FD: {
 		struct write_arg *arg = (void *)args->arg2;
 
 		VALGRIND_MAKE_MEM_DEFINED(arg->stability_got,
@@ -202,7 +193,6 @@ int gpfs_ganesha(int op, void *oarg)
 
 #ifdef NFS_CONTAINERIZATION
 		if (gpfs_fd < 0) {
-
 			/* In containerization, /dev/ss0 may not be present.
 			 * So look for gpfs mount.
 			 */
@@ -211,13 +201,13 @@ int gpfs_ganesha(int op, void *oarg)
 				goto exit;
 
 			while (!readDone) {
-				char  lineBuf[2048];
-				char  *savePtr;
-				char  *type;
-				char  *ptr;
+				char lineBuf[2048];
+				char *savePtr;
+				char *type;
+				char *ptr;
 				/* Read the next line from the file */
-				if (fgets(lineBuf, sizeof(lineBuf), file)
-						== NULL) {
+				if (fgets(lineBuf, sizeof(lineBuf), file) ==
+				    NULL) {
 					readDone = true;
 					break;
 					/* Something is broken with the
@@ -246,21 +236,23 @@ int gpfs_ganesha(int op, void *oarg)
 				gpfs_fd = open(dirPath, O_RDONLY);
 
 				if (gpfs_fd >= 0)
-					LogEvent(COMPONENT_FSAL,
-				"%s GPFS file system found, fd %d,dirPath=%s\n",
-					__func__, gpfs_fd, dirPath);
+					LogEvent(
+						COMPONENT_FSAL,
+						"%s GPFS file system found, fd %d,dirPath=%s\n",
+						__func__, gpfs_fd, dirPath);
 			}
 exit:
 			if (!gotPath)
-				LogEvent(COMPONENT_FSAL,
-				"%s no mounted GPFS file system found, fd %d\n",
-				__func__, gpfs_fd);
+				LogEvent(
+					COMPONENT_FSAL,
+					"%s no mounted GPFS file system found, fd %d\n",
+					__func__, gpfs_fd);
 		}
 #endif
 		if (gpfs_fd == -1)
 			LogFatal(COMPONENT_FSAL,
-				"open of %s failed with errno %d",
-				GPFS_DEVNAMEX, errno);
+				 "open of %s failed with errno %d",
+				 GPFS_DEVNAMEX, errno);
 		(void)fcntl(gpfs_fd, F_SETFD, FD_CLOEXEC);
 	}
 
@@ -280,7 +272,7 @@ exit:
 		idx = gpfs_op2index(op);
 		(void)atomic_inc_uint64_t(&gpfs_stats.op_stats[idx].num_ops);
 		(void)atomic_add_uint64_t(&gpfs_stats.op_stats[idx].resp_time,
-				  resp_time);
+					  resp_time);
 		if (gpfs_stats.op_stats[idx].resp_time_max < resp_time)
 			gpfs_stats.op_stats[idx].resp_time_max = resp_time;
 		if (gpfs_stats.op_stats[idx].resp_time_min == 0 ||
