@@ -31,8 +31,8 @@
 #include "config.h"
 
 #include "fsal.h"
-#include <misc/portable.h>	/* used for 'bswap*' */
-#include <libgen.h>		/* used for 'dirname' */
+#include <misc/portable.h> /* used for 'bswap*' */
+#include <libgen.h> /* used for 'dirname' */
 #include <pthread.h>
 #include <string.h>
 #include <sys/types.h>
@@ -48,9 +48,11 @@
 #include "export_mgr.h"
 #include <misc/portable.h>
 
-#ifdef USE_LTTNG
-#include "gsh_lttng/fsal_mem.h"
+#include "gsh_lttng/gsh_lttng.h"
+#if defined(USE_LTTNG) && !defined(LTTNG_PARSING)
+#include "gsh_lttng/generated_traces/fsalmem.h"
 #endif
+
 /* helpers to/from other MEM objects
  */
 
@@ -66,10 +68,9 @@ static void mem_release_export(struct fsal_export *exp_hdl)
 	if (myself->root_handle != NULL) {
 		mem_clean_export(myself->root_handle);
 
-		fsal_obj_handle_fini(&myself->root_handle->obj_handle);
+		fsal_obj_handle_fini(&myself->root_handle->obj_handle, true);
 
-		LogDebug(COMPONENT_FSAL,
-			 "Releasing hdl=%p, name=%s",
+		LogDebug(COMPONENT_FSAL, "Releasing hdl=%p, name=%s",
 			 myself->root_handle, myself->root_handle->m_name);
 
 		PTHREAD_RWLOCK_wrlock(&myself->mfe_exp_lock);
@@ -114,8 +115,7 @@ static fsal_status_t mem_get_dynamic_info(struct fsal_export *exp_hdl,
 
 static fsal_status_t mem_wire_to_host(struct fsal_export *exp_hdl,
 				      fsal_digesttype_t in_type,
-				      struct gsh_buffdesc *fh_desc,
-				      int flags)
+				      struct gsh_buffdesc *fh_desc, int flags)
 {
 	size_t fh_min;
 	uint64_t *hashkey;
@@ -183,13 +183,12 @@ static struct state_t *mem_alloc_state(struct fsal_export *exp_hdl,
 
 	init_fsal_fd(fsal_fd, FSAL_FD_STATE, op_ctx->fsal_export);
 
-#ifdef USE_LTTNG
-	tracepoint(fsalmem, mem_alloc_state, __func__, __LINE__, state);
-#endif
+	GSH_AUTO_TRACEPOINT(fsalmem, mem_alloc_state, TRACE_DEBUG,
+			    "Allocated state: {}", state);
+
 	return state;
 }
 
-
 /**
  * @brief Function to get the fasl_obj_handle that has fsal_fd as its global fd.
  *
@@ -199,9 +198,8 @@ static struct state_t *mem_alloc_state(struct fsal_export *exp_hdl,
  *
  * @return the fsal_obj_handle.
  */
-void get_fsal_obj_hdl(struct fsal_export *exp_hdl,
-				  struct fsal_fd *fd,
-				  struct fsal_obj_handle **handle)
+void get_fsal_obj_hdl(struct fsal_export *exp_hdl, struct fsal_fd *fd,
+		      struct fsal_obj_handle **handle)
 {
 	struct mem_fsal_obj_handle *myself = NULL;
 
@@ -242,21 +240,20 @@ const char *str_async_type(uint32_t async_type)
 }
 
 static struct config_item_list async_types_conf[] = {
-	CONFIG_LIST_TOK("inline",		MEM_INLINE),
-	CONFIG_LIST_TOK("fixed",		MEM_FIXED),
-	CONFIG_LIST_TOK("random",		MEM_RANDOM),
-	CONFIG_LIST_TOK("random_or_inline",	MEM_RANDOM_OR_INLINE),
+	CONFIG_LIST_TOK("inline", MEM_INLINE),
+	CONFIG_LIST_TOK("fixed", MEM_FIXED),
+	CONFIG_LIST_TOK("random", MEM_RANDOM),
+	CONFIG_LIST_TOK("random_or_inline", MEM_RANDOM_OR_INLINE),
 	CONFIG_LIST_EOL
 };
 
 static struct config_item mem_export_params[] = {
 	CONF_ITEM_NOOP("name"),
-	CONF_ITEM_UI32("Async_Delay", 0, 1000, 0,
-		       mem_fsal_export, async_delay),
+	CONF_ITEM_UI32("Async_Delay", 0, 1000, 0, mem_fsal_export, async_delay),
 	CONF_ITEM_TOKEN("Async_Type", MEM_INLINE, async_types_conf,
 			mem_fsal_export, async_type),
-	CONF_ITEM_UI32("Async_Stall_Delay", 0, 1000, 0,
-		       mem_fsal_export, async_stall_delay),
+	CONF_ITEM_UI32("Async_Stall_Delay", 0, 1000, 0, mem_fsal_export,
+		       async_stall_delay),
 	CONFIG_EOL
 };
 
@@ -276,14 +273,13 @@ static struct config_block mem_export_param_block = {
  * returns the export with one reference taken.
  */
 
-fsal_status_t mem_create_export(struct fsal_module *fsal_hdl,
-				void *parse_node,
+fsal_status_t mem_create_export(struct fsal_module *fsal_hdl, void *parse_node,
 				struct config_error_type *err_type,
 				const struct fsal_up_vector *up_ops)
 {
 	struct mem_fsal_export *myself;
 	int retval = 0;
-	fsal_status_t fsal_status = {0, 0};
+	fsal_status_t fsal_status = { 0, 0 };
 
 	myself = gsh_calloc(1, sizeof(struct mem_fsal_export));
 
@@ -292,25 +288,21 @@ fsal_status_t mem_create_export(struct fsal_module *fsal_hdl,
 	fsal_export_init(&myself->export);
 	mem_export_ops_init(&myself->export.exp_ops);
 
-	retval = load_config_from_node(parse_node,
-				       &mem_export_param_block,
-				       myself,
-				       true,
-				       err_type);
+	retval = load_config_from_node(parse_node, &mem_export_param_block,
+				       myself, true, err_type);
 
 	if (retval != 0) {
 		fsal_status = posix2fsal_status(EINVAL);
-		goto err_free;	/* seriously bad */
+		goto err_free; /* seriously bad */
 	}
 
 	retval = fsal_attach_export(fsal_hdl, &myself->export.exports);
 
 	if (retval != 0) {
 		/* seriously bad */
-		LogMajor(COMPONENT_FSAL,
-			 "Could not attach export");
+		LogMajor(COMPONENT_FSAL, "Could not attach export");
 		fsal_status = posix2fsal_status(retval);
-		goto err_free;	/* seriously bad */
+		goto err_free; /* seriously bad */
 	}
 
 	myself->export.fsal = fsal_hdl;
@@ -323,15 +315,14 @@ fsal_status_t mem_create_export(struct fsal_module *fsal_hdl,
 	/* Insert into exports list */
 	glist_add_tail(&MEM.mem_exports, &myself->export_entry);
 
-	LogDebug(COMPONENT_FSAL,
-		 "Created exp %p - %s",
-		 myself, myself->export_path);
+	LogDebug(COMPONENT_FSAL, "Created exp %p - %s", myself,
+		 myself->export_path);
 
 	return fsalstat(ERR_FSAL_NO_ERROR, 0);
 
 err_free:
 	free_export_ops(&myself->export);
-	gsh_free(myself);	/* elvis has left the building */
+	gsh_free(myself); /* elvis has left the building */
 	return fsal_status;
 }
 
@@ -361,8 +352,7 @@ err_free:
  * @return FSAL status.
  */
 
-fsal_status_t mem_update_export(struct fsal_module *fsal_hdl,
-				void *parse_node,
+fsal_status_t mem_update_export(struct fsal_module *fsal_hdl, void *parse_node,
 				struct config_error_type *err_type,
 				struct fsal_export *original,
 				struct fsal_module *updated_super)
@@ -374,19 +364,16 @@ fsal_status_t mem_update_export(struct fsal_module *fsal_hdl,
 	fsal_status_t status;
 
 	/* Check for changes in stacking by calling default update_export. */
-	status = update_export(fsal_hdl, parse_node, err_type,
-			       original, updated_super);
+	status = update_export(fsal_hdl, parse_node, err_type, original,
+			       updated_super);
 
 	if (FSAL_IS_ERROR(status))
 		return status;
 
 	memset(&myself, 0, sizeof(myself));
 
-	retval = load_config_from_node(parse_node,
-				       &mem_export_param_block,
-				       &myself,
-				       true,
-				       err_type);
+	retval = load_config_from_node(parse_node, &mem_export_param_block,
+				       &myself, true, err_type);
 
 	if (retval != 0) {
 		return posix2fsal_status(EINVAL);
@@ -399,10 +386,10 @@ fsal_status_t mem_update_export(struct fsal_module *fsal_hdl,
 	atomic_store_uint32_t(&orig->async_type, myself.async_type);
 
 	LogEvent(COMPONENT_FSAL,
-		 "Updated FSAL_MEM aync parameters type=%s, delay=%"PRIu32
-		 ", stall_delay=%"PRIu32,
-		 str_async_type(myself.async_type),
-		 myself.async_delay, myself.async_stall_delay);
+		 "Updated FSAL_MEM aync parameters type=%s, delay=%" PRIu32
+		 ", stall_delay=%" PRIu32,
+		 str_async_type(myself.async_type), myself.async_delay,
+		 myself.async_stall_delay);
 
 	return fsalstat(ERR_FSAL_NO_ERROR, 0);
 }
