@@ -30,7 +30,7 @@
 #include "config.h"
 
 #include "fsal.h"
-#include <libgen.h>		/* used for 'dirname' */
+#include <libgen.h> /* used for 'dirname' */
 #include <pthread.h>
 #include <string.h>
 #include <limits.h>
@@ -49,47 +49,44 @@
 static const char memname[] = "MEM";
 
 /* my module private storage */
-struct mem_fsal_module MEM = {
-	.fsal = {
-		.fs_info = {
-			.maxfilesize = INT64_MAX,
-			.maxlink = 0,
-			.maxnamelen = MAXNAMLEN,
-			.maxpathlen = MAXPATHLEN,
-			.no_trunc = true,
-			.chown_restricted = true,
-			.case_insensitive = false,
-			.case_preserving = true,
-			.link_support = true,
-			.symlink_support = true,
-			.lock_support = false,
-			.lock_support_async_block = false,
-			.named_attr = false,
-			.unique_handles = true,
-			.acl_support = 0,
-			.cansettime = true,
-			.homogenous = true,
-			.supported_attrs = MEM_SUPPORTED_ATTRIBUTES,
-			.maxread = FSAL_MAXIOSIZE,
-			.maxwrite = FSAL_MAXIOSIZE,
-			.umask = 0,
-			.auth_exportpath_xdev = false,
-			.link_supports_permission_checks = false,
-			.readdir_plus = true,
-			.expire_time_parent = -1,
-		}
-	}
-};
+struct mem_fsal_module
+	MEM = { .fsal = { .fs_info = {
+				  .maxfilesize = INT64_MAX,
+				  .maxlink = 0,
+				  .maxnamelen = MAXNAMLEN,
+				  .maxpathlen = MAXPATHLEN,
+				  .no_trunc = true,
+				  .chown_restricted = true,
+				  .case_insensitive = false,
+				  .case_preserving = true,
+				  .link_support = true,
+				  .symlink_support = true,
+				  .lock_support = false,
+				  .lock_support_async_block = false,
+				  .named_attr = false,
+				  .unique_handles = true,
+				  .acl_support = 0,
+				  .cansettime = true,
+				  .homogenous = true,
+				  .supported_attrs = MEM_SUPPORTED_ATTRIBUTES,
+				  .maxread = FSAL_MAXIOSIZE,
+				  .maxwrite = FSAL_MAXIOSIZE,
+				  .umask = 0,
+				  .auth_exportpath_xdev = false,
+				  .link_supports_permission_checks = false,
+				  .readdir_plus = true,
+				  .expire_time_parent = -1,
+			  } } };
 
 static struct config_item mem_items[] = {
-	CONF_ITEM_UI32("Inode_Size", 0, 0x200000, 0,
-		       mem_fsal_module, inode_size),
-	CONF_ITEM_UI32("Up_Test_Interval", 0, UINT32_MAX, 0,
-		       mem_fsal_module, up_interval),
-	CONF_ITEM_UI32("Async_Threads", 0, 100, 0,
-		       mem_fsal_module, async_threads),
-	CONF_ITEM_BOOL("Whence_is_name", false,
-		       mem_fsal_module, whence_is_name),
+	CONF_ITEM_UI32("Inode_Size", 0, 0x200000, 0, mem_fsal_module,
+		       inode_size),
+	CONF_ITEM_UI32("Up_Test_Interval", 0, UINT32_MAX, 0, mem_fsal_module,
+		       up_interval),
+	CONF_ITEM_UI32("Async_Threads", 0, 100, 0, mem_fsal_module,
+		       async_threads),
+	CONF_ITEM_BOOL("Whence_is_name", false, mem_fsal_module,
+		       whence_is_name),
 	CONFIG_EOL
 };
 
@@ -97,7 +94,7 @@ static struct config_block mem_block = {
 	.dbus_interface_name = "org.ganesha.nfsd.config.fsal.mem",
 	.blk_desc.name = "MEM",
 	.blk_desc.type = CONFIG_BLOCK,
-	.blk_desc.flags = CONFIG_UNIQUE,  /* too risky to have more */
+	.blk_desc.flags = CONFIG_UNIQUE, /* too risky to have more */
 	.blk_desc.u.blk.init = noop_conf_init,
 	.blk_desc.u.blk.params = mem_items,
 	.blk_desc.u.blk.commit = noop_conf_commit
@@ -108,8 +105,7 @@ struct fridgethr *mem_async_fridge;
 /**
  * Initialize subsystem
  */
-static fsal_status_t
-mem_async_pkginit(void)
+static fsal_status_t mem_async_pkginit(void)
 {
 	/* Return code from system calls */
 	int code = 0;
@@ -133,14 +129,15 @@ mem_async_pkginit(void)
 	/* spawn MEM_ASYNC background thread */
 	code = fridgethr_init(&mem_async_fridge, "MEM_ASYNC_fridge", &frp);
 	if (code != 0) {
-		LogMajor(COMPONENT_FSAL,
-			 "Unable to initialize MEM_ASYNC fridge, error code %d.",
-			 code);
+		LogMajor(
+			COMPONENT_FSAL,
+			"Unable to initialize MEM_ASYNC fridge, error code %d.",
+			code);
 	}
 
 	LogEvent(COMPONENT_FSAL,
-		 "Initialized FSAL_MEM async thread pool with %"
-		 PRIu32" threads.",
+		 "Initialized FSAL_MEM async thread pool with %" PRIu32
+		 " threads.",
 		 MEM.async_threads);
 
 	return posix2fsal_status(code);
@@ -151,16 +148,14 @@ mem_async_pkginit(void)
  *
  * @return FSAL status
  */
-static fsal_status_t
-mem_async_pkgshutdown(void)
+static fsal_status_t mem_async_pkgshutdown(void)
 {
 	if (!mem_async_fridge) {
 		/* Async wasn't configured */
 		return fsalstat(ERR_FSAL_NO_ERROR, 0);
 	}
 
-	int rc = fridgethr_sync_command(mem_async_fridge,
-					fridgethr_comm_stop,
+	int rc = fridgethr_sync_command(mem_async_fridge, fridgethr_comm_stop,
 					120);
 
 	if (rc == ETIMEDOUT) {
@@ -182,27 +177,24 @@ mem_async_pkgshutdown(void)
 
 /* Initialize mem fs info */
 static fsal_status_t mem_init_config(struct fsal_module *fsal_hdl,
-				 config_file_t config_struct,
-				 struct config_error_type *err_type)
+				     config_file_t config_struct,
+				     struct config_error_type *err_type)
 {
 	struct mem_fsal_module *mem_me =
-	    container_of(fsal_hdl, struct mem_fsal_module, fsal);
-	fsal_status_t status = {0, 0};
+		container_of(fsal_hdl, struct mem_fsal_module, fsal);
+	fsal_status_t status = { 0, 0 };
 
 	LogDebug(COMPONENT_FSAL, "MEM module setup.");
 	LogFullDebug(COMPONENT_FSAL,
-				 "Supported attributes default = 0x%" PRIx64,
-				 mem_me->fsal.fs_info.supported_attrs);
+		     "Supported attributes default = 0x%" PRIx64,
+		     mem_me->fsal.fs_info.supported_attrs);
 
 	/* if we have fsal specific params, do them here
 	 * fsal_hdl->name is used to find the block containing the
 	 * params.
 	 */
-	(void) load_config_from_parse(config_struct,
-				      &mem_block,
-				      mem_me,
-				      true,
-				      err_type);
+	(void)load_config_from_parse(config_struct, &mem_block, mem_me, true,
+				     err_type);
 	if (!config_error_is_harmless(err_type))
 		return fsalstat(ERR_FSAL_INVAL, 0);
 
@@ -230,7 +222,7 @@ static fsal_status_t mem_init_config(struct fsal_module *fsal_hdl,
 	display_fsinfo(&mem_me->fsal);
 	LogFullDebug(COMPONENT_FSAL,
 		     "Supported attributes constant = 0x%" PRIx64,
-		     (uint64_t) MEM_SUPPORTED_ATTRIBUTES);
+		     (uint64_t)MEM_SUPPORTED_ATTRIBUTES);
 	LogDebug(COMPONENT_FSAL,
 		 "FSAL INIT: Supported attributes mask = 0x%" PRIx64,
 		 mem_me->fsal.fs_info.supported_attrs);
@@ -261,8 +253,7 @@ MODULE_INIT void init(void)
 	retval = register_fsal(myself, memname, FSAL_MAJOR_VERSION,
 			       FSAL_MINOR_VERSION, FSAL_ID_NO_PNFS);
 	if (retval != 0) {
-		LogCrit(COMPONENT_FSAL,
-			"MEM module failed to register.");
+		LogCrit(COMPONENT_FSAL, "MEM module failed to register.");
 	}
 	myself->m_ops.create_export = mem_create_export;
 	myself->m_ops.update_export = mem_update_export;
@@ -278,8 +269,7 @@ MODULE_FINI void finish(void)
 {
 	int retval;
 
-	LogDebug(COMPONENT_FSAL,
-		 "MEM module finishing.");
+	LogDebug(COMPONENT_FSAL, "MEM module finishing.");
 
 	/* Shutdown UP calls */
 	mem_up_pkgshutdown();
