@@ -23,7 +23,7 @@
 #include "saunafs_fsal_types.h"
 
 #ifdef LINUX
-#include <linux/falloc.h>  /* for fallocate  */
+#include <linux/falloc.h> /* for fallocate  */
 #include <sys/sysmacros.h> /* for makedev(3) */
 #endif
 
@@ -363,7 +363,7 @@ fsal_status_t reopen_func(struct fsal_obj_handle *objectHandle,
 	struct sau_fileinfo *saunafsFD = NULL;
 	struct SaunaFSExport *export = NULL;
 	int posixFlags = 0;
-	fsal_status_t status = {ERR_FSAL_NO_ERROR, 0};
+	fsal_status_t status = { ERR_FSAL_NO_ERROR, 0 };
 
 	handle = container_of(objectHandle, struct SaunaFSHandle, handle);
 	fileDescriptor = container_of(fsalFd, struct SaunaFSFd, fsalFd);
@@ -453,7 +453,7 @@ openByHandle(struct fsal_obj_handle *objectHandle, struct state_t *state,
 	fsalFd = &saunafsFd->fsalFd;
 
 	/* Indicate we want to do fd work (can't fail since not reclaiming) */
-	(void)fsal_start_fd_work(fsalFd, false);
+	fsal_start_fd_work_no_reclaim(fsalFd);
 
 	oldOpenflags = saunafsFd->fsalFd.openflags;
 
@@ -715,16 +715,23 @@ static fsal_status_t openByName(struct fsal_obj_handle *objectHandle,
  *                                           created object
  * @param [in,out] callerPermissionCheck     The caller must do a
  *                                           permission check
+ * @param[in,out] parentPreAttributes        Optional attributes for parent dir
+ *                                           before the operation.
+ *                                           Should be atomic.
+ * @param[in,out] parentPostAttributes       Optional attributes for parent dir
+ *                                           after the operation.
+ *                                           Should be atomic.
  *
  * @returns: FSAL status
  */
 static fsal_status_t
 open2(struct fsal_obj_handle *objectHandle, struct state_t *state,
-		fsal_openflags_t openflags, enum fsal_create_mode createmode,
-		const char *name, struct fsal_attrlist *attributesToSet,
-		fsal_verifier_t verifier,
-		struct fsal_obj_handle **createdObject,
-		struct fsal_attrlist *attributes, bool *callerPermissionCheck)
+      fsal_openflags_t openflags, enum fsal_create_mode createmode,
+      const char *name, struct fsal_attrlist *attributesToSet,
+      fsal_verifier_t verifier, struct fsal_obj_handle **createdObject,
+      struct fsal_attrlist *attributes, bool *callerPermissionCheck,
+      struct fsal_attrlist *parentPreAttributes,
+      struct fsal_attrlist *parentPostAttributes)
 {
 	struct SaunaFSExport *export = NULL;
 	struct SaunaFSHandle *handle = NULL;
@@ -987,6 +994,10 @@ static void read2(struct fsal_obj_handle *objectHandle, bool bypass,
  * @param [out]    createdObject       Newly created object
  * @param [in,out] attributes          Optional attributes for newly
  *                                     created object
+ * @param[in,out] parentPreAttributes  Optional attributes for parent dir
+ *                                     before the operation. Should be atomic.
+ * @param[in,out] parentPostAttributes Optional attributes for parent dir
+ *                                     after the operation. Should be atomic.
  *
  * \see fsal_api.h for more information
  *
@@ -996,7 +1007,9 @@ static fsal_status_t mkdir_(struct fsal_obj_handle *directoryHandle,
 			    const char *name,
 			    struct fsal_attrlist *attributesToSet,
 			    struct fsal_obj_handle **createdObject,
-			    struct fsal_attrlist *attributes)
+			    struct fsal_attrlist *attributes,
+			    struct fsal_attrlist *parentPreAttributes,
+			    struct fsal_attrlist *parentPostAttributes)
 {
 	struct SaunaFSExport *export = NULL;
 	struct SaunaFSHandle *directory = NULL;
@@ -1075,7 +1088,9 @@ static fsal_status_t mkdir_(struct fsal_obj_handle *directoryHandle,
  */
 static fsal_status_t link_(struct fsal_obj_handle *objectHandle,
 			   struct fsal_obj_handle *destinationDirHandle,
-			   const char *name)
+			   const char *name,
+			   struct fsal_attrlist *destdirPreAttributes,
+			   struct fsal_attrlist *destdirPostAttributes)
 {
 	struct SaunaFSExport *export = NULL;
 	struct SaunaFSHandle *handle = NULL;
@@ -1115,6 +1130,14 @@ static fsal_status_t link_(struct fsal_obj_handle *objectHandle,
  * @param [in] oldName             Original name
  * @param [in] newParentHandle     Destination directory
  * @param [in] newName             New name
+ * @param[in,out] oldParentPreAttributes  Optional attributes for olddParent
+ *                                      before the operation. Should be atomic.
+ * @param[in,out] oldParentPostAttributes Optional attributes for oldParent
+ *                                      after the operation. Should be atomic.
+ * @param[in,out] newParentPreAttributes  Optional attributes for newParent
+ *                                      before the operation. Should be atomic.
+ * @param[in,out] newParentPostAttributes Optional attributes for newParent
+ *                                      after the operation. Should be atomic.
  *
  * @returns: FSAL status
  */
@@ -1122,7 +1145,11 @@ static fsal_status_t rename_(struct fsal_obj_handle *objectHandle,
 			     struct fsal_obj_handle *oldParentHandle,
 			     const char *oldName,
 			     struct fsal_obj_handle *newParentHandle,
-			     const char *newName)
+			     const char *newName,
+			     struct fsal_attrlist *oldParentPreAttributes,
+			     struct fsal_attrlist *oldParentPostAttributes,
+			     struct fsal_attrlist *newParentPreAttributes,
+			     struct fsal_attrlist *newParentPostAttributes)
 {
 	(void)objectHandle;
 	struct SaunaFSExport *export = NULL;
@@ -1160,12 +1187,18 @@ static fsal_status_t rename_(struct fsal_obj_handle *objectHandle,
  *                                 name
  * @param [in] objectHandle        The object being removed
  * @param [in] name                The name to remove
+ * @param[in,out] parentPreAttributes  Optional attributes for parent dir
+ *                                     before the operation. Should be atomic.
+ * @param[in,out] parentPostAttributes Optional attributes for parent dir
+ *                                     after the operation. Should be atomic.
  *
  * @returns: FSAL status
  */
 static fsal_status_t unlink_(struct fsal_obj_handle *directoryHandle,
 			     struct fsal_obj_handle *objectHandle,
-			     const char *name)
+			     const char *name,
+			     struct fsal_attrlist *parentPreAttributes,
+			     struct fsal_attrlist *parentPostAttributes)
 {
 	struct SaunaFSExport *export = NULL;
 	struct SaunaFSHandle *directory = NULL;
@@ -1621,6 +1654,10 @@ static fsal_status_t close2(struct fsal_obj_handle *objectHandle,
  * @param [out] createdObject       Newly created object
  * @param [in,out] attributes       Optional attributes for newly created
  *                                  object
+ * @param[in,out] parentPreAttributes  Optional attributes for parent dir
+ *                                     before the operation. Should be atomic.
+ * @param[in,out] parentPostAttributes Optional attributes for parent dir
+ *                                     after the operation. Should be atomic.
  *
  * \see fsal_api.h for more information
  *
@@ -1630,7 +1667,9 @@ static fsal_status_t symlink_(struct fsal_obj_handle *directoryHandle,
 			      const char *name, const char *symbolicLinkPath,
 			      struct fsal_attrlist *attributesToSet,
 			      struct fsal_obj_handle **createdObject,
-			      struct fsal_attrlist *attributes)
+			      struct fsal_attrlist *attributes,
+			      struct fsal_attrlist *parentPreAttributes,
+			      struct fsal_attrlist *parentPostAttributes)
 {
 	struct SaunaFSExport *export = NULL;
 	struct SaunaFSHandle *directory = NULL;
@@ -1903,6 +1942,10 @@ static fsal_status_t reopen2(struct fsal_obj_handle *objectHandle,
  * @param [in] createdObject       Newly created object
  * @param [in] attributes          Optional attributes for newly created
  *                                 object
+ * @param[in,out] parentPreAttributes  Optional attributes for parent dir
+ *                                     before the operation. Should be atomic.
+ * @param[in,out] parentPostAttributes Optional attributes for parent dir
+ *                                     after the operation. Should be atomic.
  *
  * \see fsal_api.h for more information
  *
@@ -1912,7 +1955,9 @@ static fsal_status_t mknode(struct fsal_obj_handle *directoryHandle,
 			    const char *name, object_file_type_t nodeType,
 			    struct fsal_attrlist *attributesToSet,
 			    struct fsal_obj_handle **createdObject,
-			    struct fsal_attrlist *attributes)
+			    struct fsal_attrlist *attributes,
+			    struct fsal_attrlist *parentPreAttributes,
+			    struct fsal_attrlist *parentPostAttributes)
 {
 	struct SaunaFSExport *export = NULL;
 	struct SaunaFSHandle *directory = NULL;
@@ -2602,7 +2647,7 @@ struct SaunaFSHandle *allocateHandle(const struct stat *attribute,
 	result->key.inode = attribute->st_ino;
 
 	fsal_obj_handle_init(&result->handle, &export->export,
-			     posix2fsal_type(attribute->st_mode));
+			     posix2fsal_type(attribute->st_mode), true);
 
 	result->handle.obj_ops = &SaunaFS.handleOperations;
 	result->handle.fsid = posix2fsal_fsid(attribute->st_dev);
@@ -2624,6 +2669,6 @@ struct SaunaFSHandle *allocateHandle(const struct stat *attribute,
  */
 void deleteHandle(struct SaunaFSHandle *object)
 {
-	fsal_obj_handle_fini(&object->handle);
+	fsal_obj_handle_fini(&object->handle, true);
 	gsh_free(object);
 }
