@@ -51,7 +51,7 @@
 #define HANDLE_TYPE_MASK 0xC0
 #define HANDLE_DUMMY 0x20
 #define HANDLE_FSID_MASK (~(HANDLE_TYPE_MASK | HANDLE_DUMMY))
- /*
+/*
  * 0, 8, or 16 bytes	fsid type
  * 1,2 or 4 bytes	handle type
  * 12 to 40 bytes	opaque kernel handle
@@ -72,47 +72,42 @@ int display_vfs_handle(struct display_buffer *dspbuf,
 	uint8_t handle_cursor = 1;
 	int b_left;
 
-	b_left = display_printf(dspbuf, "Handle len %hhu 0x%02hhx: ",
-				fh->handle_len, fh->handle_data[0]);
+	b_left = display_printf(dspbuf,
+				"Handle len %hhu 0x%02hhx: ", fh->handle_len,
+				fh->handle_data[0]);
 
 	if (b_left <= 0)
 		return b_left;
 
-	switch ((enum fsid_type) fh->handle_data[0] & HANDLE_FSID_MASK) {
+	switch ((enum fsid_type)fh->handle_data[0] & HANDLE_FSID_MASK) {
 	case FSID_NO_TYPE:
 		b_left = display_cat(dspbuf, "no fsid");
 		break;
 
 	case FSID_ONE_UINT64:
 	case FSID_MAJOR_64:
-		memcpy(u64,
-		       fh->handle_data + handle_cursor,
-		       sizeof(u64[0]));
+		memcpy(u64, fh->handle_data + handle_cursor, sizeof(u64[0]));
 		handle_cursor += sizeof(u64[0]);
 		b_left = display_printf(dspbuf,
-					"fsid=0x%016"PRIx64
+					"fsid=0x%016" PRIx64
 					".0x0000000000000000",
 					u64[0]);
 		break;
 
 	case FSID_TWO_UINT64:
-		memcpy(u64,
-		       fh->handle_data + handle_cursor,
-		       sizeof(u64));
+		memcpy(u64, fh->handle_data + handle_cursor, sizeof(u64));
 		handle_cursor += sizeof(u64);
 		b_left = display_printf(dspbuf,
-					"fsid=0x%016"PRIx64".0x%016"PRIx64,
+					"fsid=0x%016" PRIx64 ".0x%016" PRIx64,
 					u64[0], u64[1]);
 		break;
 
 	case FSID_TWO_UINT32:
 	case FSID_DEVICE:
-		memcpy(u32,
-		       fh->handle_data + handle_cursor,
-		       sizeof(u32));
+		memcpy(u32, fh->handle_data + handle_cursor, sizeof(u32));
 		handle_cursor += sizeof(u32);
 		b_left = display_printf(dspbuf,
-					"fsid=0x%016"PRIx64".0x%016"PRIx64,
+					"fsid=0x%016" PRIx32 ".0x%016" PRIx32,
 					u32[0], u32[1]);
 		break;
 	}
@@ -134,18 +129,14 @@ int display_vfs_handle(struct display_buffer *dspbuf,
 		handle_cursor++;
 		break;
 	case HANDLE_TYPE_16:
-		memcpy(&i16,
-		       fh->handle_data + handle_cursor,
-		       sizeof(i16));
+		memcpy(&i16, fh->handle_data + handle_cursor, sizeof(i16));
 		handle_cursor += sizeof(i16);
-		b_left = display_printf(dspbuf, ", type 0x%04h"PRIx16, i16);
+		b_left = display_printf(dspbuf, ", type 0x%04h" PRIx16, i16);
 		break;
 	case HANDLE_TYPE_32:
-		memcpy(&i32,
-		       fh->handle_data + handle_cursor,
-		       sizeof(i32));
+		memcpy(&i32, fh->handle_data + handle_cursor, sizeof(i32));
 		handle_cursor += sizeof(i32);
-		b_left = display_printf(dspbuf, ", type 0x%04"PRIx32, i32);
+		b_left = display_printf(dspbuf, ", type 0x%04" PRIx32, i32);
 		break;
 	}
 
@@ -157,28 +148,25 @@ int display_vfs_handle(struct display_buffer *dspbuf,
 	if (b_left <= 0)
 		return b_left;
 
-	return display_opaque_value(dspbuf,
-				    fh->handle_data + handle_cursor,
+	return display_opaque_value(dspbuf, fh->handle_data + handle_cursor,
 				    fh->handle_len - handle_cursor);
 }
 
-#define LogVFSHandle(fh)						\
-	do {								\
-		if (isMidDebug(COMPONENT_FSAL)) {			\
-			char buf[256] = "\0";				\
-			struct display_buffer dspbuf =			\
-					{sizeof(buf), buf, buf};	\
-									\
-			display_vfs_handle(&dspbuf, fh);		\
-									\
-			LogMidDebug(COMPONENT_FSAL, "%s", buf);		\
-		}							\
+#define LogVFSHandle(fh)                                                   \
+	do {                                                               \
+		if (isMidDebug(COMPONENT_FSAL)) {                          \
+			char buf[256] = "\0";                              \
+			struct display_buffer dspbuf = { sizeof(buf), buf, \
+							 buf };            \
+                                                                           \
+			display_vfs_handle(&dspbuf, fh);                   \
+                                                                           \
+			LogMidDebug(COMPONENT_FSAL, "%s", buf);            \
+		}                                                          \
 	} while (0)
 
-int vfs_map_name_to_handle_at(int fd,
-			      struct fsal_filesystem *fs,
-			      const char *path,
-			      vfs_file_handle_t *fh,
+int vfs_map_name_to_handle_at(int fd, struct fsal_filesystem *fs,
+			      const char *path, vfs_file_handle_t *fh,
 			      int flags)
 {
 	struct file_handle *kernel_fh;
@@ -195,9 +183,8 @@ int vfs_map_name_to_handle_at(int fd,
 	if (rc < 0) {
 		int err = errno;
 
-		LogDebug(COMPONENT_FSAL,
-			 "Error %s (%d) bytes = %d",
-			 strerror(err), err, (int) kernel_fh->handle_bytes);
+		LogDebug(COMPONENT_FSAL, "Error %s (%d) bytes = %d",
+			 strerror(err), err, (int)kernel_fh->handle_bytes);
 		errno = err;
 		return rc;
 	}
@@ -207,10 +194,8 @@ int vfs_map_name_to_handle_at(int fd,
 	fh->handle_len = 1;
 
 	/* Pack fsid into wire handle */
-	rc = encode_fsid(fh->handle_data + 1,
-			 sizeof_fsid(fs->fsid_type),
-			 &fs->fsid,
-			 fs->fsid_type);
+	rc = encode_fsid(fh->handle_data + 1, sizeof_fsid(fs->fsid_type),
+			 &fs->fsid, fs->fsid_type);
 
 	if (rc < 0) {
 		errno = EINVAL;
@@ -222,8 +207,7 @@ int vfs_map_name_to_handle_at(int fd,
 	/* Pack handle type into wire handle */
 	if (kernel_fh->handle_type <= UINT8_MAX) {
 		/* Copy one byte in and advance cursor */
-		fh->handle_data[fh->handle_len] =
-					kernel_fh->handle_type;
+		fh->handle_data[fh->handle_len] = kernel_fh->handle_type;
 		fh->handle_len++;
 		fh->handle_data[0] |= HANDLE_TYPE_8;
 	} else if (kernel_fh->handle_type <= INT16_MAX &&
@@ -231,17 +215,14 @@ int vfs_map_name_to_handle_at(int fd,
 		/* Type fits in 16 bits */
 		int16_t handle_type_16 = kernel_fh->handle_type;
 
-		memcpy(fh->handle_data + fh->handle_len,
-		       &handle_type_16,
+		memcpy(fh->handle_data + fh->handle_len, &handle_type_16,
 		       sizeof(handle_type_16));
 		fh->handle_len += sizeof(handle_type_16);
 		fh->handle_data[0] |= HANDLE_TYPE_16;
-	} else  {
+	} else {
 		/* Type needs whole 32 bits */
 		i32 = kernel_fh->handle_type;
-		memcpy(fh->handle_data + fh->handle_len,
-		       &i32,
-		       sizeof(i32));
+		memcpy(fh->handle_data + fh->handle_len, &i32, sizeof(i32));
 		fh->handle_len += sizeof(i32);
 		fh->handle_data[0] |= HANDLE_TYPE_32;
 	}
@@ -252,8 +233,7 @@ int vfs_map_name_to_handle_at(int fd,
 		errno = EOVERFLOW;
 		return -1;
 	} else {
-		memcpy(fh->handle_data + fh->handle_len,
-		       kernel_fh->f_handle,
+		memcpy(fh->handle_data + fh->handle_len, kernel_fh->f_handle,
 		       kernel_fh->handle_bytes);
 		fh->handle_len += kernel_fh->handle_bytes;
 	}
@@ -263,9 +243,8 @@ int vfs_map_name_to_handle_at(int fd,
 	return 0;
 }
 
-int vfs_open_by_handle(struct fsal_filesystem *fs,
-		       vfs_file_handle_t *fh, int openflags,
-		       fsal_errors_t *fsal_error)
+int vfs_open_by_handle(struct fsal_filesystem *fs, vfs_file_handle_t *fh,
+		       int openflags, fsal_errors_t *fsal_error)
 {
 	struct file_handle *kernel_fh;
 	uint8_t handle_cursor = sizeof_fsid(fs->fsid_type) + 1;
@@ -273,9 +252,8 @@ int vfs_open_by_handle(struct fsal_filesystem *fs,
 	int32_t i32;
 	int fd;
 
-	LogFullDebug(COMPONENT_FSAL,
-		     "vfs_fs = %s root_fd = %d",
-		     fs->path, root_fd(fs));
+	LogFullDebug(COMPONENT_FSAL, "vfs_fs = %s root_fd = %d", fs->path,
+		     root_fd(fs));
 
 	LogVFSHandle(fh);
 
@@ -283,8 +261,7 @@ int vfs_open_by_handle(struct fsal_filesystem *fs,
 
 	switch (fh->handle_data[0] & HANDLE_TYPE_MASK) {
 	case 0:
-		LogDebug(COMPONENT_FSAL,
-			 "Invalid handle type = 0");
+		LogDebug(COMPONENT_FSAL, "Invalid handle type = 0");
 		errno = EINVAL;
 		fd = -1;
 		goto out;
@@ -293,24 +270,19 @@ int vfs_open_by_handle(struct fsal_filesystem *fs,
 		handle_cursor++;
 		break;
 	case HANDLE_TYPE_16:
-		memcpy(&i16,
-		       fh->handle_data + handle_cursor,
-		       sizeof(i16));
+		memcpy(&i16, fh->handle_data + handle_cursor, sizeof(i16));
 		handle_cursor += sizeof(i16);
 		kernel_fh->handle_type = i16;
 		break;
 	case HANDLE_TYPE_32:
-		memcpy(&i32,
-		       fh->handle_data + handle_cursor,
-		       sizeof(i32));
+		memcpy(&i32, fh->handle_data + handle_cursor, sizeof(i32));
 		handle_cursor += sizeof(i32);
 		kernel_fh->handle_type = i32;
 		break;
 	}
 
 	kernel_fh->handle_bytes = fh->handle_len - handle_cursor;
-	memcpy(kernel_fh->f_handle,
-	       fh->handle_data + handle_cursor,
+	memcpy(kernel_fh->f_handle, fh->handle_data + handle_cursor,
 	       kernel_fh->handle_bytes);
 
 	fd = open_by_handle_at(root_fd(fs), kernel_fh, openflags);
@@ -330,39 +302,32 @@ out:
 	return fd;
 }
 
-int vfs_fd_to_handle(int fd, struct fsal_filesystem *fs,
-		     vfs_file_handle_t *fh)
+int vfs_fd_to_handle(int fd, struct fsal_filesystem *fs, vfs_file_handle_t *fh)
 {
 	return vfs_map_name_to_handle_at(fd, fs, "", fh, AT_EMPTY_PATH);
 }
 
-int vfs_name_to_handle(int atfd,
-		       struct fsal_filesystem *fs,
-		       const char *name,
+int vfs_name_to_handle(int atfd, struct fsal_filesystem *fs, const char *name,
 		       vfs_file_handle_t *fh)
 {
 	return vfs_map_name_to_handle_at(atfd, fs, name, fh, 0);
 }
 
-int vfs_extract_fsid(vfs_file_handle_t *fh,
-		     enum fsid_type *fsid_type,
+int vfs_extract_fsid(vfs_file_handle_t *fh, enum fsid_type *fsid_type,
 		     struct fsal_fsid__ *fsid)
 {
 	LogVFSHandle(fh);
 
-	*fsid_type = (enum fsid_type) fh->handle_data[0] & HANDLE_FSID_MASK;
+	*fsid_type = (enum fsid_type)fh->handle_data[0] & HANDLE_FSID_MASK;
 
-	if (decode_fsid(fh->handle_data + 1,
-			fh->handle_len - 1,
-			fsid,
+	if (decode_fsid(fh->handle_data + 1, fh->handle_len - 1, fsid,
 			*fsid_type) < 0)
 		return ESTALE;
 	else
 		return 0;
 }
 
-int vfs_encode_dummy_handle(vfs_file_handle_t *fh,
-			    struct fsal_filesystem *fs)
+int vfs_encode_dummy_handle(vfs_file_handle_t *fh, struct fsal_filesystem *fs)
 {
 	int rc;
 
@@ -371,10 +336,8 @@ int vfs_encode_dummy_handle(vfs_file_handle_t *fh,
 	fh->handle_len = 1;
 
 	/* Pack fsid into wire handle */
-	rc = encode_fsid(fh->handle_data + 1,
-			 sizeof_fsid(fs->fsid_type),
-			 &fs->fsid,
-			 fs->fsid_type);
+	rc = encode_fsid(fh->handle_data + 1, sizeof_fsid(fs->fsid_type),
+			 &fs->fsid, fs->fsid_type);
 
 	if (rc < 0) {
 		errno = EINVAL;
@@ -401,21 +364,19 @@ bool vfs_valid_handle(struct gsh_buffdesc *desc)
 	bool ok;
 
 	if (desc->addr == NULL) {
-		LogDebug(COMPONENT_FSAL,
-			 "desc->addr == NULL");
+		LogDebug(COMPONENT_FSAL, "desc->addr == NULL");
 		return false;
 	}
 
 	if (desc->len > VFS_HANDLE_LEN) {
-		LogDebug(COMPONENT_FSAL,
-			 "desc->len %d > VFS_HANDLE_LEN",
-			 (int) desc->len);
+		LogDebug(COMPONENT_FSAL, "desc->len %d > VFS_HANDLE_LEN",
+			 (int)desc->len);
 		return false;
 	}
 
-	handle0 = *((uint8_t *) (desc->addr));
+	handle0 = *((uint8_t *)(desc->addr));
 
-	switch ((enum fsid_type) handle0 & HANDLE_FSID_MASK) {
+	switch ((enum fsid_type)handle0 & HANDLE_FSID_MASK) {
 	case FSID_NO_TYPE:
 	case FSID_ONE_UINT64:
 	case FSID_MAJOR_64:
@@ -423,15 +384,13 @@ bool vfs_valid_handle(struct gsh_buffdesc *desc)
 	case FSID_TWO_UINT32:
 	case FSID_DEVICE:
 		fsid_type_ok = true;
-		len += sizeof_fsid((enum fsid_type) handle0 &
-						    HANDLE_FSID_MASK);
+		len += sizeof_fsid((enum fsid_type)handle0 & HANDLE_FSID_MASK);
 		break;
 	}
 
 	if (!fsid_type_ok) {
-		LogDebug(COMPONENT_FSAL,
-			 "FSID Type %02hhx invalid",
-			 (uint8_t) (handle0 & HANDLE_FSID_MASK));
+		LogDebug(COMPONENT_FSAL, "FSID Type %02hhx invalid",
+			 (uint8_t)(handle0 & HANDLE_FSID_MASK));
 		return false;
 	}
 
@@ -439,8 +398,8 @@ bool vfs_valid_handle(struct gsh_buffdesc *desc)
 		ok = len == desc->len;
 		if (!ok) {
 			LogDebug(COMPONENT_FSAL,
-				 "Len %d != desc->len %d for DUMMY handle",
-				 len, (int) desc->len);
+				 "Len %d != desc->len %d for DUMMY handle", len,
+				 (int)desc->len);
 		}
 
 		return ok;
@@ -460,30 +419,28 @@ bool vfs_valid_handle(struct gsh_buffdesc *desc)
 		len += sizeof(int32_t);
 		break;
 	default:
-		LogDebug(COMPONENT_FSAL,
-			 "Handle Type %02hhx invalid",
-			 (uint8_t) (handle0 & HANDLE_TYPE_MASK));
+		LogDebug(COMPONENT_FSAL, "Handle Type %02hhx invalid",
+			 (uint8_t)(handle0 & HANDLE_TYPE_MASK));
 		return false;
 	}
 
 	ok = (len + VFS_MIN_HANDLE_SIZE) <= desc->len;
 	if (!ok) {
 		LogDebug(COMPONENT_FSAL,
-			 "Len %d + VFS_MIN_HANDLE_SIZE %d > desc->len %d",
-			 len, len + VFS_MIN_HANDLE_SIZE, (int) desc->len);
+			 "Len %d + VFS_MIN_HANDLE_SIZE %d > desc->len %d", len,
+			 len + VFS_MIN_HANDLE_SIZE, (int)desc->len);
 		return false;
 	}
 	ok = (len + VFS_MAX_HANDLE) >= desc->len;
 	if (!ok) {
 		LogDebug(COMPONENT_FSAL,
-			 "Len %d + VFS_MAX_HANDLE %d < desc->len %d",
-			 len, len + VFS_MAX_HANDLE, (int) desc->len);
+			 "Len %d + VFS_MAX_HANDLE %d < desc->len %d", len,
+			 len + VFS_MAX_HANDLE, (int)desc->len);
 	}
 	return true;
 }
 
-int vfs_re_index(struct fsal_filesystem *fs,
-		 struct vfs_fsal_export *exp)
+int vfs_re_index(struct fsal_filesystem *fs, struct vfs_fsal_export *exp)
 {
 	return 0;
 }
