@@ -36,14 +36,13 @@
 /* Export parameters */
 extern struct config_block *vfs_sub_export_param;
 
-
 /** Routines for sub-FSALS
  */
 
 void vfs_sub_fini(struct vfs_fsal_export *myself);
 
 void vfs_sub_init_export_ops(struct vfs_fsal_export *myself,
-			      const char *export_path);
+			     const char *export_path);
 
 int vfs_sub_init_export(struct vfs_fsal_export *myself);
 
@@ -60,6 +59,5 @@ int vfs_sub_init_export(struct vfs_fsal_export *myself);
 struct vfs_fsal_obj_handle *vfs_sub_alloc_handle(void);
 
 int vfs_sub_init_handle(struct vfs_fsal_export *myself,
-		struct vfs_fsal_obj_handle *hdl,
-		const char *path);
+			struct vfs_fsal_obj_handle *hdl, const char *path);
 #endif /* SUBFSAL_H */
