@@ -68,7 +68,7 @@ void vfs_handle_ops_init(struct fsal_obj_ops *ops);
 
 static inline int root_fd(struct fsal_filesystem *fs)
 {
-	int fd = (long) fs->private_data;
+	int fd = (long)fs->private_data;
 
 	return fd;
 }
@@ -81,19 +81,16 @@ static inline int vfs_get_root_fd(struct fsal_export *exp_hdl)
 /* Internal VFS method linkage to export object
  */
 
-int vfs_claim_filesystem(struct fsal_filesystem *fs,
-			 struct fsal_export *exp,
+int vfs_claim_filesystem(struct fsal_filesystem *fs, struct fsal_export *exp,
 			 void **private_data);
 
 void vfs_unclaim_filesystem(struct fsal_filesystem *fs);
 
-fsal_status_t vfs_create_export(struct fsal_module *fsal_hdl,
-				void *parse_node,
+fsal_status_t vfs_create_export(struct fsal_module *fsal_hdl, void *parse_node,
 				struct config_error_type *err_type,
 				const struct fsal_up_vector *up_ops);
 
-fsal_status_t vfs_update_export(struct fsal_module *fsal_hdl,
-				void *parse_node,
+fsal_status_t vfs_update_export(struct fsal_module *fsal_hdl, void *parse_node,
 				struct config_error_type *err_type,
 				struct fsal_export *original,
 				struct fsal_module *updated_super);
@@ -101,8 +98,7 @@ fsal_status_t vfs_update_export(struct fsal_module *fsal_hdl,
 /* method proto linkage to handle.c for export
  */
 
-fsal_status_t vfs_lookup_path(struct fsal_export *exp_hdl,
-			      const char *path,
+fsal_status_t vfs_lookup_path(struct fsal_export *exp_hdl, const char *path,
 			      struct fsal_obj_handle **handle,
 			      struct fsal_attrlist *attrs_out);
 
@@ -112,7 +108,7 @@ fsal_status_t vfs_create_handle(struct fsal_export *exp_hdl,
 				struct fsal_attrlist *attrs_out);
 
 struct vfs_subfsal_obj_ops {
-/**
+	/**
  * @brief Gte sub-fsal attributes from an object
  *
  * @param[in] vfs_hdl    The VFS object to modify
@@ -120,10 +116,10 @@ struct vfs_subfsal_obj_ops {
  *
  * @return FSAL status.
  */
-	fsal_status_t (*getattrs)(struct vfs_fsal_obj_handle *vfs_hdl,
-				  int fd, attrmask_t request_mask,
+	fsal_status_t (*getattrs)(struct vfs_fsal_obj_handle *vfs_hdl, int fd,
+				  attrmask_t request_mask,
 				  struct fsal_attrlist *attrs);
-/**
+	/**
  * @brief Set sub-fsal attributes on an object
  *
  * @param[in] vfs_hdl    The VFS object to modify
@@ -132,8 +128,8 @@ struct vfs_subfsal_obj_ops {
  *
  * @return FSAL status.
  */
-	fsal_status_t (*setattrs)(struct vfs_fsal_obj_handle *vfs_hdl,
-				  int fd, attrmask_t request_mask,
+	fsal_status_t (*setattrs)(struct vfs_fsal_obj_handle *vfs_hdl, int fd,
+				  attrmask_t request_mask,
 				  struct fsal_attrlist *attrib_set);
 };
 
@@ -170,10 +166,10 @@ struct vfs_fsal_obj_handle {
 	fsal_dev_t dev;
 	vfs_file_handle_t *handle;
 #ifdef ENABLE_VFS_DEBUG_ACL
-	uint32_t mode;		/*< POSIX access mode */
+	uint32_t mode; /*< POSIX access mode */
 #endif
-	struct vfs_subfsal_obj_ops *sub_ops;	/*< Optional subfsal ops */
-	const struct fsal_up_vector *up_ops;	/*< Upcall operations */
+	struct vfs_subfsal_obj_ops *sub_ops; /*< Optional subfsal ops */
+	const struct fsal_up_vector *up_ops; /*< Upcall operations */
 	union {
 		struct {
 			struct fsal_share share;
@@ -194,44 +190,34 @@ struct vfs_fsal_obj_handle {
 	container_of((fsal), struct vfs_fsal_obj_handle, obj_handle)
 
 /* default vex ops */
-int vfs_fd_to_handle(int fd, struct fsal_filesystem *fs,
-		     vfs_file_handle_t *fh);
+int vfs_fd_to_handle(int fd, struct fsal_filesystem *fs, vfs_file_handle_t *fh);
 
-int vfs_name_to_handle(int atfd,
-		       struct fsal_filesystem *fs,
-		       const char *name,
+int vfs_name_to_handle(int atfd, struct fsal_filesystem *fs, const char *name,
 		       vfs_file_handle_t *fh);
 
-int vfs_open_by_handle(struct fsal_filesystem *fs,
-		       vfs_file_handle_t *fh, int openflags,
-		       fsal_errors_t *fsal_error);
+int vfs_open_by_handle(struct fsal_filesystem *fs, vfs_file_handle_t *fh,
+		       int openflags, fsal_errors_t *fsal_error);
 
-int vfs_encode_dummy_handle(vfs_file_handle_t *fh,
-			    struct fsal_filesystem *fs);
+int vfs_encode_dummy_handle(vfs_file_handle_t *fh, struct fsal_filesystem *fs);
 
 bool vfs_is_dummy_handle(vfs_file_handle_t *fh);
 
 fsal_status_t vfs_check_handle(struct fsal_export *exp_hdl,
 			       struct gsh_buffdesc *hdl_desc,
 			       struct fsal_filesystem **fs,
-			       vfs_file_handle_t *fh,
-			       bool *dummy);
+			       vfs_file_handle_t *fh, bool *dummy);
 
 bool vfs_valid_handle(struct gsh_buffdesc *desc);
 
-int vfs_readlink(struct vfs_fsal_obj_handle *myself,
-		 fsal_errors_t *fsal_error);
+int vfs_readlink(struct vfs_fsal_obj_handle *myself, fsal_errors_t *fsal_error);
 
-int vfs_extract_fsid(vfs_file_handle_t *fh,
-		     enum fsid_type *fsid_type,
+int vfs_extract_fsid(vfs_file_handle_t *fh, enum fsid_type *fsid_type,
 		     struct fsal_fsid__ *fsid);
 
-int vfs_get_root_handle(struct fsal_filesystem *fs,
-			struct vfs_fsal_export *exp,
+int vfs_get_root_handle(struct fsal_filesystem *fs, struct vfs_fsal_export *exp,
 			int *root_fd);
 
-int vfs_re_index(struct fsal_filesystem *fs,
-		 struct vfs_fsal_export *exp);
+int vfs_re_index(struct fsal_filesystem *fs, struct vfs_fsal_export *exp);
 
 /*
  * VFS structure to tell subfunctions whether they should close the
@@ -242,8 +228,7 @@ struct closefd {
 	int close_fd;
 };
 
-int vfs_fsal_open(struct vfs_fsal_obj_handle *hdl,
-		  int openflags,
+int vfs_fsal_open(struct vfs_fsal_obj_handle *hdl, int openflags,
 		  fsal_errors_t *fsal_error);
 
 fsal_status_t vfs_close_func(struct fsal_obj_handle *obj_hdl,
@@ -253,20 +238,17 @@ fsal_status_t vfs_reopen_func(struct fsal_obj_handle *obj_hdl,
 			      fsal_openflags_t openflags,
 			      struct fsal_fd *fsal_fd);
 
-struct vfs_fsal_obj_handle *alloc_handle(int dirfd,
-					 vfs_file_handle_t *fh,
-					 struct fsal_filesystem *fs,
-					 struct stat *stat,
-					 vfs_file_handle_t *dir_fh,
-					 const char *path,
-					 struct fsal_export *exp_hdl);
+struct vfs_fsal_obj_handle *
+alloc_handle(int dirfd, vfs_file_handle_t *fh, struct fsal_filesystem *fs,
+	     struct stat *stat, vfs_file_handle_t *dir_fh, const char *path,
+	     struct fsal_export *exp_hdl);
 
 void free_vfs_fsal_obj_handle(struct vfs_fsal_obj_handle **hdl);
 
 static inline bool vfs_unopenable_type(object_file_type_t type)
 {
-	if ((type == SOCKET_FILE) || (type == CHARACTER_FILE)
-	    || (type == BLOCK_FILE)) {
+	if ((type == SOCKET_FILE) || (type == CHARACTER_FILE) ||
+	    (type == BLOCK_FILE)) {
 		return true;
 	} else {
 		return false;
@@ -278,7 +260,7 @@ void vfs_state_init(void);
 void vfs_state_release(struct gsh_buffdesc *key);
 struct state_hdl *vfs_state_locate(struct fsal_obj_handle *obj);
 
-	/* I/O management */
+/* I/O management */
 fsal_status_t vfs_close_my_fd(struct vfs_fd *my_fd);
 
 fsal_status_t vfs_close(struct fsal_obj_handle *obj_hdl);
@@ -291,39 +273,31 @@ struct state_t *vfs_alloc_state(struct fsal_export *exp_hdl,
 fsal_status_t vfs_merge(struct fsal_obj_handle *orig_hdl,
 			struct fsal_obj_handle *dupe_hdl);
 
-fsal_status_t vfs_open2(struct fsal_obj_handle *obj_hdl,
-			struct state_t *state,
-			fsal_openflags_t openflags,
-			enum fsal_create_mode createmode,
-			const char *name,
-			struct fsal_attrlist *attrib_set,
-			fsal_verifier_t verifier,
-			struct fsal_obj_handle **new_obj,
-			struct fsal_attrlist *attrs_out,
-			bool *caller_perm_check);
+fsal_status_t
+vfs_open2(struct fsal_obj_handle *obj_hdl, struct state_t *state,
+	  fsal_openflags_t openflags, enum fsal_create_mode createmode,
+	  const char *name, struct fsal_attrlist *attrib_set,
+	  fsal_verifier_t verifier, struct fsal_obj_handle **new_obj,
+	  struct fsal_attrlist *attrs_out, bool *caller_perm_check,
+	  struct fsal_attrlist *parent_pre_attrs_out,
+	  struct fsal_attrlist *parent_post_attrs_out);
 
 fsal_openflags_t vfs_status2(struct fsal_obj_handle *obj_hdl,
 			     struct state_t *state);
 
 fsal_status_t vfs_reopen2(struct fsal_obj_handle *obj_hdl,
-			  struct state_t *state,
-			  fsal_openflags_t openflags);
+			  struct state_t *state, fsal_openflags_t openflags);
 
-void vfs_read2(struct fsal_obj_handle *obj_hdl,
-	       bool bypass,
-	       fsal_async_cb done_cb,
-	       struct fsal_io_arg *read_arg,
+void vfs_read2(struct fsal_obj_handle *obj_hdl, bool bypass,
+	       fsal_async_cb done_cb, struct fsal_io_arg *read_arg,
 	       void *caller_arg);
 
-void vfs_write2(struct fsal_obj_handle *obj_hdl,
-		bool bypass,
-		fsal_async_cb done_cb,
-		struct fsal_io_arg *write_arg,
+void vfs_write2(struct fsal_obj_handle *obj_hdl, bool bypass,
+		fsal_async_cb done_cb, struct fsal_io_arg *write_arg,
 		void *caller_arg);
 
 #ifdef __USE_GNU
-fsal_status_t vfs_seek2(struct fsal_obj_handle *obj_hdl,
-			struct state_t *state,
+fsal_status_t vfs_seek2(struct fsal_obj_handle *obj_hdl, struct state_t *state,
 			struct io_info *info);
 #endif
 
@@ -333,13 +307,11 @@ fsal_status_t vfs_fallocate(struct fsal_obj_handle *obj_hdl,
 			    uint64_t length, bool allocate);
 #endif
 
-fsal_status_t vfs_commit2(struct fsal_obj_handle *obj_hdl,
-			  off_t offset,
+fsal_status_t vfs_commit2(struct fsal_obj_handle *obj_hdl, off_t offset,
 			  size_t len);
 
 fsal_status_t vfs_lock_op2(struct fsal_obj_handle *obj_hdl,
-			   struct state_t *state,
-			   void *owner,
+			   struct state_t *state, void *owner,
 			   fsal_lock_op_t lock_op,
 			   fsal_lock_param_t *request_lock,
 			   fsal_lock_param_t *conflicting_lock);
@@ -349,8 +321,7 @@ fsal_status_t getattr2(struct fsal_obj_handle *obj_hdl);
 fsal_status_t vfs_getattr2(struct fsal_obj_handle *obj_hdl,
 			   struct fsal_attrlist *attrs);
 
-fsal_status_t vfs_setattr2(struct fsal_obj_handle *obj_hdl,
-			   bool bypass,
+fsal_status_t vfs_setattr2(struct fsal_obj_handle *obj_hdl, bool bypass,
 			   struct state_t *state,
 			   struct fsal_attrlist *attrib_set);
 
@@ -366,12 +337,9 @@ fsal_status_t vfs_list_ext_attrs(struct fsal_obj_handle *obj_hdl,
 fsal_status_t vfs_getextattr_id_by_name(struct fsal_obj_handle *obj_hdl,
 					const char *xattr_name,
 					unsigned int *pxattr_id);
-fsal_status_t vfs_getextattr_value(struct vfs_fsal_obj_handle *vfs_hdl,
-				   int fd,
-				   const char *xattr_name,
-				   void *buffer_addr,
-				   size_t buffer_size,
-				   size_t *p_output_size);
+fsal_status_t vfs_getextattr_value(struct vfs_fsal_obj_handle *vfs_hdl, int fd,
+				   const char *xattr_name, void *buffer_addr,
+				   size_t buffer_size, size_t *p_output_size);
 fsal_status_t vfs_getextattr_value_by_name(struct fsal_obj_handle *obj_hdl,
 					   const char *xattr_name,
 					   void *buffer_addr,
@@ -379,18 +347,14 @@ fsal_status_t vfs_getextattr_value_by_name(struct fsal_obj_handle *obj_hdl,
 					   size_t *p_output_size);
 fsal_status_t vfs_getextattr_value_by_id(struct fsal_obj_handle *obj_hdl,
 					 unsigned int xattr_id,
-					 void *buffer_addr,
-					 size_t buffer_size,
+					 void *buffer_addr, size_t buffer_size,
 					 size_t *p_output_size);
 fsal_status_t vfs_setextattr_value(struct fsal_obj_handle *obj_hdl,
-				   const char *xattr_name,
-				   void *buffer_addr,
-				   size_t buffer_size,
-				   int create);
+				   const char *xattr_name, void *buffer_addr,
+				   size_t buffer_size, int create);
 fsal_status_t vfs_setextattr_value_by_id(struct fsal_obj_handle *obj_hdl,
 					 unsigned int xattr_id,
-					 void *buffer_addr,
-					 size_t buffer_size);
+					 void *buffer_addr, size_t buffer_size);
 fsal_status_t vfs_remove_extattr_by_id(struct fsal_obj_handle *obj_hdl,
 				       unsigned int xattr_id);
 fsal_status_t vfs_remove_extattr_by_name(struct fsal_obj_handle *obj_hdl,
@@ -398,15 +362,15 @@ fsal_status_t vfs_remove_extattr_by_name(struct fsal_obj_handle *obj_hdl,
 
 fsal_status_t check_hsm_by_fd(int fd);
 
-fsal_status_t vfs_get_fs_locations(struct vfs_fsal_obj_handle *hdl,
-				   int fd,
+fsal_status_t vfs_get_fs_locations(struct vfs_fsal_obj_handle *hdl, int fd,
 				   struct fsal_attrlist *attrs_out);
 
 static inline bool vfs_set_credentials(const struct user_cred *creds,
-					  const struct fsal_module *fsal_module)
+				       const struct fsal_module *fsal_module)
 {
-	bool only_one_user = container_of(fsal_module,
-				struct vfs_fsal_module, module)->only_one_user;
+	bool only_one_user =
+		container_of(fsal_module, struct vfs_fsal_module, module)
+			->only_one_user;
 
 	if (only_one_user)
 		return fsal_set_credentials_only_one_user(creds);
@@ -416,14 +380,19 @@ static inline bool vfs_set_credentials(const struct user_cred *creds,
 	}
 }
 
-static inline void vfs_restore_ganesha_credentials(const struct fsal_module
-							*fsal_module)
+static inline void
+vfs_restore_ganesha_credentials(const struct fsal_module *fsal_module)
 {
-	bool only_one_user = container_of(fsal_module,
-				struct vfs_fsal_module, module)->only_one_user;
+	bool only_one_user =
+		container_of(fsal_module, struct vfs_fsal_module, module)
+			->only_one_user;
 
 	if (!only_one_user)
 		fsal_restore_ganesha_credentials();
 }
 
-#endif			/* VFS_METHODS_H */
+fsal_status_t find_fd(struct fsal_fd **out_fd, struct fsal_obj_handle *obj_hdl,
+		      struct fsal_fd *tmp_fd, struct state_t *state,
+		      fsal_openflags_t openflags, bool bypass);
+
+#endif /* VFS_METHODS_H */
