@@ -1,3 +1,4 @@
+/* SPDX-License-Identifier: LGPL-3.0-or-later */
 /*
  * Copyright (C) 2010, Linux Box Corporation
  * All Rights Reserved
@@ -44,7 +45,7 @@
  * architecture).  Quadratic probing is used to emulate perfect
  * hashing.  Worst case behavior is challenging to reproduce.
  * Heuristic methods are used to detect worst-case scenarios and fall
- * back to tractable (e.g., lookup) algorthims.
+ * back to tractable (e.g., lookup) algorithms.
  *
  */
 
@@ -102,18 +103,13 @@ static inline int avl_dirent_sorted_cmpf(const struct avltree_node *lhs,
 	/* On create a dirent will not yet belong to a chunk, but only
 	 * one of the two nodes in comparison can not belong to a chunk.
 	 */
-	subcall(
-		if (lk->chunk != NULL)
+	subcall(if (lk->chunk != NULL)
 			rc = lk->chunk->parent->sub_handle->obj_ops->dirent_cmp(
-				lk->chunk->parent->sub_handle,
-				lk->name, lk->ck,
+				lk->chunk->parent->sub_handle, lk->name, lk->ck,
 				rk->name, rk->ck);
-		else
-			rc = rk->chunk->parent->sub_handle->obj_ops->dirent_cmp(
-				rk->chunk->parent->sub_handle,
-				lk->name, lk->ck,
-				rk->name, rk->ck)
-	       );
+		else rc = rk->chunk->parent->sub_handle->obj_ops->dirent_cmp(
+			rk->chunk->parent->sub_handle, lk->name, lk->ck,
+			rk->name, rk->ck));
 
 	return rc;
 }
@@ -131,6 +127,6 @@ mdcache_dir_entry_t *mdcache_avl_lookup(mdcache_entry_t *entry,
 void mdcache_avl_clean_trees(mdcache_entry_t *parent);
 
 void unchunk_dirent(mdcache_dir_entry_t *dirent);
-#endif				/* MDCACHE_AVL_H */
+#endif /* MDCACHE_AVL_H */
 
 /** @} */
