@@ -82,7 +82,7 @@ struct mdcache_parameter {
 	    settable by Chunks_HWMark. */
 	uint32_t chunks_lwmark;
 	/** Base interval in seconds between runs of the LRU cleaner
-	    thread. Defaults to 60, settable with LRU_Run_Interval. */
+	    thread. Defaults to 90, settable with LRU_Run_Interval. */
 	uint32_t lru_run_interval;
 	/** If "Cache_FDs" is set to false, the reaper thread aggressively
 	 *  closes FDs , significantly reducing the number of open FDs.
@@ -91,8 +91,14 @@ struct mdcache_parameter {
 	 *  If "Cache_FDs" is set to true (default), FDs are cached, and the
 	 *  LRU reaper thread closes FDs only when the current open FD count
 	 *  reaches or exceeds the "fds_lowat" threshold.
-	 */
+	 *
+	 *  Note, this setting has no effect when Close_Fast is set to true. */
 	bool Cache_FDs;
+	/**
+	 * Whether to close files immediately after opening files and
+	 * using them for read/write/commit. Defaults to false,
+	 * settable with Close_Fast. */
+	bool close_fast;
 	/** The percentage of the system-imposed maximum of file
 	    descriptors at which Ganesha will deny requests.
 	    Defaults to 99, settable with FD_Limit_Percent. */
@@ -132,6 +138,12 @@ struct mdcache_parameter {
 	/** Total number of files ganesha can delegate to clients
 	    as a percent of Entries_HWMark */
 	int32_t files_delegatable_percent;
+	/** This option allows mdcache_test_access to use the cached owner value
+	    for an object in case of owner override, even if the cache entry is
+	    not up to date. This could potentially lead to the wrong result, but
+	    can significantly improve performance saving the need to update
+	    attributes on many read/write operations. */
+	bool use_cached_owner_on_owner_override;
 };
 
 extern struct mdcache_parameter mdcache_param;
