@@ -586,10 +586,11 @@ static fsal_status_t mdcache_readdir(struct fsal_obj_handle *dir_hdl,
  * FSALs call the default method.  This should be revisited if a FSAL wants to
  * override test_access().
  *
- * @note If @a owner_skip is provided, we test against the cached owner.  This
- * is because doing a getattrs() potentially on each read and write (writes
- * invalidate cached attributes) is a huge performance hit.  Eventually, finer
- * grained attribute validity would be a better solution
+ * @note If @a owner_skip is provided, and
+ * mdcache_param.use_cached_owner_on_owner_override is true, we test against the
+ * cached owner.  This is because doing a getattrs() potentially on each read
+ * and write (writes invalidate cached attributes) is a huge performance hit.
+ * Eventually, finer grained attribute validity would be a better solution
  *
  * @param[in] obj_hdl     Handle to check
  * @param[in] access_type Access requested
@@ -608,7 +609,8 @@ static fsal_status_t mdcache_test_access(struct fsal_obj_handle *obj_hdl,
 	mdcache_entry_t *entry =
 		container_of(obj_hdl, mdcache_entry_t, obj_handle);
 
-	if (owner_skip && entry->attrs.owner == op_ctx->creds.caller_uid)
+	if (owner_skip && entry->attrs.owner == op_ctx->creds.caller_uid &&
+	    mdcache_param.use_cached_owner_on_owner_override)
 		return fsalstat(ERR_FSAL_NO_ERROR, 0);
 
 	return fsal_test_access(obj_hdl, access_type, allowed, denied,
@@ -824,13 +826,13 @@ out:
  * @param[in] need_acl		Indicates if the ACL needs updating.
  * @param[in] need_fslocations	Indicates if the fslocations are needed.
  * @param[in] need_seclabel	Indicates if security label is needed.
- * @param[in] invalidate	Invalidate the dirent cache if the entry is a
- *				directory.
+ * @param[in/out] invalidate	Caller wants to know if it should Invalidate the
+ *				dirent cache.
  */
 
 fsal_status_t mdcache_refresh_attrs(mdcache_entry_t *entry, bool need_acl,
 				    bool need_fslocations, bool need_seclabel,
-				    bool invalidate)
+				    bool *invalidate)
 {
 	struct fsal_attrlist attrs;
 	fsal_status_t status = { 0, 0 };
@@ -839,6 +841,10 @@ fsal_status_t mdcache_refresh_attrs(mdcache_entry_t *entry, bool need_acl,
 	cbgetattr_t *cbgetattr;
 	uint32_t original_generation;
 
+	/* Assume no invalidation. */
+	if (invalidate != NULL)
+		*invalidate = false;
+
 	/* Use this to detect if we should invalidate a directory. */
 	oldmtime = entry->attrs.mtime;
 
@@ -938,11 +944,10 @@ out:
 	LogAttrlist(COMPONENT_MDCACHE, NIV_FULL_DEBUG, "attrs ", &entry->attrs,
 		    true);
 
-	if (invalidate && entry->obj_handle.type == DIRECTORY &&
+	if (invalidate != NULL && entry->obj_handle.type == DIRECTORY &&
 	    gsh_time_cmp(&oldmtime, &entry->attrs.mtime) != 0) {
-		PTHREAD_RWLOCK_wrlock(&entry->content_lock);
-		mdcache_dirent_invalidate_all(entry);
-		PTHREAD_RWLOCK_unlock(&entry->content_lock);
+		/* Request caller to invalidate */
+		*invalidate = true;
 	}
 
 	return status;
@@ -964,6 +969,7 @@ static fsal_status_t mdcache_getattrs(struct fsal_obj_handle *obj_hdl,
 	mdcache_entry_t *entry =
 		container_of(obj_hdl, mdcache_entry_t, obj_handle);
 	fsal_status_t status = { 0, 0 };
+	bool invalidate = false;
 
 #ifdef USE_MONITORING
 	const char *OPERATION = "getattr";
@@ -971,6 +977,21 @@ static fsal_status_t mdcache_getattrs(struct fsal_obj_handle *obj_hdl,
 	const uint16_t export_id = (export == NULL ? 0 : export->export_id);
 #endif /* USE_MONITORING */
 
+	if (op_ctx->export_perms.expire_time_attr == 0) {
+		/* Attribute caching is disabled. No reason to lock the entry
+		 * and serialize getattr access. Use subcall directly */
+#ifdef USE_MONITORING
+		monitoring__dynamic_mdcache_cache_miss(OPERATION, export_id);
+#endif /* USE_MONITORING */
+
+		subcall(status = entry->sub_handle->obj_ops->getattrs(
+				entry->sub_handle, attrs_out););
+
+		LogAttrlist(COMPONENT_MDCACHE, NIV_FULL_DEBUG, "attrs ",
+			    attrs_out, true);
+		return status;
+	}
+
 	PTHREAD_RWLOCK_rdlock(&entry->attr_lock);
 
 	if (mdcache_is_attrs_valid(entry, attrs_out->request_mask)) {
@@ -1000,7 +1021,7 @@ static fsal_status_t mdcache_getattrs(struct fsal_obj_handle *obj_hdl,
 	status = mdcache_refresh_attrs(
 		entry, (attrs_out->request_mask & ATTR_ACL) != 0,
 		(attrs_out->request_mask & ATTR4_FS_LOCATIONS) != 0,
-		(attrs_out->request_mask & ATTR4_SEC_LABEL) != 0, true);
+		(attrs_out->request_mask & ATTR4_SEC_LABEL) != 0, &invalidate);
 
 	if (FSAL_IS_ERROR(status)) {
 		/* We failed to fetch any attributes. Pass that fact back to
@@ -1021,6 +1042,12 @@ unlock_no_attrs:
 
 	PTHREAD_RWLOCK_unlock(&entry->attr_lock);
 
+	if (invalidate) {
+		PTHREAD_RWLOCK_wrlock(&entry->content_lock);
+		mdcache_dirent_invalidate_all(entry);
+		PTHREAD_RWLOCK_unlock(&entry->content_lock);
+	}
+
 	if (FSAL_IS_ERROR(status) && (status.major == ERR_FSAL_STALE))
 		mdcache_kill_entry(entry);
 
@@ -1059,6 +1086,12 @@ static fsal_status_t mdcache_setattr2(struct fsal_obj_handle *obj_hdl,
 		goto out;
 	}
 
+	if (op_ctx->export_perms.expire_time_attr == 0) {
+		/* Attribute caching is disabled. No need to refresh the
+		 * attributes */
+		goto out;
+	}
+
 	/* In case of ACL enabled, any of the below attribute changes
 	 * result in change of ACL set as well.
 	 */
@@ -1069,7 +1102,7 @@ static fsal_status_t mdcache_setattr2(struct fsal_obj_handle *obj_hdl,
 	}
 
 	PTHREAD_RWLOCK_wrlock(&entry->attr_lock);
-	status2 = mdcache_refresh_attrs(entry, need_acl, false, false, false);
+	status2 = mdcache_refresh_attrs(entry, need_acl, false, false, NULL);
 	if (FSAL_IS_ERROR(status2)) {
 		/* Assume that the cache is bogus now */
 		atomic_clear_uint32_t_bits(&entry->mde_flags,
