@@ -476,7 +476,7 @@ fsal_status_t mdcache_alloc_and_check_handle(
 
 fsal_status_t mdcache_refresh_attrs(mdcache_entry_t *entry, bool need_acl,
 				    bool need_fslocations, bool need_seclabel,
-				    bool invalidate);
+				    bool *invalidate);
 
 fsal_status_t mdcache_new_entry(struct mdcache_fsal_export *exp,
 				struct fsal_obj_handle *sub_handle,
@@ -1127,9 +1127,15 @@ mdcache_refresh_attrs_no_invalidate(mdcache_entry_t *entry)
 {
 	fsal_status_t status;
 
+	if (op_ctx->export_perms.expire_time_attr == 0) {
+		/* Attribute cache is disabled, no need to refresh the
+		 * attributes */
+		return fsalstat(ERR_FSAL_NO_ERROR, 0);
+	}
+
 	PTHREAD_RWLOCK_wrlock(&entry->attr_lock);
 
-	status = mdcache_refresh_attrs(entry, false, false, false, false);
+	status = mdcache_refresh_attrs(entry, false, false, false, NULL);
 
 	PTHREAD_RWLOCK_unlock(&entry->attr_lock);
 
