@@ -1266,8 +1266,11 @@ static void lru_run(struct fridgethr_context *ctx)
 				atomic_fetch_uint64_t(&lru_state.entries_used),
 				lru_state.entries_release_size);
 
+			EXPORT_ADMIN_LOCK();
 			released = mdcache_lru_release_entries(
 				lru_state.entries_release_size);
+			EXPORT_ADMIN_UNLOCK();
+
 			LogFullDebug(COMPONENT_MDCACHE_LRU,
 				     "Actually release %zd entries", released);
 		} else {
@@ -1546,6 +1549,7 @@ void init_fds_limit(void)
 
 	fd_lru_parameter.lru_run_interval = mdcache_param.lru_run_interval;
 	fd_lru_parameter.Cache_FDs = mdcache_param.Cache_FDs;
+	fd_lru_parameter.close_fast = mdcache_param.close_fast;
 	fd_lru_parameter.fd_limit_percent = mdcache_param.fd_limit_percent;
 	fd_lru_parameter.fd_hwmark_percent = mdcache_param.fd_hwmark_percent;
 	fd_lru_parameter.fd_lwmark_percent = mdcache_param.fd_lwmark_percent;
@@ -1629,6 +1633,7 @@ fsal_status_t mdcache_lru_pkginit(void)
 
 	fd_lru_parameter.lru_run_interval = mdcache_param.lru_run_interval;
 	fd_lru_parameter.Cache_FDs = mdcache_param.Cache_FDs;
+	fd_lru_parameter.close_fast = mdcache_param.close_fast;
 	fd_lru_parameter.fd_limit_percent = mdcache_param.fd_limit_percent;
 	fd_lru_parameter.fd_hwmark_percent = mdcache_param.fd_hwmark_percent;
 	fd_lru_parameter.fd_lwmark_percent = mdcache_param.fd_lwmark_percent;
@@ -1798,7 +1803,7 @@ void mdcache_lru_insert_active(mdcache_entry_t *entry)
 void _mdcache_lru_ref(mdcache_entry_t *entry, uint32_t flags, const char *func,
 		      int line)
 {
-	int32_t refcnt, active_refcnt;
+	int32_t refcnt, active_refcnt = -999;
 
 	/* Always take a normal reference so unref to 0 works right */
 	refcnt = atomic_inc_int32_t(&entry->lru.refcnt);
