@@ -75,6 +75,8 @@ bool fsal_supports(struct fsal_staticfsinfo_t *info,
 		return !!info->lock_support;
 	case fso_lock_support_async_block:
 		return !!info->lock_support_async_block;
+	case fso_lock_full_control:
+		return !!info->lock_full_control;
 	case fso_named_attr:
 		return !!info->named_attr;
 	case fso_unique_handles:
@@ -109,8 +111,10 @@ bool fsal_supports(struct fsal_staticfsinfo_t *info,
 		return !!info->compliant_eof_behavior;
 	case fso_xattr_support:
 		return !!info->xattr_support;
+	case fso_allocate_own_read_buffer:
+		return !!info->allocate_own_read_buffer;
 	default:
-		return false;	/* whatever I don't know about,
+		return false; /* whatever I don't know about,
 				 * you can't do
 				 */
 	}
