@@ -132,6 +132,8 @@ void destroy_fsals(void)
 	struct glist_head *mi = NULL;
 	/* Next module */
 	struct glist_head *mn = NULL;
+	int rc = 0;
+	char *fsal_name;
 
 	glist_for_each_safe(mi, mn, &fsal_list)
 	{
@@ -182,21 +184,15 @@ void destroy_fsals(void)
 			 */
 			atomic_store_int32_t(&m->refcount, 0);
 		}
-		if (m->dl_handle) {
-			int rc = 0;
-			char *fsal_name = gsh_strdup(m->name);
-
-			LogEvent(COMPONENT_FSAL, "Unloading FSAL %s",
-				 fsal_name);
-			rc = m->m_ops.unload(m);
-			if (rc != 0) {
-				LogMajor(COMPONENT_FSAL,
-					 "Unload of %s failed with error %d",
-					 fsal_name, rc);
-			}
-			LogEvent(COMPONENT_FSAL, "FSAL %s unloaded", fsal_name);
-			gsh_free(fsal_name);
+		fsal_name = gsh_strdupa(m->name);
+		LogEvent(COMPONENT_FSAL, "Unloading FSAL %s", fsal_name);
+		rc = m->m_ops.unload(m);
+		if (rc != 0) {
+			LogMajor(COMPONENT_FSAL,
+				 "Unload of %s failed with error %d", fsal_name,
+				 rc);
 		}
+		LogEvent(COMPONENT_FSAL, "FSAL %s unloaded", fsal_name);
 	}
 
 	release_posix_file_systems();
