@@ -83,6 +83,7 @@
 #include "FSAL/fsal_localfs.h"
 #ifdef USE_MONITORING
 #include "nfs_metrics.h"
+#include "sal_metrics.h"
 #endif
 
 pthread_mutexattr_t default_mutex_attr;
@@ -952,7 +953,7 @@ static void nfs_Start_threads(void)
 
 int nfsv4_init_params(void)
 {
-	int rc;
+	int __attribute__((unused)) rc;
 	int owner_len, scope_len, ss_suffix_len;
 	char *cid_server_scope_suffix = "_NFS-Ganesha";
 
@@ -1010,6 +1011,7 @@ static void nfs_Init(const nfs_start_info_t *p_start_info)
 #ifdef USE_MONITORING
 	/* initializing nfs ganesha metrics */
 	nfs_metrics__init();
+	sal_metrics__init();
 #endif
 
 	/* acls cache may be needed by exports_pkginit */
@@ -1227,8 +1229,8 @@ static void do_malloc_trim(void *param)
 {
 	LogDebug(COMPONENT_MAIN,
 		 malloc_trim(0) ?
-			 "malloc_trim() released some memory" :
-			 "malloc_trim() was not able to release memory");
+			       "malloc_trim() released some memory" :
+			       "malloc_trim() was not able to release memory");
 	(void)delayed_submit(do_malloc_trim, 0, THIRTY_MIN);
 }
 #endif
