@@ -68,6 +68,8 @@
 #endif
 #include "gsh_xprt_tracepoint.h"
 
+#include "nfs_metrics.h"
+
 #define NFS_pcp nfs_param.core_param
 #define NFS_options NFS_pcp.core_options
 #define NFS_program NFS_pcp.program
@@ -874,23 +876,21 @@ static enum xprt_stat nfs_rpc_process_request(nfs_request_t *reqdata,
 
 		LogFullDebug(COMPONENT_DISPATCH,
 			     "RPCSEC_GSS no_dispatch=%d gc->gc_proc=(%u) %s %s",
-			     no_dispatch, gc->gc_proc,
-			     str_gc_proc(gc->gc_proc),
-			     gc->gc_svc == RPCSEC_GSS_SVC_NONE ? "krb5"
-			     : gc->gc_svc == RPCSEC_GSS_SVC_INTEGRITY ? "krb5i"
-			     : gc->gc_svc == RPCSEC_GSS_SVC_PRIVACY ? "krb5p"
-			     : "unknown");
+			     no_dispatch, gc->gc_proc, str_gc_proc(gc->gc_proc),
+			     gc->gc_svc == RPCSEC_GSS_SVC_NONE	    ? "krb5" :
+			     gc->gc_svc == RPCSEC_GSS_SVC_INTEGRITY ? "krb5i" :
+			     gc->gc_svc == RPCSEC_GSS_SVC_PRIVACY   ? "krb5p" :
+								      "unknown");
 #ifdef _USE_NFS_RDMA
 		if (get_port(svc_getrpclocal(xprt)) ==
-			nfs_param.core_param.port[P_NFS_RDMA] &&
-			gc->gc_svc == RPCSEC_GSS_SVC_PRIVACY) {
-				LogCrit(COMPONENT_DISPATCH,
-					"NFS over RDMA transport is not supported for GSS flavour krb5p, failing the request !!!");
-				/* mount.nfs gets Protocol not
+			    nfs_param.core_param.port[P_NFS_RDMA] &&
+		    gc->gc_svc == RPCSEC_GSS_SVC_PRIVACY) {
+			LogCrit(COMPONENT_DISPATCH,
+				"NFS over RDMA transport is not supported for GSS flavour krb5p, failing the request !!!");
+			/* mount.nfs gets Protocol not
 				 * supported errors
 				 */
-				return svcerr_progvers(&reqdata->svc,
-						       NFS_V4, NFS_V4);
+			return svcerr_progvers(&reqdata->svc, NFS_V4, NFS_V4);
 		}
 #endif
 		if (no_dispatch) {
@@ -924,6 +924,8 @@ static enum xprt_stat nfs_rpc_process_request(nfs_request_t *reqdata,
 			 * measure the frequency of occurrence this scenario.
 			 */
 			if (gc->gc_proc == RPCSEC_GSS_DATA) {
+				nfs_metrics__gss_request_dropped();
+
 				LogInfo(COMPONENT_DISPATCH,
 					"Received AUTH_OK for RPCSEC_GSS_DATA procedure with no-dispatch set to true. Destroying connection.");
 				SVC_DESTROY(reqdata->svc.rq_xprt);
@@ -984,7 +986,7 @@ static enum xprt_stat nfs_rpc_process_request(nfs_request_t *reqdata,
 	}
 
 	/* set up the request context */
-	init_op_context(&reqdata->op_context, NULL, NULL,
+	init_op_context(&reqdata->op_context, NULL, NULL, reqdata,
 			(sockaddr_t *)svc_getrpccaller(xprt),
 			reqdata->svc.rq_msg.cb_vers, 0, NFS_REQUEST);
 
