@@ -180,7 +180,7 @@ static nfsstat4 open4_validate_claim(compound_data_t *data,
 				*grace_ref = true;
 			} else {
 				status = want_grace ? NFS4ERR_NO_GRACE :
-							    NFS4ERR_GRACE;
+						      NFS4ERR_GRACE;
 			}
 		} else {
 			*grace_ref = false;
@@ -1033,7 +1033,7 @@ retry_open_file:
 		LogFullDebug(COMPONENT_STATE, "Calling reopen2");
 
 		status = fsal_reopen2(file_obj, *file_state,
-				      openflags | old_openflags, false);
+				      openflags | old_openflags, true);
 
 		if (FSAL_IS_ERROR(status)) {
 			res_OPEN4->status = nfs4_Errno_status(status);
@@ -1332,8 +1332,8 @@ enum nfs_req_result nfs4_op_open(struct nfs_argop4 *op, compound_data_t *data,
 		 arg_OPEN4->owner.clientid);
 
 	retval = nfs_client_id_get_confirmed(data->minorversion == 0 ?
-							   arg_OPEN4->owner.clientid :
-							   data->session->clientid,
+						     arg_OPEN4->owner.clientid :
+						     data->session->clientid,
 					     &clientid);
 
 	if (retval != CLIENT_ID_SUCCESS) {
@@ -1457,7 +1457,7 @@ enum nfs_req_result nfs4_op_open(struct nfs_argop4 *op, compound_data_t *data,
 
 	res_OPEN4->OPEN4res_u.resok4.cinfo.atomic =
 		is_parent_pre_attrs_valid && is_parent_post_attrs_valid ? TRUE :
-										FALSE;
+									  FALSE;
 
 	/* Handle open stateid/seqid for success */
 	update_stateid(file_state, &res_OPEN4->OPEN4res_u.resok4.stateid, data,
