@@ -54,15 +54,15 @@ enum nfs_req_result nfs4_op_openattr(struct nfs_argop4 *op,
 				     compound_data_t *data,
 				     struct nfs_resop4 *resp)
 {
-	OPENATTR4args * const arg_OPENATTR4 __attribute__ ((unused))
-	    = &op->nfs_argop4_u.opopenattr;
-	OPENATTR4res * const res_OPENATTR4 = &resp->nfs_resop4_u.opopenattr;
+	OPENATTR4args *const arg_OPENATTR4
+		__attribute__((unused)) = &op->nfs_argop4_u.opopenattr;
+	OPENATTR4res *const res_OPENATTR4 = &resp->nfs_resop4_u.opopenattr;
 
 	resp->resop = NFS4_OP_OPENATTR;
 	res_OPENATTR4->status = NFS4ERR_NOTSUPP;
 
 	return NFS_REQ_ERROR;
-}				/* nfs4_op_openattr */
+} /* nfs4_op_openattr */
 
 /**
  * @brief Free memory allocated for OPENATTR result
