@@ -48,8 +48,14 @@
 #include "fsal_pnfs.h"
 #include "server_stats.h"
 #include "export_mgr.h"
+#include "nfs_exports.h"
 #include "gsh_rpc.h"
 
+#include "gsh_lttng/gsh_lttng.h"
+#if defined(USE_LTTNG) && !defined(LTTNG_PARSING)
+#include "gsh_lttng/generated_traces/nfs4.h"
+#endif
+
 struct nfs4_read_data {
 	/** Results for read */
 	READ4res *res_READ4;
@@ -118,8 +124,11 @@ static enum nfs_req_result nfs4_complete_read(struct nfs4_read_data *data)
 			/* We won't need the FSAL's iovec and buffers if it used
 			 * them
 			 */
-			if (read_arg->iov_release != NULL)
+			if (read_arg->iov_release != NULL) {
 				read_arg->iov_release(read_arg->release_data);
+				read_arg->iov[0].iov_base = NULL;
+				read_arg->iov_release = NULL;
+			}
 
 			/* We will use the iov we set up before the call, but
 			 * set the length of the buffer to 0. The
@@ -197,6 +206,29 @@ static void nfs4_complete_read_plus(struct nfs_resop4 *resp,
 	}
 }
 
+static fsal_status_t allow_read(struct fsal_obj_handle *obj,
+				uint32_t read_access_check_policy_to_check)
+{
+	const uint32_t read_access_check_policy = atomic_fetch_uint32_t(
+		&op_ctx->ctx_export->read_access_check_policy);
+	fsal_status_t ret = { 0, 0 };
+
+	if (read_access_check_policy & read_access_check_policy_to_check) {
+		ret = obj->obj_ops->test_access(obj, FSAL_READ_ACCESS, NULL,
+						NULL, true);
+
+		if (ret.major == ERR_FSAL_ACCESS) {
+			/* Test for execute permission */
+			ret = fsal_access(
+				obj, FSAL_MODE_MASK_SET(FSAL_X_OK) |
+					     FSAL_ACE4_MASK_SET(
+						     FSAL_ACE_PERM_EXECUTE));
+		}
+	}
+
+	return ret;
+}
+
 /**
  * @brief Callback for NFS4 read done
  *
@@ -215,6 +247,11 @@ static void nfs4_read_cb(struct fsal_obj_handle *obj, fsal_status_t ret,
 	if (ret.major == ERR_FSAL_SHARE_DENIED)
 		ret = fsalstat(ERR_FSAL_LOCKED, 0);
 
+	if (!FSAL_IS_ERROR(ret)) {
+		/* Perform permission checks after the FSAL does the read */
+		ret = allow_read(obj, READ_ACCESS_CHECK_POLICY_POST);
+	}
+
 	/* Get result */
 	data->res_READ4->status = nfs4_Errno_status(ret);
 
@@ -661,17 +698,8 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 		anonymous_started = true;
 	}
 
-	/* Need to permission check the read. */
-	fsal_status = obj->obj_ops->test_access(obj, FSAL_READ_ACCESS, NULL,
-						NULL, true);
-
-	if (fsal_status.major == ERR_FSAL_ACCESS) {
-		/* Test for execute permission */
-		fsal_status = fsal_access(
-			obj, FSAL_MODE_MASK_SET(FSAL_X_OK) |
-				     FSAL_ACE4_MASK_SET(FSAL_ACE_PERM_EXECUTE));
-	}
-
+	/* Perform permission checks before the FSAL does the read */
+	fsal_status = allow_read(obj, READ_ACCESS_CHECK_POLICY_PRE);
 	if (FSAL_IS_ERROR(fsal_status)) {
 		res_READ4->status = nfs4_Errno_status(fsal_status);
 		goto out;
@@ -768,6 +796,7 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 	read_data = gsh_calloc(1, sizeof(*read_data));
 	LogFullDebug(COMPONENT_NFS_V4, "Allocated read_data %p", read_data);
 	read_arg = &read_data->read_arg;
+	read_arg->info = info;
 	read_arg->state = state_found;
 	read_arg->offset = offset;
 	read_arg->iov_count = resok->data.iovcnt;
@@ -846,8 +875,15 @@ out:
 enum nfs_req_result nfs4_op_read(struct nfs_argop4 *op, compound_data_t *data,
 				 struct nfs_resop4 *resp)
 {
+	READ4args *const arg_READ4 = &op->nfs_argop4_u.opread;
+	READ4res *const res_READ4 = &resp->nfs_resop4_u.opread;
 	enum nfs_req_result rc;
 
+	GSH_AUTO_TRACEPOINT(nfs4, op_read_start, TRACE_INFO,
+			    "READ arg: stateid={} offset={} count={}",
+			    arg_READ4->stateid.seqid, arg_READ4->offset,
+			    arg_READ4->count);
+
 	/* Say we are managing NFS4_OP_READ */
 	resp->resop = NFS4_OP_READ;
 
@@ -877,6 +913,10 @@ enum nfs_req_result nfs4_op_read(struct nfs_argop4 *op, compound_data_t *data,
 		data->op_data = NULL;
 	}
 
+	GSH_AUTO_TRACEPOINT(nfs4, op_read_end, TRACE_INFO,
+			    "READ res: rc={} status={} datalen={}", rc,
+			    res_READ4->status,
+			    res_READ4->READ4res_u.resok4.data.data_len);
 	return rc;
 }
 
