@@ -36,6 +36,11 @@
 #include "nfs_convert.h"
 #include "export_mgr.h"
 
+#include "gsh_lttng/gsh_lttng.h"
+#if defined(USE_LTTNG) && !defined(LTTNG_PARSING)
+#include "gsh_lttng/generated_traces/nfs4.h"
+#endif
+
 /**
  * @brief Opaque bookkeeping structure for NFSv4 readdir
  *
@@ -74,6 +79,17 @@ static void restore_data(struct nfs4_readdir_cb_data *tracker)
 	}
 }
 
+/* Base response of READDIR res ok includes nfsstat4, and verifier. This is the
+ * part of the data that is not serialized with struct dirlist4 */
+#define READDIR_RESOK_BASE_SIZE (sizeof(verifier4))
+
+/* Base response of dirlist4 It includes entry termination and eof */
+#define DIR_LIST4_BASE_SIZE (2 * BYTES_PER_XDR_UNIT)
+
+/* Base response size includes READDIR_RESOK_BASE_SIZE and
+ * DIR_LIST4_BASE_SIZE. */
+#define READDIR_RESP_BASE_SIZE (READDIR_RESOK_BASE_SIZE + DIR_LIST4_BASE_SIZE)
+
 /* The base size of a readdir entry includes cookie, name length, and the
  * indicator if a next entry follows.
  */
@@ -108,14 +124,17 @@ fsal_errors_t nfs4_readdir_callback(void *opaque, struct fsal_obj_handle *obj,
 	fsal_status_t fsal_status;
 	fsal_accessflags_t access_mask_attr = 0;
 	u_int pos_start = xdr_getpos(&tracker->xdr);
-	u_int mem_left = tracker->mem_avail - pos_start;
+	/* We must leave space to deserialize DIR_LIST4_BASE_SIZE */
+	u_int mem_avail = tracker->mem_avail - DIR_LIST4_BASE_SIZE;
 	component4 name;
 	bool_t res_false = false;
 	bool_t lock_dir = false;
 	struct fsal_obj_handle *saved_current_obj = NULL;
 
+	assert(mem_avail >= pos_start);
 	LogFullDebug(COMPONENT_NFS_READDIR, "Entry %s pos %d mem_left %d",
-		     cb_parms->name, (int)pos_start, (int)mem_left);
+		     cb_parms->name, (int)pos_start,
+		     (int)(mem_avail - pos_start));
 
 	memset(&args, 0, sizeof(args));
 
@@ -300,18 +319,13 @@ not_junction:
 	}
 
 	/* Bits that don't require allocation */
-	if (mem_left < BASE_ENTRY_SIZE) {
-		if (!tracker->has_entries) {
-			tracker->error = NFS4ERR_TOOSMALL;
-		}
+	if (xdr_getpos(&tracker->xdr) + BASE_ENTRY_SIZE > mem_avail) {
 		LogDebug(COMPONENT_NFS_READDIR,
 			 "Skipping because too small for BASE_ENTRY_SIZE %d",
 			 (int)BASE_ENTRY_SIZE);
 		goto failure;
 	}
 
-	mem_left -= BASE_ENTRY_SIZE;
-
 	/* The filename.  We don't use str2utf8 because that has an
 	 * additional copy into a buffer before copying into the
 	 * destination.
@@ -319,10 +333,9 @@ not_junction:
 	name.utf8string_len = strlen(cb_parms->name);
 	name.utf8string_val = (char *)cb_parms->name;
 
-	if (mem_left < RNDUP(name.utf8string_len)) {
-		if (!tracker->has_entries) {
-			tracker->error = NFS4ERR_TOOSMALL;
-		}
+	if (xdr_getpos(&tracker->xdr) + BASE_ENTRY_SIZE +
+		    RNDUP(name.utf8string_len) >
+	    mem_avail) {
 		LogDebug(COMPONENT_NFS_READDIR,
 			 "Skipping because of name %s too long %d",
 			 (char *)cb_parms->name, (int)name.utf8string_len);
@@ -406,8 +419,7 @@ not_junction:
 	data->current_obj = obj;
 	if (!xdr_encode_entry4(&tracker->xdr, &args, tracker->req_attr, cookie,
 			       &name) ||
-	    (xdr_getpos(&tracker->xdr) + BYTES_PER_XDR_UNIT) >=
-		    tracker->mem_avail) {
+	    (xdr_getpos(&tracker->xdr) + BYTES_PER_XDR_UNIT) > mem_avail) {
 		/* We had an overflow */
 		LogFullDebug(
 			COMPONENT_NFS_READDIR,
@@ -421,9 +433,9 @@ not_junction:
 skip:
 
 	if (args.rdattr_error != NFS4_OK) {
+		tracker->error = args.rdattr_error;
 		if (!attribute_is_set(tracker->req_attr, FATTR4_RDATTR_ERROR) &&
 		    !attribute_is_set(tracker->req_attr, FATTR4_FS_LOCATIONS)) {
-			tracker->error = args.rdattr_error;
 			LogDebug(
 				COMPONENT_NFS_READDIR,
 				"Skipping because of %s and didn't ask for FATTR4_RDATTR_ERROR or FATTR4_FS_LOCATIONS",
@@ -433,8 +445,8 @@ skip:
 
 		if (!xdr_nfs4_fattr_fill_error(&tracker->xdr, tracker->req_attr,
 					       cookie, &name, &args) ||
-		    (xdr_getpos(&tracker->xdr) + BYTES_PER_XDR_UNIT) >=
-			    tracker->mem_avail) {
+		    (xdr_getpos(&tracker->xdr) + BYTES_PER_XDR_UNIT) >
+			    mem_avail) {
 			/* We had an overflow */
 			LogFullDebug(
 				COMPONENT_NFS_READDIR,
@@ -455,6 +467,9 @@ server_fault:
 
 failure:
 
+	if (!tracker->has_entries && tracker->error == NFS4_OK)
+		tracker->error = NFS4ERR_TOOSMALL;
+
 	/* Reset to where we started this entry and encode a boolean
 	 * false instead (entry_follows is false).
 	 */
@@ -490,12 +505,6 @@ void xdr_dirlist4_uio_release(struct xdr_uio *uio, u_int flags)
 	}
 }
 
-/* Base response size includes nfsstat4, eof, verifier and termination of
- * entries list.
- */
-#define READDIR_RESP_BASE_SIZE \
-	(sizeof(nfsstat4) + sizeof(verifier4) + 2 * BYTES_PER_XDR_UNIT)
-
 /**
  * @brief NFS4_OP_READDIR
  *
@@ -529,6 +538,12 @@ enum nfs_req_result nfs4_op_readdir(struct nfs_argop4 *op,
 	bool use_cookie_verifier =
 		op_ctx_export_has_option(EXPORT_OPTION_USE_COOKIE_VERIFIER);
 
+	GSH_AUTO_TRACEPOINT(
+		nfs4, op_readir_start, TRACE_INFO,
+		"READDIR arg: cookie={} verifier={} dircount={} maxcount={}",
+		arg_READDIR4->cookie, TP_VERIFIER(arg_READDIR4->cookieverf),
+		arg_READDIR4->dircount, arg_READDIR4->maxcount);
+
 	resp->resop = NFS4_OP_READDIR;
 	res_READDIR4->status = NFS4_OK;
 
@@ -551,8 +566,8 @@ enum nfs_req_result nfs4_op_readdir(struct nfs_argop4 *op,
 	if (nfs_param.core_param.readdir_res_size < maxcount)
 		maxcount = nfs_param.core_param.readdir_res_size;
 
-	if (maxcount > (arg_READDIR4->maxcount + sizeof(nfsstat4)))
-		maxcount = arg_READDIR4->maxcount + sizeof(nfsstat4);
+	if (maxcount > (arg_READDIR4->maxcount))
+		maxcount = arg_READDIR4->maxcount;
 
 	/* Use the dircount from the request as the max number of entries if
 	 * lower than the configured max.
@@ -659,7 +674,7 @@ enum nfs_req_result nfs4_op_readdir(struct nfs_argop4 *op,
 	}
 
 	/* Prepare to read the entries */
-	tracker.mem_avail = maxcount - READDIR_RESP_BASE_SIZE;
+	tracker.mem_avail = maxcount - READDIR_RESOK_BASE_SIZE;
 	tracker.max_count = dircount;
 	tracker.entries = get_buffer_for_io_response(tracker.mem_avail, NULL);
 	/* If buffer was not assigned, let's allocate it */
@@ -708,17 +723,10 @@ enum nfs_req_result nfs4_op_readdir(struct nfs_argop4 *op,
 		goto out_destroy;
 	}
 
-	/* Set the op response size to be accounted for, maxcount was the
-	 * maximum space that mem_avail started from before we deducted
-	 * READDIR_RESP_BASE_SIZE and the space used for each entry.
-	 *
-	 * So the formula below is equivalent to:
-	 *
-	 *     maxcount - maxcount + READDIR_RESP_BASE_SIZE + space for entries
-	 *
-	 * So maxcount disappears and all that is left is the actual size.
-	 */
-	data->op_resp_size = maxcount - tracker.mem_avail;
+	/* Response size is the space we used for the entires + the response
+	 * base size + nfsstat4 size. */
+	data->op_resp_size = xdr_getpos(&tracker.xdr) + READDIR_RESP_BASE_SIZE +
+			     sizeof(nfsstat4);
 
 	if (tracker.has_entries) {
 		struct xdr_uio *uio;
@@ -801,6 +809,12 @@ out:
 
 	LogDebug(COMPONENT_NFS_READDIR, "Returning %s",
 		 nfsstat4_to_str(res_READDIR4->status));
+	GSH_AUTO_TRACEPOINT(
+		nfs4, op_readir_end, TRACE_INFO,
+		"READDIR res: status={} verifier={} eof={}",
+		res_READDIR4->status,
+		TP_VERIFIER(res_READDIR4->READDIR4res_u.resok4.cookieverf),
+		res_READDIR4->READDIR4res_u.resok4.reply.eof);
 
 	return nfsstat4_to_nfs_req_result(res_READDIR4->status);
 } /* nfs4_op_readdir */
