@@ -40,17 +40,6 @@
 #include "fsal.h"
 #include "export_mgr.h"
 
-/**
- * @brief Find the node for this path component
- *
- * If not found, create it.  Called from token_to_proc() iterator
- *
- * @param token [IN] path name component
- * @param arg   [IN] callback state
- *
- * @return status as bool. false terminates foreach
- */
-
 struct pseudofs_state {
 	struct gsh_export *export;
 	struct fsal_obj_handle *obj;
@@ -187,6 +176,16 @@ out:
 	parent_obj->obj_ops->put_ref(parent_obj);
 }
 
+/**
+ * @brief Find the node for this path component
+ *
+ * If not found, create it.
+ *
+ * @param name    [IN] path name component
+ * @param state   [IN] pseudofs state
+ *
+ * @return status as bool. false terminates foreach
+ */
 bool make_pseudofs_node(char *name, struct pseudofs_state *state)
 {
 	struct fsal_obj_handle *new_node = NULL;
@@ -334,7 +333,7 @@ bool pseudo_mount_export(struct gsh_export *export)
 
 	/* skip exports that aren't for NFS v4
 	 * Also, nothing to actually do for Pseudo Root
-	 * (defer checking pseudopath for Pseudo Root until we have refstr.
+	 * (defer checking pseudopath for Pseudo Root until we have refstr.)
 	 */
 	if (!export_can_be_mounted(export))
 		return true;
@@ -538,7 +537,8 @@ void create_pseudofs(void)
 	struct gsh_export *export;
 
 	/* Initialize a root context */
-	init_op_context(&op_context, NULL, NULL, NULL, NFS_V4, 0, NFS_RELATED);
+	init_op_context(&op_context, NULL, NULL, NULL, NULL, NFS_V4, 0,
+			NFS_RELATED);
 	op_ctx->flags.pseudo_fsal_internal_lookup = true;
 
 	while (true) {
@@ -640,7 +640,7 @@ void pseudo_unmount_export(struct gsh_export *export)
 	get_gsh_export_ref(mounted_on_export);
 
 	init_op_context(&op_context, mounted_on_export,
-			mounted_on_export->fsal_export, NULL, NFS_V4, 0,
+			mounted_on_export->fsal_export, NULL, NULL, NFS_V4, 0,
 			NFS_RELATED);
 	op_ctx->flags.pseudo_fsal_internal_lookup = true;
 
