@@ -48,24 +48,24 @@
 static pthread_mutex_t grace_mutex;
 static struct timespec current_grace; /* current grace period timeout */
 static int clid_count; /* number of active clients */
-static struct glist_head clid_list = GLIST_HEAD_INIT(clid_list);  /* clients */
+static struct glist_head clid_list = GLIST_HEAD_INIT(clid_list); /* clients */
 
 /*
  * Low two bits of grace_status word are flags. One for whether we're currently
  * in a grace period and one if a change was requested.
  */
-#define GRACE_STATUS_ACTIVE_SHIFT	0
-#define GRACE_STATUS_CHANGE_REQ_SHIFT	1
+#define GRACE_STATUS_ACTIVE_SHIFT 0
+#define GRACE_STATUS_CHANGE_REQ_SHIFT 1
 
 /* The remaining bits are for the refcount */
-#define GRACE_STATUS_COUNTER_SHIFT	2
+#define GRACE_STATUS_COUNTER_SHIFT 2
 
-#define GRACE_STATUS_ACTIVE		(1U << GRACE_STATUS_ACTIVE_SHIFT)
-#define GRACE_STATUS_CHANGE_REQ		(1U << GRACE_STATUS_CHANGE_REQ_SHIFT)
-#define GRACE_STATUS_REF_INCREMENT	(1U << GRACE_STATUS_COUNTER_SHIFT)
-#define GRACE_STATUS_COUNT_MASK		((~0U) << GRACE_STATUS_COUNTER_SHIFT)
+#define GRACE_STATUS_ACTIVE (1U << GRACE_STATUS_ACTIVE_SHIFT)
+#define GRACE_STATUS_CHANGE_REQ (1U << GRACE_STATUS_CHANGE_REQ_SHIFT)
+#define GRACE_STATUS_REF_INCREMENT (1U << GRACE_STATUS_COUNTER_SHIFT)
+#define GRACE_STATUS_COUNT_MASK ((~0U) << GRACE_STATUS_COUNTER_SHIFT)
 
-static uint32_t	grace_status;
+static uint32_t grace_status;
 
 static int default_recovery_init(void)
 {
@@ -104,24 +104,20 @@ static struct nfs4_recovery_backend default_recovery_backend = {
 	.add_revoke_fh = default_add_revoke_fh,
 };
 
-
 static struct nfs4_recovery_backend *recovery_backend =
-					&default_recovery_backend;
+	&default_recovery_backend;
 int32_t reclaim_completes; /* atomic */
 
 static void nfs4_recovery_load_clids(nfs_grace_start_t *gsp);
 static void nfs_release_nlm_state(char *release_ip);
 static void nfs_release_v4_clients(char *ip);
 
-
-
-
 clid_entry_t *nfs4_add_clid_entry(char *cl_name)
 {
 	clid_entry_t *new_ent = gsh_malloc(sizeof(clid_entry_t));
 
 	glist_init(&new_ent->cl_rfh_list);
-	(void) strlcpy(new_ent->cl_name, cl_name, sizeof(new_ent->cl_name));
+	(void)strlcpy(new_ent->cl_name, cl_name, sizeof(new_ent->cl_name));
 	glist_add(&clid_list, &new_ent->cl_list);
 	++clid_count;
 	return new_ent;
@@ -140,8 +136,7 @@ void nfs4_cleanup_clid_entries(void)
 {
 	struct clid_entry *clid_entry;
 	/* when not doing a takeover, start with an empty list */
-	while ((clid_entry = glist_first_entry(&clid_list,
-					       struct clid_entry,
+	while ((clid_entry = glist_first_entry(&clid_list, struct clid_entry,
 					       cl_list)) != NULL) {
 		glist_del(&clid_entry->cl_list);
 		gsh_free(clid_entry);
@@ -152,13 +147,22 @@ void nfs4_cleanup_clid_entries(void)
 }
 
 /*
- * Check the current status of the grace period against what the caller needs.
+ * If Sticky_garce enabled, Check the current status of the grace
+ * period against what the caller needs.
  * If it's different then return false without taking a reference. If a change
  * has been requested, then we also don't want to give out a reference.
+ * Else return true if in grace period or return false if not.
  */
 bool nfs_get_grace_status(bool want_grace)
 {
 	uint32_t cur, pro, old;
+	/* check if sticky grace is disabled,
+	 * if we are in grace period and return*/
+	if (!nfs_param.nfsv4_param.sticky_grace) {
+		cur = atomic_fetch_uint32_t(&grace_status);
+
+		return want_grace == (bool)(cur & GRACE_STATUS_ACTIVE);
+	}
 
 	old = atomic_fetch_uint32_t(&grace_status);
 	do {
@@ -180,13 +184,19 @@ bool nfs_get_grace_status(bool want_grace)
 }
 
 /*
- * Put grace status. If the refcount goes to zero, and a change was requested,
+ * Put grace status function is a no-op without sticky_grace.
+ * Else if sticky_grace enabled, If the refcount goes to zero,
+ * and a change was requested,
  * then wake the reaper thread to do its thing.
  */
 void nfs_put_grace_status(void)
 {
 	uint32_t cur;
 
+	/* check if sticky grace is disabled, to skip decrementing ref count*/
+	if (!nfs_param.nfsv4_param.sticky_grace)
+		return; /* no sticky grace mode, no decrementing ref count*/
+
 	cur = __sync_sub_and_fetch(&grace_status, GRACE_STATUS_REF_INCREMENT);
 	if (cur & GRACE_STATUS_CHANGE_REQ &&
 	    !(cur >> GRACE_STATUS_COUNTER_SHIFT)) {
@@ -198,10 +208,9 @@ void nfs_put_grace_status(void)
 /**
  * Lift the grace period if it's still active.
  */
-static void
-nfs_lift_grace_locked(void)
+static void nfs_lift_grace_locked(void)
 {
-	uint32_t cur;
+	uint32_t __attribute__((unused)) cur;
 
 	/*
 	 * Caller must hold grace_mutex. Only the thread that actually sets
@@ -212,8 +221,10 @@ nfs_lift_grace_locked(void)
 		__sync_synchronize();
 		/* Now change the actual status */
 		cur = __sync_and_and_fetch(&grace_status,
-			~(GRACE_STATUS_ACTIVE|GRACE_STATUS_CHANGE_REQ));
-		assert(!(cur & GRACE_STATUS_COUNT_MASK));
+					   ~(GRACE_STATUS_ACTIVE |
+					     GRACE_STATUS_CHANGE_REQ));
+		assert(!nfs_param.nfsv4_param.sticky_grace ||
+		       !(cur & GRACE_STATUS_COUNT_MASK));
 		LogEvent(COMPONENT_STATE, "NFS Server Now NOT IN GRACE");
 	}
 }
@@ -271,7 +282,7 @@ int nfs_start_grace(nfs_grace_start_t *gsp)
 	ret = clock_gettime(CLOCK_MONOTONIC, &current_grace);
 	if (ret != 0) {
 		LogCrit(COMPONENT_MAIN, "Failed to get timestamp");
-		assert(0);	/* if this is broken, we are toast so die */
+		assert(0); /* if this is broken, we are toast so die */
 	}
 
 	cur = atomic_fetch_uint32_t(&grace_status);
@@ -284,11 +295,14 @@ int nfs_start_grace(nfs_grace_start_t *gsp)
 			break;
 
 		/*
-		 * Are there outstanding refs? If so, then set the change req
+		 * Are there outstanding
+		 * refs(check only if sticky grace is enabled)?
+		 * If so, then set the change req
 		 * flag and nothing else. If not, then clear the change req
 		 * flag and flip the active bit.
 		 */
-		if (old & GRACE_STATUS_COUNT_MASK) {
+		if ((old & GRACE_STATUS_COUNT_MASK) &
+		    nfs_param.nfsv4_param.sticky_grace) {
 			pro = old | GRACE_STATUS_CHANGE_REQ;
 		} else {
 			pro = old | GRACE_STATUS_ACTIVE;
@@ -302,11 +316,13 @@ int nfs_start_grace(nfs_grace_start_t *gsp)
 	} while (cur != old);
 
 	/*
-	 * If we were not in a grace period before and there were still
-	 * references outstanding, then we can't do anything else.
+	 * If sticky_garce is enabled and we were not in a grace period
+	 * before and there were still references outstanding,
+	 * then we can't do anything else.
 	 * Fail with -EAGAIN so that caller can retry if needed.
 	 */
-	if (!was_grace && (old & GRACE_STATUS_COUNT_MASK)) {
+	if (!was_grace && (old & GRACE_STATUS_COUNT_MASK) &&
+	    nfs_param.nfsv4_param.sticky_grace) {
 		LogEvent(COMPONENT_STATE,
 			 "Unable to start grace, grace status 0x%x",
 			 grace_status);
@@ -317,11 +333,11 @@ int nfs_start_grace(nfs_grace_start_t *gsp)
 	__sync_synchronize();
 
 	if ((int)nfs_param.nfsv4_param.grace_period <
-		(int)nfs_param.nfsv4_param.lease_lifetime) {
+	    (int)nfs_param.nfsv4_param.lease_lifetime) {
 		LogWarn(COMPONENT_STATE,
-		 "NFS Server GRACE duration should at least match LEASE period. Current configured values are GRACE(%d), LEASE(%d)",
-		 (int)nfs_param.nfsv4_param.grace_period,
-		 (int)nfs_param.nfsv4_param.lease_lifetime);
+			"NFS Server GRACE duration should at least match LEASE period. Current configured values are GRACE(%d), LEASE(%d)",
+			(int)nfs_param.nfsv4_param.grace_period,
+			(int)nfs_param.nfsv4_param.lease_lifetime);
 	}
 
 	LogEvent(COMPONENT_STATE, "NFS Server Now IN GRACE, duration %d",
@@ -371,7 +387,7 @@ int nfs_start_grace(nfs_grace_start_t *gsp)
 		}
 	}
 	LogEvent(COMPONENT_STATE,
-		"grace reload client info completed from backend");
+		 "grace reload client info completed from backend");
 out:
 	PTHREAD_MUTEX_unlock(&grace_mutex);
 	return ret;
@@ -441,8 +457,10 @@ bool nfs_grace_is_member(void)
 int nfs_recovery_get_nodeid(char **pnodeid)
 {
 	int rc;
-	long maxlen;
+	size_t maxlen;
+	size_t copylen;
 	char *nodeid = NULL;
+	char *hostname = NULL;
 
 	if (recovery_backend->get_nodeid) {
 		rc = recovery_backend->get_nodeid(&nodeid);
@@ -462,17 +480,27 @@ int nfs_recovery_get_nodeid(char **pnodeid)
 	 * Either the backend doesn't support get_nodeid or it handed back a
 	 * NULL pointer. Just use hostname.
 	 */
-	maxlen = sysconf(_SC_HOST_NAME_MAX);
-	nodeid = gsh_malloc(maxlen);
-	rc = gsh_gethostname(nodeid, maxlen,
-			nfs_param.core_param.enable_AUTHSTATS);
+	hostname = gsh_malloc(MAXNAMLEN + 1);
+	rc = gsh_gethostname(hostname, MAXNAMLEN + 1,
+			     nfs_param.core_param.enable_AUTHSTATS);
 	if (rc != 0) {
 		LogEvent(COMPONENT_CLIENTID, "gethostname failed: %d", errno);
 		rc = -errno;
-		gsh_free(nodeid);
-	} else {
-		*pnodeid = nodeid;
+		gsh_free(hostname);
+		return rc;
 	}
+
+	maxlen = sysconf(_SC_HOST_NAME_MAX);
+	copylen = strlen(hostname);
+	if (copylen > maxlen)
+		copylen = maxlen;
+	nodeid = gsh_malloc(copylen + 1);
+	memcpy(nodeid, hostname, copylen);
+	nodeid[copylen] = '\0';
+
+	*pnodeid = nodeid;
+	gsh_free(hostname);
+
 	return rc;
 }
 
@@ -492,8 +520,10 @@ void nfs_try_lift_grace(void)
 	 */
 	PTHREAD_MUTEX_lock(&grace_mutex);
 	rc_count = atomic_fetch_int32_t(&reclaim_completes);
-	LogEvent(COMPONENT_STATE, "check grace:reclaim complete(%d)"
-		" clid count(%d)", rc_count, clid_count);
+	LogEvent(COMPONENT_STATE,
+		 "check grace:reclaim complete(%d)"
+		 " clid count(%d)",
+		 rc_count, clid_count);
 #ifdef _USE_NLM
 	if (!nfs_param.core_param.enable_NLM)
 #endif
@@ -528,30 +558,40 @@ void nfs_try_lift_grace(void)
 	 * Clustered backends may need extra checks before they can do so. If
 	 * the backend does not implement a try_lift_grace operation, then we
 	 * assume there are no external conditions and that it's always ok.
+	 *
+	 * If sticky grace is disabled, no additional checks or status updates
+	 * are performed; the grace period is lifted relying
+	 * only on backend-specific checks (if any).
 	 */
 	if (!in_grace) {
 		cur = atomic_fetch_uint32_t(&grace_status);
-		do {
-			old = cur;
+		/* no extra check if sticky grace is disabled.*/
+		if (nfs_param.nfsv4_param.sticky_grace) {
+			do {
+				old = cur;
 
-			/* Are we already done? Exit if so */
-			if (!(cur & GRACE_STATUS_ACTIVE)) {
-				PTHREAD_MUTEX_unlock(&grace_mutex);
-				return;
-			}
+				/* Are we already done? Exit if so */
+				if (!(cur & GRACE_STATUS_ACTIVE)) {
+					PTHREAD_MUTEX_unlock(&grace_mutex);
+					return;
+				}
 
-			/* Record that a change has now been requested */
-			pro = old | GRACE_STATUS_CHANGE_REQ;
-			if (pro == old)
-				break;
-			cur = __sync_val_compare_and_swap(&grace_status,
-							  old, pro);
-		} while (cur != old);
+				/* Record that a change
+				 * has now been requested */
+				pro = old | GRACE_STATUS_CHANGE_REQ;
+				if (pro == old)
+					break;
+				cur = __sync_val_compare_and_swap(&grace_status,
+								  old, pro);
+			} while (cur != old);
 
-		/* Otherwise, go ahead and lift if we can */
-		if (!(old & GRACE_STATUS_COUNT_MASK) &&
-		    (!recovery_backend->try_lift_grace ||
-		     recovery_backend->try_lift_grace()))
+			/* Otherwise, go ahead and lift if we can */
+			if (!(old & GRACE_STATUS_COUNT_MASK) &&
+			    (!recovery_backend->try_lift_grace ||
+			     recovery_backend->try_lift_grace()))
+				nfs_lift_grace_locked();
+		} else if (!recovery_backend->try_lift_grace ||
+			   recovery_backend->try_lift_grace())
 			nfs_lift_grace_locked();
 	}
 	PTHREAD_MUTEX_unlock(&grace_mutex);
@@ -568,11 +608,11 @@ void nfs_wait_for_grace_enforcement(void)
 	pthread_mutex_lock(&enforcing_mutex);
 	nfs_try_lift_grace();
 	while (nfs_in_grace() && !nfs_grace_enforcing()) {
-		struct timespec	timeo = { .tv_sec = time(NULL) + 5,
+		struct timespec timeo = { .tv_sec = time(NULL) + 5,
 					  .tv_nsec = 0 };
 
 		pthread_cond_timedwait(&enforcing_cond, &enforcing_mutex,
-						&timeo);
+				       &timeo);
 
 		pthread_mutex_unlock(&enforcing_mutex);
 		nfs_start_grace(&gsp);
@@ -595,10 +635,8 @@ static pthread_mutex_t norefs_mutex;
 void nfs_wait_for_grace_norefs(void)
 {
 	pthread_mutex_lock(&norefs_mutex);
-	struct timespec	timeo = { .tv_sec = time(NULL) + 5,
-				  .tv_nsec = 0 };
-	pthread_cond_timedwait(&norefs_cond, &norefs_mutex,
-			       &timeo);
+	struct timespec timeo = { .tv_sec = time(NULL) + 5, .tv_nsec = 0 };
+	pthread_cond_timedwait(&norefs_cond, &norefs_mutex, &timeo);
 	pthread_mutex_unlock(&norefs_mutex);
 }
 
@@ -641,13 +679,11 @@ static bool check_clid(nfs_client_id_t *clientid, clid_entry_t *clid_ent)
 {
 	bool ret = false;
 
-
 	LogDebug(COMPONENT_CLIENTID, "compare %s to %s",
 		 clientid->cid_recov_tag, clid_ent->cl_name);
 
 	if (clientid->cid_recov_tag &&
-	    !strncmp(clientid->cid_recov_tag,
-		     clid_ent->cl_name, PATH_MAX))
+	    !strncmp(clientid->cid_recov_tag, clid_ent->cl_name, PATH_MAX))
 		ret = true;
 
 	return ret;
@@ -660,7 +696,7 @@ static bool check_clid(nfs_client_id_t *clientid, clid_entry_t *clid_ent)
  *
  * @param[in] clientid Client record
  */
-void  nfs4_chk_clid_impl(nfs_client_id_t *clientid, clid_entry_t **clid_ent_arg)
+void nfs4_chk_clid_impl(nfs_client_id_t *clientid, clid_entry_t **clid_ent_arg)
 {
 	struct glist_head *node;
 	clid_entry_t *clid_ent;
@@ -678,13 +714,14 @@ void  nfs4_chk_clid_impl(nfs_client_id_t *clientid, clid_entry_t **clid_ent_arg)
 	 * find it, mark it to allow reclaims.
 	 */
 	PTHREAD_MUTEX_lock(&clientid->cid_mutex);
-	glist_for_each(node, &clid_list) {
+	glist_for_each(node, &clid_list)
+	{
 		clid_ent = glist_entry(node, clid_entry_t, cl_list);
 		if (check_clid(clientid, clid_ent)) {
 			if (isDebug(COMPONENT_CLIENTID)) {
 				char str[LOG_BUFF_LEN] = "\0";
-				struct display_buffer dspbuf = {
-					sizeof(str), str, str};
+				struct display_buffer dspbuf = { sizeof(str),
+								 str, str };
 
 				display_client_id_rec(&dspbuf, clientid);
 
@@ -700,7 +737,7 @@ void  nfs4_chk_clid_impl(nfs_client_id_t *clientid, clid_entry_t **clid_ent_arg)
 	PTHREAD_MUTEX_unlock(&clientid->cid_mutex);
 }
 
-void  nfs4_chk_clid(nfs_client_id_t *clientid)
+void nfs4_chk_clid(nfs_client_id_t *clientid)
 {
 	clid_entry_t *dummy_clid_ent;
 
@@ -721,7 +758,7 @@ static void nfs4_recovery_load_clids(nfs_grace_start_t *gsp)
 	LogDebug(COMPONENT_STATE, "Load recovery cli %p", gsp);
 
 	recovery_backend->recovery_read_clids(gsp, nfs4_add_clid_entry,
-						nfs4_add_rfh_entry);
+					      nfs4_add_rfh_entry);
 }
 
 #ifdef USE_RADOS_RECOV
@@ -732,7 +769,9 @@ static struct {
 	void (*cluster_init)(struct nfs4_recovery_backend **);
 	int (*load_config_from_parse)(config_file_t,
 				      struct config_error_type *);
-} rados = { NULL,};
+} rados = {
+	NULL,
+};
 
 static int load_rados_recov(void)
 {
@@ -746,10 +785,10 @@ static int load_rados_recov(void)
 	if (rados.dl) {
 		rados.kv_init = dlsym(rados.dl, "rados_kv_backend_init");
 		rados.ng_init = dlsym(rados.dl, "rados_ng_backend_init");
-		rados.cluster_init = dlsym(rados.dl,
-					   "rados_cluster_backend_init");
-		rados.load_config_from_parse = dlsym(rados.dl,
-					   "rados_load_config_from_parse");
+		rados.cluster_init =
+			dlsym(rados.dl, "rados_cluster_backend_init");
+		rados.load_config_from_parse =
+			dlsym(rados.dl, "rados_load_config_from_parse");
 
 		if (!rados.kv_init || !rados.ng_init || !rados.cluster_init ||
 		    !rados.load_config_from_parse) {
@@ -838,7 +877,7 @@ void nfs4_recovery_shutdown(void)
 		recovery_backend->recovery_shutdown();
 #ifdef USE_RADOS_RECOV
 	if (rados.dl)
-		(void) dlclose(rados.dl);
+		(void)dlclose(rados.dl);
 	rados.dl = NULL;
 #endif
 }
@@ -891,7 +930,7 @@ bool nfs4_check_deleg_reclaim(nfs_client_id_t *clid, nfs_fh4 *fhandle)
 	struct glist_head *node;
 	rdel_fh_t *rfh_entry;
 	clid_entry_t *clid_ent;
-	int b64ret;
+	int __attribute__((unused)) b64ret;
 	bool retval = true;
 
 	/* Convert nfs_fh4_val into base64 encoded string */
@@ -902,13 +941,14 @@ bool nfs4_check_deleg_reclaim(nfs_client_id_t *clid, nfs_fh4 *fhandle)
 	PTHREAD_MUTEX_lock(&grace_mutex);
 	nfs4_chk_clid_impl(clid, &clid_ent);
 	if (clid_ent) {
-		glist_for_each(node, &clid_ent->cl_rfh_list) {
+		glist_for_each(node, &clid_ent->cl_rfh_list)
+		{
 			rfh_entry = glist_entry(node, rdel_fh_t, rdfh_list);
 			assert(rfh_entry != NULL);
 			if (!strcmp(rhdlstr, rfh_entry->rdfh_handle_str)) {
 				LogFullDebug(COMPONENT_CLIENTID,
-					"Can't reclaim revoked fh:%s",
-					rfh_entry->rdfh_handle_str);
+					     "Can't reclaim revoked fh:%s",
+					     rfh_entry->rdfh_handle_str);
 				retval = false;
 				break;
 			}
@@ -932,9 +972,8 @@ static void nlm_releasecall(struct fridgethr_context *ctx)
 	nsm_cp = ctx->arg;
 	err = state_nlm_notify(nsm_cp, false, 0);
 	if (err != STATE_SUCCESS)
-		LogDebug(COMPONENT_STATE,
-			"state_nlm_notify failed with %d",
-			err);
+		LogDebug(COMPONENT_STATE, "state_nlm_notify failed with %d",
+			 err);
 	dec_nsm_client_ref(nsm_cp);
 }
 #endif /* _USE_NLM */
@@ -948,7 +987,7 @@ void extractv4(char *ipv6, char *ipv4, size_t size)
 	while (token != NULL) {
 		/* IPv4 delimiter is '.' */
 		if (strchr(token, '.') != NULL) {
-			(void) strlcpy(ipv4, token, size);
+			(void)strlcpy(ipv4, token, size);
 			return;
 		}
 		token = strtok_r(NULL, delim, &saveptr);
@@ -1013,19 +1052,19 @@ static void nfs_release_nlm_state(char *release_ip)
 		PTHREAD_RWLOCK_wrlock(&ht->partitions[i].ht_lock);
 		head_rbt = &ht->partitions[i].rbt;
 		/* go through all entries in the red-black-tree */
-		RBT_LOOP(head_rbt, pn) {
+		RBT_LOOP(head_rbt, pn)
+		{
 			pdata = RBT_OPAQ(pn);
-			nlm_cp = (state_nlm_client_t *) pdata->val.addr;
+			nlm_cp = (state_nlm_client_t *)pdata->val.addr;
 
-			if (sprint_sockip(&nlm_cp->slc_server_addr,
-					  serverip, sizeof(serverip)) &&
+			if (sprint_sockip(&nlm_cp->slc_server_addr, serverip,
+					  sizeof(serverip)) &&
 			    ip_str_match(release_ip, serverip)) {
 				nsm_cp = nlm_cp->slc_nsm_client;
 				inc_nsm_client_ref(nsm_cp);
 				state_status = fridgethr_submit(
-						state_async_fridge,
-						nlm_releasecall,
-						nsm_cp);
+					state_async_fridge, nlm_releasecall,
+					nsm_cp);
 				if (state_status != STATE_SUCCESS) {
 					dec_nsm_client_ref(nsm_cp);
 					LogCrit(COMPONENT_STATE,
@@ -1045,10 +1084,10 @@ static int ip_match(char *ip, nfs_client_id_t *cid)
 	char *value = cid->cid_client_record->cr_client_val;
 	int len = cid->cid_client_record->cr_client_val_len;
 
-	LogDebug(COMPONENT_STATE, "NFS Server V4 match ip %s with (%.*s)",
-		 ip, len, value);
+	LogDebug(COMPONENT_STATE, "NFS Server V4 match ip %s with (%.*s)", ip,
+		 len, value);
 
-	if (strlen(ip) == 0)	/* No IP all are matching */
+	if (strlen(ip) == 0) /* No IP all are matching */
 		return 1;
 
 	haystack = alloca(len + 1);
@@ -1057,7 +1096,7 @@ static int ip_match(char *ip, nfs_client_id_t *cid)
 	if (strstr(haystack, ip) != NULL)
 		return 1;
 
-	return 0;		/* no match */
+	return 0; /* no match */
 }
 
 /*
@@ -1085,13 +1124,14 @@ restart:
 		PTHREAD_RWLOCK_wrlock(&ht->partitions[i].ht_lock);
 
 		/* go through all entries in the red-black-tree */
-		RBT_LOOP(head_rbt, pn) {
+		RBT_LOOP(head_rbt, pn)
+		{
 			pdata = RBT_OPAQ(pn);
 
-			cp = (nfs_client_id_t *) pdata->val.addr;
+			cp = (nfs_client_id_t *)pdata->val.addr;
 			PTHREAD_MUTEX_lock(&cp->cid_mutex);
-			if ((cp->cid_confirmed == CONFIRMED_CLIENT_ID)
-			     && ip_match(ip, cp)) {
+			if ((cp->cid_confirmed == CONFIRMED_CLIENT_ID) &&
+			    ip_match(ip, cp)) {
 				inc_client_id_ref(cp);
 
 				/* client_record is always non-NULL. */
@@ -1100,12 +1140,12 @@ restart:
 				PTHREAD_MUTEX_unlock(&cp->cid_mutex);
 
 				PTHREAD_RWLOCK_unlock(
-						&ht->partitions[i].ht_lock);
+					&ht->partitions[i].ht_lock);
 
 				/* nfs_client_id_expire requires cr_mutex */
 				PTHREAD_MUTEX_lock(&recp->cr_mutex);
 
-				nfs_client_id_expire(cp, true);
+				nfs_client_id_expire(cp, true, true);
 
 				PTHREAD_MUTEX_unlock(&recp->cr_mutex);
 
@@ -1168,7 +1208,7 @@ int load_recovery_param_from_conf(config_file_t parse_tree,
 			LogCrit(COMPONENT_CLIENTID,
 				"Failed to load Backend %s. Please install the appropriate package",
 				recovery_backend_str(
-				       nfs_param.nfsv4_param.recovery_backend));
+					nfs_param.nfsv4_param.recovery_backend));
 			return -1;
 		}
 
