@@ -47,13 +47,11 @@ unsigned int v4_old_dir_len;
  *
  */
 static int fs_convert_opaque_value_max_for_dir(struct display_buffer *dspbuf,
-					       void *value,
-					       int len,
-					       int max)
+					       void *value, int len, int max)
 {
 	unsigned int i = 0;
-	int          b_left = display_start(dspbuf);
-	int          cpy = len;
+	int b_left = display_start(dspbuf);
+	int cpy = len;
 
 	if (b_left <= 0)
 		return 0;
@@ -103,8 +101,10 @@ static void fs_create_clid_name(nfs_client_id_t *clientid)
 {
 	nfs_client_record_t *cl_rec = clientid->cid_client_record;
 	const char *str_client_addr = "(unknown)";
-	char cidstr[PATH_MAX] = { 0, };
-	struct display_buffer dspbuf = {sizeof(cidstr), cidstr, cidstr};
+	char cidstr[PATH_MAX] = {
+		0,
+	};
+	struct display_buffer dspbuf = { sizeof(cidstr), cidstr, cidstr };
 	char cidstr_lenx[5];
 	int total_size, cidstr_lenx_len, cidstr_len, str_client_addr_len;
 
@@ -112,8 +112,7 @@ static void fs_create_clid_name(nfs_client_id_t *clientid)
 	if (clientid->gsh_client != NULL)
 		str_client_addr = clientid->gsh_client->hostaddr_str;
 
-	if (fs_convert_opaque_value_max_for_dir(&dspbuf,
-						cl_rec->cr_client_val,
+	if (fs_convert_opaque_value_max_for_dir(&dspbuf, cl_rec->cr_client_val,
 						cl_rec->cr_client_val_len,
 						PATH_MAX) > 0) {
 		cidstr_len = strlen(cidstr);
@@ -135,16 +134,16 @@ static void fs_create_clid_name(nfs_client_id_t *clientid)
 				 cidstr_lenx_len);
 		}
 
-		total_size = cidstr_len + str_client_addr_len + 5 +
-			     cidstr_lenx_len;
+		total_size =
+			cidstr_len + str_client_addr_len + 5 + cidstr_lenx_len;
 
 		/* hold both long form clientid and IP */
 		clientid->cid_recov_tag = gsh_malloc(total_size);
 
 		/* Can't overrun and shouldn't return EOVERFLOW or EINVAL */
-		(void) snprintf(clientid->cid_recov_tag, total_size,
-				"%s-(%s:%s)",
-				str_client_addr, cidstr_lenx, cidstr);
+		(void)snprintf(clientid->cid_recov_tag, total_size,
+			       "%s-(%s:%s)", str_client_addr, cidstr_lenx,
+			       cidstr);
 	}
 
 	LogDebug(COMPONENT_CLIENTID, "Created client name [%s]",
@@ -171,10 +170,11 @@ int fs_create_recov_dir(void)
 
 	err = mkdir(nfs_param.nfsv4_param.recov_root, 0755);
 	if (err == -1 && errno != EEXIST) {
-		LogEvent(COMPONENT_CLIENTID,
-			 "Failed to create v4 recovery dir (%s), errno: %s (%d)",
-			 nfs_param.nfsv4_param.recov_root,
-			 strerror(errno), errno);
+		LogEvent(
+			COMPONENT_CLIENTID,
+			"Failed to create v4 recovery dir (%s), errno: %s (%d)",
+			nfs_param.nfsv4_param.recov_root, strerror(errno),
+			errno);
 	}
 
 	root_len = strlen(nfs_param.nfsv4_param.recov_root);
@@ -193,8 +193,8 @@ int fs_create_recov_dir(void)
 
 	memcpy(v4_recov_dir, nfs_param.nfsv4_param.recov_root, root_len);
 	v4_recov_dir[root_len] = '/';
-	memcpy(v4_recov_dir + 1 + root_len,
-	       nfs_param.nfsv4_param.recov_dir, dir_len + 1);
+	memcpy(v4_recov_dir + 1 + root_len, nfs_param.nfsv4_param.recov_dir,
+	       dir_len + 1);
 	dir_len = 1 + root_len + dir_len;
 
 	LogDebug(COMPONENT_CLIENTID, "v4_recov_dir=%s", v4_recov_dir);
@@ -222,8 +222,8 @@ int fs_create_recov_dir(void)
 
 	memcpy(v4_old_dir, nfs_param.nfsv4_param.recov_root, root_len);
 	v4_old_dir[root_len] = '/';
-	memcpy(v4_old_dir + 1 + root_len,
-	       nfs_param.nfsv4_param.recov_old_dir, old_len + 1);
+	memcpy(v4_old_dir + 1 + root_len, nfs_param.nfsv4_param.recov_old_dir,
+	       old_len + 1);
 	old_len = 1 + root_len + old_len;
 
 	LogDebug(COMPONENT_CLIENTID, "v4_old_dir=%s", v4_old_dir);
@@ -250,25 +250,26 @@ int fs_create_recov_dir(void)
 		err = mkdir(v4_recov_dir, 0755);
 
 		if (err == -1 && errno != EEXIST) {
-			LogEvent(COMPONENT_CLIENTID,
-				 "Failed to create v4 recovery dir(%s), errno: %s (%d)",
-				 v4_recov_dir, strerror(errno), errno);
+			LogEvent(
+				COMPONENT_CLIENTID,
+				"Failed to create v4 recovery dir(%s), errno: %s (%d)",
+				v4_recov_dir, strerror(errno), errno);
 		}
 
 		err = mkdir(v4_old_dir, 0755);
 
 		if (err == -1 && errno != EEXIST) {
-			LogEvent(COMPONENT_CLIENTID,
-				 "Failed to create v4 recovery dir(%s), errno: %s (%d)",
-				 v4_old_dir, strerror(errno), errno);
+			LogEvent(
+				COMPONENT_CLIENTID,
+				"Failed to create v4 recovery dir(%s), errno: %s (%d)",
+				v4_old_dir, strerror(errno), errno);
 		}
 	}
 
-
-	LogInfo(COMPONENT_CLIENTID,
-		"NFSv4 Recovery Directory %s", v4_recov_dir);
-	LogInfo(COMPONENT_CLIENTID,
-		"NFSv4 Recovery Directory (old) %s", v4_old_dir);
+	LogInfo(COMPONENT_CLIENTID, "NFSv4 Recovery Directory %s",
+		v4_recov_dir);
+	LogInfo(COMPONENT_CLIENTID, "NFSv4 Recovery Directory (old) %s",
+		v4_old_dir);
 
 	return 0;
 }
@@ -276,7 +277,7 @@ int fs_create_recov_dir(void)
 void fs_add_clid(nfs_client_id_t *clientid)
 {
 	int err = 0;
-	char path[PATH_MAX] = {0};
+	char path[PATH_MAX] = { 0 };
 	int length, position;
 	int pathpos = strlen(v4_recov_dir);
 
@@ -305,16 +306,14 @@ void fs_add_clid(nfs_client_id_t *clientid)
 
 		if (len <= NAME_MAX) {
 			memcpy(path + pathpos,
-			       clientid->cid_recov_tag + position,
-			       len + 1);
+			       clientid->cid_recov_tag + position, len + 1);
 			err = mkdir(path, 0700);
 			break;
 		}
 
 		/* if (remaining) clientid is longer than 255, */
 		/* get the next 255 bytes and create a subdir */
-		memcpy(path + pathpos,
-		       clientid->cid_recov_tag + position,
+		memcpy(path + pathpos, clientid->cid_recov_tag + position,
 		       NAME_MAX);
 		pathpos += NAME_MAX;
 		path[pathpos] = '\0';
@@ -325,9 +324,10 @@ void fs_add_clid(nfs_client_id_t *clientid)
 	}
 
 	if (err == -1 && errno != EEXIST) {
-		LogEvent(COMPONENT_CLIENTID,
-			 "Failed to create client in recovery dir (%s), errno: %s (%d)",
-			 path, strerror(errno), errno);
+		LogEvent(
+			COMPONENT_CLIENTID,
+			"Failed to create client in recovery dir (%s), errno: %s (%d)",
+			path, strerror(errno), errno);
 	} else {
 		LogDebug(COMPONENT_CLIENTID, "Created client dir [%s]", path);
 	}
@@ -348,41 +348,37 @@ static void fs_rm_revoked_handles(char *path)
 	dp = opendir(path);
 	if (dp == NULL) {
 		LogEvent(COMPONENT_CLIENTID, "opendir %s failed errno: %s (%d)",
-			path, strerror(errno), errno);
+			 path, strerror(errno), errno);
 		return;
 	}
 	for (dentp = readdir(dp); dentp != NULL; dentp = readdir(dp)) {
 		int rc;
 
 		if (!strcmp(dentp->d_name, ".") ||
-				!strcmp(dentp->d_name, "..") ||
-				dentp->d_name[0] != '\x1') {
+		    !strcmp(dentp->d_name, "..") || dentp->d_name[0] != '\x1') {
 			continue;
 		}
 
-		rc = snprintf(del_path, sizeof(del_path), "%s/%s",
-			      path, dentp->d_name);
+		rc = snprintf(del_path, sizeof(del_path), "%s/%s", path,
+			      dentp->d_name);
 
 		if (unlikely(rc >= sizeof(del_path))) {
-			LogCrit(COMPONENT_CLIENTID,
-				"Path %s/%s too long",
-				path, dentp->d_name);
+			LogCrit(COMPONENT_CLIENTID, "Path %s/%s too long", path,
+				dentp->d_name);
 		} else if (unlikely(rc < 0)) {
 			LogCrit(COMPONENT_CLIENTID,
 				"Unexpected return from snprintf %d error %s (%d)",
 				rc, strerror(errno), errno);
 		} else if (unlink(del_path) < 0) {
 			LogEvent(COMPONENT_CLIENTID,
-				 "unlink of %s failed errno: %s (%d)",
-				 del_path,
+				 "unlink of %s failed errno: %s (%d)", del_path,
 				 strerror(errno), errno);
 		}
 	}
 	(void)closedir(dp);
 }
 
-static void fs_rm_clid_impl(int position,
-			    char *recov_dir, int len,
+static void fs_rm_clid_impl(int position, char *recov_dir, int len,
 			    char *parent_path, int parent_len)
 {
 	int err;
@@ -417,15 +413,15 @@ static void fs_rm_clid_impl(int position,
 	/* recursively remove the directory hirerchy which represent the
 	 *clientid
 	 */
-	fs_rm_clid_impl(position + segment_len,
-			recov_dir, len,
-			path, total_len - 1);
+	fs_rm_clid_impl(position + segment_len, recov_dir, len, path,
+			total_len - 1);
 
 	err = rmdir(path);
 	if (err == -1) {
-		LogEvent(COMPONENT_CLIENTID,
-			 "Failed to remove client recovery dir (%s), errno: %s (%d)",
-			 path, strerror(errno), errno);
+		LogEvent(
+			COMPONENT_CLIENTID,
+			"Failed to remove client recovery dir (%s), errno: %s (%d)",
+			path, strerror(errno), errno);
 	} else {
 		LogDebug(COMPONENT_CLIENTID, "Removed client dir (%s)", path);
 	}
@@ -440,9 +436,8 @@ void fs_rm_clid(nfs_client_id_t *clientid)
 		return;
 
 	clientid->cid_recov_tag = NULL;
-	fs_rm_clid_impl(0,
-			recov_dir, strlen(recov_dir),
-			v4_recov_dir, v4_recov_dir_len);
+	fs_rm_clid_impl(0, recov_dir, strlen(recov_dir), v4_recov_dir,
+			v4_recov_dir_len);
 	gsh_free(recov_dir);
 }
 
@@ -461,10 +456,8 @@ void fs_rm_clid(nfs_client_id_t *clientid)
  * @param[in] Target dir to copy.
  * @param[in] del Delete after populating
  */
-static void fs_cp_pop_revoked_delegs(clid_entry_t *clid_ent,
-				     char *path,
-				     char *tgtdir,
-				     bool del,
+static void fs_cp_pop_revoked_delegs(clid_entry_t *clid_ent, char *path,
+				     char *tgtdir, bool del,
 				     add_rfh_entry_hook add_rfh_entry)
 {
 	struct dirent *dentp;
@@ -475,7 +468,7 @@ static void fs_cp_pop_revoked_delegs(clid_entry_t *clid_ent,
 	dp = opendir(path);
 	if (dp == NULL) {
 		LogEvent(COMPONENT_CLIENTID, "opendir %s failed errno: %s (%d)",
-			path, strerror(errno), errno);
+			 path, strerror(errno), errno);
 		return;
 	}
 
@@ -485,7 +478,8 @@ static void fs_cp_pop_revoked_delegs(clid_entry_t *clid_ent,
 		/* All the revoked filehandles stored with \x1 prefix */
 		if (dentp->d_name[0] != '\x1') {
 			/* Something wrong; it should not happen */
-			LogMidDebug(COMPONENT_CLIENTID,
+			LogMidDebug(
+				COMPONENT_CLIENTID,
 				"%s showed up along with revoked FHs. Skipping",
 				dentp->d_name);
 			continue;
@@ -495,13 +489,13 @@ static void fs_cp_pop_revoked_delegs(clid_entry_t *clid_ent,
 			char lopath[PATH_MAX];
 			int fd, rc;
 
-			rc = snprintf(lopath, sizeof(lopath), "%s/%s",
-				      tgtdir, dentp->d_name);
+			rc = snprintf(lopath, sizeof(lopath), "%s/%s", tgtdir,
+				      dentp->d_name);
 
 			if (unlikely(rc >= sizeof(lopath))) {
 				LogCrit(COMPONENT_CLIENTID,
-					"Path %s/%s too long",
-					 tgtdir, dentp->d_name);
+					"Path %s/%s too long", tgtdir,
+					dentp->d_name);
 			} else if (unlikely(rc < 0)) {
 				LogCrit(COMPONENT_CLIENTID,
 					"Unexpected return from snprintf %d error %s (%d)",
@@ -509,7 +503,8 @@ static void fs_cp_pop_revoked_delegs(clid_entry_t *clid_ent,
 			} else {
 				fd = creat(lopath, 0700);
 				if (fd < 0) {
-					LogEvent(COMPONENT_CLIENTID,
+					LogEvent(
+						COMPONENT_CLIENTID,
 						"Failed to copy revoked handle file %s to %s errno: %s(%d)",
 						dentp->d_name, tgtdir,
 						strerror(errno), errno);
@@ -522,9 +517,8 @@ static void fs_cp_pop_revoked_delegs(clid_entry_t *clid_ent,
 		/* Ignore the beginning \x1 and copy the rest (file handle) */
 		new_ent = add_rfh_entry(clid_ent, dentp->d_name + 1);
 
-		LogFullDebug(COMPONENT_CLIENTID,
-			"revoked handle: %s",
-			new_ent->rdfh_handle_str);
+		LogFullDebug(COMPONENT_CLIENTID, "revoked handle: %s",
+			     new_ent->rdfh_handle_str);
 
 		/* Since the handle is loaded into memory, go ahead and
 		 * delete it from the stable storage.
@@ -533,13 +527,13 @@ static void fs_cp_pop_revoked_delegs(clid_entry_t *clid_ent,
 			char del_path[PATH_MAX];
 			int rc;
 
-			rc = snprintf(del_path, sizeof(del_path), "%s/%s",
-				      path, dentp->d_name);
+			rc = snprintf(del_path, sizeof(del_path), "%s/%s", path,
+				      dentp->d_name);
 
 			if (unlikely(rc >= sizeof(del_path))) {
 				LogCrit(COMPONENT_CLIENTID,
-					"Path %s/%s too long",
-					 path, dentp->d_name);
+					"Path %s/%s too long", path,
+					dentp->d_name);
 			} else if (unlikely(rc < 0)) {
 				LogCrit(COMPONENT_CLIENTID,
 					"Unexpected return from snprintf %d error %s (%d)",
@@ -547,8 +541,7 @@ static void fs_cp_pop_revoked_delegs(clid_entry_t *clid_ent,
 			} else if (unlink(del_path) < 0) {
 				LogEvent(COMPONENT_CLIENTID,
 					 "unlink of %s failed errno: %s (%d)",
-					 del_path,
-					 strerror(errno), errno);
+					 del_path, strerror(errno), errno);
 			}
 		}
 	}
@@ -573,10 +566,8 @@ static void fs_cp_pop_revoked_delegs(clid_entry_t *clid_ent,
  *
  * @return POSIX error codes.
  */
-static int fs_read_recov_clids_impl(const char *parent_path,
-				    char *clid_str,
-				    char *tgtdir,
-				    int takeover,
+static int fs_read_recov_clids_impl(const char *parent_path, char *clid_str,
+				    char *tgtdir, int takeover,
 				    add_clid_entry_hook add_clid_entry,
 				    add_rfh_entry_hook add_rfh_entry)
 {
@@ -648,15 +639,11 @@ static int fs_read_recov_clids_impl(const char *parent_path,
 		if (clid_str)
 			memcpy(build_clid, clid_str, clid_str_len);
 
-		memcpy(build_clid + clid_str_len,
-		       dentp->d_name,
+		memcpy(build_clid + clid_str_len, dentp->d_name,
 		       segment_len + 1);
 
-		rc = fs_read_recov_clids_impl(sub_path,
-					      build_clid,
-					      new_path,
-					      takeover,
-					      add_clid_entry,
+		rc = fs_read_recov_clids_impl(sub_path, build_clid, new_path,
+					      takeover, add_clid_entry,
 					      add_rfh_entry);
 		gsh_free(new_path);
 
@@ -675,8 +662,8 @@ static int fs_read_recov_clids_impl(const char *parent_path,
 			 */
 			if (total_clid_len >= PATH_MAX) {
 				LogEvent(COMPONENT_CLIENTID,
-					"invalid clid format: %s, too long",
-					build_clid);
+					 "invalid clid format: %s, too long",
+					 build_clid);
 				gsh_free(sub_path);
 				gsh_free(build_clid);
 				continue;
@@ -684,8 +671,7 @@ static int fs_read_recov_clids_impl(const char *parent_path,
 			ptr = strchr(build_clid, '(');
 			if (ptr == NULL) {
 				LogEvent(COMPONENT_CLIENTID,
-					 "invalid clid format: %s",
-					 build_clid);
+					 "invalid clid format: %s", build_clid);
 				gsh_free(sub_path);
 				gsh_free(build_clid);
 				continue;
@@ -693,30 +679,26 @@ static int fs_read_recov_clids_impl(const char *parent_path,
 			ptr2 = strchr(ptr, ':');
 			if (ptr2 == NULL) {
 				LogEvent(COMPONENT_CLIENTID,
-					 "invalid clid format: %s",
-					 build_clid);
+					 "invalid clid format: %s", build_clid);
 				gsh_free(sub_path);
 				gsh_free(build_clid);
 				continue;
 			}
-			len = ptr2-ptr-1;
+			len = ptr2 - ptr - 1;
 			if (len >= 9) {
 				LogEvent(COMPONENT_CLIENTID,
-					 "invalid clid format: %s",
-					 build_clid);
+					 "invalid clid format: %s", build_clid);
 				gsh_free(sub_path);
 				gsh_free(build_clid);
 				continue;
 			}
-			memcpy(temp, ptr+1, len+1);
+			memcpy(temp, ptr + 1, len + 1);
 			cid_len = atoi(temp);
 			len = strlen(ptr2);
-			if ((len == (cid_len+2)) && (ptr2[len-1] == ')')) {
+			if ((len == (cid_len + 2)) && (ptr2[len - 1] == ')')) {
 				new_ent = add_clid_entry(build_clid);
-				fs_cp_pop_revoked_delegs(new_ent,
-							 sub_path,
-							 tgtdir,
-							 !takeover,
+				fs_cp_pop_revoked_delegs(new_ent, sub_path,
+							 tgtdir, !takeover,
 							 add_rfh_entry);
 				LogDebug(COMPONENT_CLIENTID,
 					 "added %s to clid list",
@@ -748,23 +730,19 @@ static void fs_read_recov_clids_recover(add_clid_entry_hook add_clid_entry,
 {
 	int rc;
 
-	rc = fs_read_recov_clids_impl(v4_old_dir, NULL, NULL, 0,
-				      add_clid_entry,
+	rc = fs_read_recov_clids_impl(v4_old_dir, NULL, NULL, 0, add_clid_entry,
 				      add_rfh_entry);
 	if (rc == -1) {
 		LogEvent(COMPONENT_CLIENTID,
-			 "Failed to read v4 recovery dir (%s)",
-			 v4_old_dir);
+			 "Failed to read v4 recovery dir (%s)", v4_old_dir);
 		return;
 	}
 
 	rc = fs_read_recov_clids_impl(v4_recov_dir, NULL, v4_old_dir, 0,
-				      add_clid_entry,
-				      add_rfh_entry);
+				      add_clid_entry, add_rfh_entry);
 	if (rc == -1) {
 		LogEvent(COMPONENT_CLIENTID,
-			 "Failed to read v4 recovery dir (%s)",
-			 v4_recov_dir);
+			 "Failed to read v4 recovery dir (%s)", v4_recov_dir);
 		return;
 	}
 }
@@ -791,8 +769,7 @@ void fs_read_recov_clids_takeover(nfs_grace_start_t *gsp,
 		rc = snprintf(path, sizeof(path), "%s", v4_recov_dir);
 
 		if (unlikely(rc >= sizeof(path))) {
-			LogCrit(COMPONENT_CLIENTID,
-				"Path %s too long",
+			LogCrit(COMPONENT_CLIENTID, "Path %s too long",
 				v4_recov_dir);
 			return;
 		} else if (unlikely(rc < 0)) {
@@ -807,8 +784,7 @@ void fs_read_recov_clids_takeover(nfs_grace_start_t *gsp,
 			      nfs_param.nfsv4_param.recov_dir);
 
 		if (unlikely(rc >= sizeof(path))) {
-			LogCrit(COMPONENT_CLIENTID,
-				"Path %s/%s/%s too long",
+			LogCrit(COMPONENT_CLIENTID, "Path %s/%s/%s too long",
 				nfs_param.nfsv4_param.recov_root, gsp->ipaddr,
 				nfs_param.nfsv4_param.recov_dir);
 			return;
@@ -821,15 +797,13 @@ void fs_read_recov_clids_takeover(nfs_grace_start_t *gsp,
 	case EVENT_TAKE_NODEID:
 		rc = snprintf(path, sizeof(path), "%s/%s/node%d",
 			      nfs_param.nfsv4_param.recov_root,
-			      nfs_param.nfsv4_param.recov_dir,
-			      gsp->nodeid);
+			      nfs_param.nfsv4_param.recov_dir, gsp->nodeid);
 
 		if (unlikely(rc >= sizeof(path))) {
 			LogCrit(COMPONENT_CLIENTID,
 				"Path %s/%s/node%d too long",
 				nfs_param.nfsv4_param.recov_root,
-				nfs_param.nfsv4_param.recov_dir,
-				gsp->nodeid);
+				nfs_param.nfsv4_param.recov_dir, gsp->nodeid);
 			return;
 		} else if (unlikely(rc < 0)) {
 			LogCrit(COMPONENT_CLIENTID,
@@ -845,8 +819,7 @@ void fs_read_recov_clids_takeover(nfs_grace_start_t *gsp,
 	LogEvent(COMPONENT_CLIENTID, "Recovery for nodeid %d dir (%s)",
 		 gsp->nodeid, path);
 
-	rc = fs_read_recov_clids_impl(path, NULL, v4_old_dir, 1,
-				      add_clid_entry,
+	rc = fs_read_recov_clids_impl(path, NULL, v4_old_dir, 1, add_clid_entry,
 				      add_rfh_entry);
 	if (rc == -1) {
 		LogEvent(COMPONENT_CLIENTID,
@@ -864,9 +837,10 @@ void fs_clean_old_recov_dir_impl(char *parent_path)
 
 	dp = opendir(parent_path);
 	if (dp == NULL) {
-		LogEvent(COMPONENT_CLIENTID,
-			 "Failed to open old v4 recovery dir (%s), errno: %s (%d)",
-			 v4_old_dir, strerror(errno), errno);
+		LogEvent(
+			COMPONENT_CLIENTID,
+			"Failed to open old v4 recovery dir (%s), errno: %s (%d)",
+			v4_old_dir, strerror(errno), errno);
 		return;
 	}
 
@@ -884,8 +858,8 @@ void fs_clean_old_recov_dir_impl(char *parent_path)
 		if (dentp->d_name[0] == '\x1') {
 			if (unlink(path) < 0) {
 				LogEvent(COMPONENT_CLIENTID,
-						"unlink of %s failed errno: %s (%d)",
-						path, strerror(errno), errno);
+					 "unlink of %s failed errno: %s (%d)",
+					 path, strerror(errno), errno);
 			}
 		} else {
 			/* This is a directory, we need process files in it! */
@@ -912,15 +886,15 @@ void fs_clean_old_recov_dir(void)
 void fs_add_revoke_fh(nfs_client_id_t *delr_clid, nfs_fh4 *delr_handle)
 {
 	char rhdlstr[NAME_MAX];
-	char path[PATH_MAX] = {0};
+	char path[PATH_MAX] = { 0 };
 	int length, position = 0, pathpos, rhdlstr_len;
 	int fd;
-	int retval;
+	int __attribute__((unused)) retval;
 
 	/* Convert nfs_fh4_val into base64 encoded string */
 	retval = base64url_encode(delr_handle->nfs_fh4_val,
-				  delr_handle->nfs_fh4_len,
-				  rhdlstr, sizeof(rhdlstr));
+				  delr_handle->nfs_fh4_len, rhdlstr,
+				  sizeof(rhdlstr));
 	assert(retval != -1);
 	rhdlstr_len = strlen(rhdlstr);
 
@@ -949,16 +923,15 @@ void fs_add_revoke_fh(nfs_client_id_t *delr_clid, nfs_fh4 *delr_handle)
 			}
 			path[pathpos++] = '/';
 			memcpy(path + pathpos,
-			       delr_clid->cid_recov_tag + position,
-			       len);
+			       delr_clid->cid_recov_tag + position, len);
 			/* Prefix 1 to converted fh */
 			memcpy(path + pathpos + len, "/\x1", 2);
-			memcpy(path + pathpos + len + 2,
-			       rhdlstr,
+			memcpy(path + pathpos + len + 2, rhdlstr,
 			       rhdlstr_len + 1);
 			fd = creat(path, 0700);
 			if (fd < 0) {
-				LogEvent(COMPONENT_CLIENTID,
+				LogEvent(
+					COMPONENT_CLIENTID,
 					"Failed to record revoke errno: %s (%d)",
 					strerror(errno), errno);
 			} else {
@@ -967,8 +940,7 @@ void fs_add_revoke_fh(nfs_client_id_t *delr_clid, nfs_fh4 *delr_handle)
 			return;
 		}
 		path[pathpos++] = '/';
-		memcpy(path + pathpos,
-		       delr_clid->cid_recov_tag + position,
+		memcpy(path + pathpos, delr_clid->cid_recov_tag + position,
 		       NAME_MAX);
 		pathpos += NAME_MAX;
 		path[pathpos] = '\0';
