@@ -28,13 +28,13 @@
 /* A rados key is a decimal string of a uint64_t value which has at most 20
  * digits plus 1 for NUL
  */
-#define RADOS_KEY_MAX_LEN	21
-#define RADOS_VAL_MAX_LEN	PATH_MAX
+#define RADOS_KEY_MAX_LEN 21
+#define RADOS_VAL_MAX_LEN PATH_MAX
 
-extern rados_t			rados_recov_cluster;
-extern rados_ioctx_t		rados_recov_io_ctx;
-extern struct gsh_refstr	*rados_recov_oid;
-extern struct gsh_refstr	*rados_recov_old_oid;
+extern rados_t rados_recov_cluster;
+extern rados_ioctx_t rados_recov_io_ctx;
+extern struct gsh_refstr *rados_recov_oid;
+extern struct gsh_refstr *rados_recov_old_oid;
 
 struct rados_kv_parameter {
 	/** Connection to ceph cluster */
@@ -59,10 +59,10 @@ struct pop_args {
 	bool old;
 	bool takeover;
 };
-typedef void (*pop_clid_entry_t)(char *, char *, size_t,  struct pop_args *);
+typedef void (*pop_clid_entry_t)(char *, char *, size_t, struct pop_args *);
 
 int rados_kv_connect(rados_ioctx_t *io_ctx, const char *userid,
-			const char *conf, const char *pool, const char *ns);
+		     const char *conf, const char *pool, const char *ns);
 void rados_kv_shutdown(void);
 int rados_kv_put(char *key, char *val, char *object);
 int rados_kv_get(char *key, char *val, char *object);
@@ -77,23 +77,23 @@ void rados_kv_add_revoke_fh(nfs_client_id_t *delr_clid, nfs_fh4 *delr_handle);
  * @param(in/out) key       The string buffer to put the key in
  * @param(in)     size      Buffer size - expected to be RADOS_KEY_MAX_LEN
  */
-static inline
-void rados_kv_create_key(nfs_client_id_t *clientid, char *key, size_t size)
+static inline void rados_kv_create_key(nfs_client_id_t *clientid, char *key,
+				       size_t size)
 {
 	assert(size == RADOS_KEY_MAX_LEN);
 
 	/* Can't overrun RADOS_KEY_MAX_LEN and shouldn't return EOVERFLOW or
 	 * EINVAL
 	 */
-	(void) snprintf(key, size, "%lu", (uint64_t)clientid->cid_clientid);
+	(void)snprintf(key, size, "%lu", (uint64_t)clientid->cid_clientid);
 }
 
 char *rados_kv_create_val(nfs_client_id_t *clientid, size_t *len);
 int rados_kv_traverse(pop_clid_entry_t callback, struct pop_args *args,
-			const char *object);
+		      const char *object);
 void rados_kv_add_revoke_fh(nfs_client_id_t *delr_clid, nfs_fh4 *delr_handle);
 
 void rados_ng_pop_clid_entry(char *key, char *val, size_t val_len,
 			     struct pop_args *pop_args);
 int rados_kv_get_nodeid(char **pnodeid);
-#endif	/* _RECOVERY_RADOS_H */
+#endif /* _RECOVERY_RADOS_H */
