@@ -98,7 +98,7 @@ static inline struct avltree_node *get_parent(const struct avltree_node *node)
 static inline void set_parent(const struct avltree_node *parent,
 			      struct avltree_node *node)
 {
-	node->parent = (uintptr_t) parent | (node->parent & 7);
+	node->parent = (uintptr_t)parent | (node->parent & 7);
 }
 
 #endif
@@ -144,7 +144,7 @@ struct avltree_node *avltree_prev(const struct avltree_node *node)
 	return parent;
 }
 
-uint64_t avltree_size(const struct avltree * tree)
+uint64_t avltree_size(const struct avltree *tree)
 {
 	return tree->size;
 }
@@ -158,7 +158,7 @@ uint64_t avltree_size(const struct avltree * tree)
 static void rotate_left(struct avltree_node *node, struct avltree *tree)
 {
 	struct avltree_node *p = node;
-	struct avltree_node *q = node->right;	/* can't be NULL */
+	struct avltree_node *q = node->right; /* can't be NULL */
 	struct avltree_node *parent = get_parent(p);
 
 	if (!is_root(p)) {
@@ -180,7 +180,7 @@ static void rotate_left(struct avltree_node *node, struct avltree *tree)
 static void rotate_right(struct avltree_node *node, struct avltree *tree)
 {
 	struct avltree_node *p = node;
-	struct avltree_node *q = node->left;	/* can't be NULL */
+	struct avltree_node *q = node->left; /* can't be NULL */
 	struct avltree_node *parent = get_parent(p);
 
 	if (!is_root(p)) {
@@ -202,14 +202,14 @@ static void rotate_right(struct avltree_node *node, struct avltree *tree)
 struct avltree_node *avltree_inf(const struct avltree_node *key,
 				 const struct avltree *tree)
 {
-	struct avltree_node *parent __attribute__ ((unused));
+	struct avltree_node *parent __attribute__((unused));
 	struct avltree_node *lb;
-	struct avltree_node *unbalanced __attribute__ ((unused));
+	struct avltree_node *unbalanced __attribute__((unused));
 	struct avltree_node *node = tree->root;
 	int is_left = 0;
 	int res = 0;
 
-	lb = avltree_first(tree);	/* at worst, the first entry */
+	lb = avltree_first(tree); /* at worst, the first entry */
 	unbalanced = node;
 	parent = NULL;
 	is_left = 0;
@@ -221,14 +221,14 @@ struct avltree_node *avltree_inf(const struct avltree_node *key,
 		if (res == 0) {
 			/* node is the infimum */
 			return node;
-		} else if (res < 1)	/* lb is less than key */
+		} else if (res < 1) /* lb is less than key */
 			lb = node;
 		parent = node;
 		if ((is_left = res > 0))
 			node = node->left;
 		else
 			node = node->right;
-	}			/* while */
+	} /* while */
 
 	return (lb);
 }
@@ -236,9 +236,9 @@ struct avltree_node *avltree_inf(const struct avltree_node *key,
 struct avltree_node *avltree_sup(const struct avltree_node *key,
 				 const struct avltree *tree)
 {
-	struct avltree_node *parent __attribute__ ((unused));
+	struct avltree_node *parent __attribute__((unused));
 	struct avltree_node *ub = NULL;
-	struct avltree_node *unbalanced __attribute__ ((unused));
+	struct avltree_node *unbalanced __attribute__((unused));
 	struct avltree_node *node = tree->root;
 	int is_left = 0;
 	int res = 0;
@@ -262,10 +262,10 @@ struct avltree_node *avltree_sup(const struct avltree_node *key,
 			node = node->right;
 		if (node) {
 			res = tree->cmp_fn(node, key);
-			if (res > 0)	/* XXX do we need reciprocal test on ub? */
+			if (res > 0) /* XXX do we need reciprocal test on ub? */
 				ub = node;
 		}
-	}			/* while */
+	} /* while */
 
 	return (ub);
 }
@@ -280,11 +280,9 @@ static void set_child(struct avltree_node *child, struct avltree_node *node,
 }
 
 /* Insertion never needs more than 2 rotations */
-void avltree_do_insert(struct avltree_node *node,
-		       struct avltree *tree,
+void avltree_do_insert(struct avltree_node *node, struct avltree *tree,
 		       struct avltree_node *parent,
-		       struct avltree_node *unbalanced,
-		       int is_left)
+		       struct avltree_node *unbalanced, int is_left)
 {
 	INIT_NODE(node);
 
@@ -327,62 +325,62 @@ void avltree_do_insert(struct avltree_node *node,
 		/* fall through */
 	case 0:
 		break;
-	case 2:{
-			struct avltree_node *right = unbalanced->right;
+	case 2: {
+		struct avltree_node *right = unbalanced->right;
 
-			if (get_balance(right) == 1) {
+		if (get_balance(right) == 1) {
+			set_balance(0, unbalanced);
+			set_balance(0, right);
+		} else {
+			switch (get_balance(right->left)) {
+			case 1:
+				set_balance(-1, unbalanced);
+				set_balance(0, right);
+				break;
+			case 0:
 				set_balance(0, unbalanced);
 				set_balance(0, right);
-			} else {
-				switch (get_balance(right->left)) {
-				case 1:
-					set_balance(-1, unbalanced);
-					set_balance(0, right);
-					break;
-				case 0:
-					set_balance(0, unbalanced);
-					set_balance(0, right);
-					break;
-				case -1:
-					set_balance(0, unbalanced);
-					set_balance(1, right);
-					break;
-				}
-				set_balance(0, right->left);
-
-				rotate_right(right, tree);
+				break;
+			case -1:
+				set_balance(0, unbalanced);
+				set_balance(1, right);
+				break;
 			}
-			rotate_left(unbalanced, tree);
-			break;
-		}
-	case -2:{
-			struct avltree_node *left = unbalanced->left;
+			set_balance(0, right->left);
 
-			if (get_balance(left) == -1) {
+			rotate_right(right, tree);
+		}
+		rotate_left(unbalanced, tree);
+		break;
+	}
+	case -2: {
+		struct avltree_node *left = unbalanced->left;
+
+		if (get_balance(left) == -1) {
+			set_balance(0, unbalanced);
+			set_balance(0, left);
+		} else {
+			switch (get_balance(left->right)) {
+			case 1:
+				set_balance(0, unbalanced);
+				set_balance(-1, left);
+				break;
+			case 0:
 				set_balance(0, unbalanced);
 				set_balance(0, left);
-			} else {
-				switch (get_balance(left->right)) {
-				case 1:
-					set_balance(0, unbalanced);
-					set_balance(-1, left);
-					break;
-				case 0:
-					set_balance(0, unbalanced);
-					set_balance(0, left);
-					break;
-				case -1:
-					set_balance(1, unbalanced);
-					set_balance(0, left);
-					break;
-				}
-				set_balance(0, left->right);
-
-				rotate_left(left, tree);
+				break;
+			case -1:
+				set_balance(1, unbalanced);
+				set_balance(0, left);
+				break;
 			}
-			rotate_right(unbalanced, tree);
-			break;
+			set_balance(0, left->right);
+
+			rotate_left(left, tree);
 		}
+		rotate_right(unbalanced, tree);
+		break;
+	}
 	}
 }
 
@@ -477,22 +475,22 @@ void avltree_remove(struct avltree_node *node, struct avltree *tree)
 			is_left = parent && parent->left == node;
 
 			balance = inc_balance(node);
-			if (balance == 0)	/* case 1 */
+			if (balance == 0) /* case 1 */
 				continue;
-			if (balance == 1)	/* case 2 */
+			if (balance == 1) /* case 2 */
 				return;
-			right = node->right;	/* case 3 */
+			right = node->right; /* case 3 */
 			switch (get_balance(right)) {
-			case 0:	/* case 3.1 */
+			case 0: /* case 3.1 */
 				set_balance(1, node);
 				set_balance(-1, right);
 				rotate_left(node, tree);
 				return;
-			case 1:	/* case 3.2 */
+			case 1: /* case 3.2 */
 				set_balance(0, node);
 				set_balance(0, right);
 				break;
-			case -1:	/* case 3.3 */
+			case -1: /* case 3.3 */
 				switch (get_balance(right->left)) {
 				case 1:
 					set_balance(-1, node);
