@@ -226,15 +226,9 @@ struct config_item_list {
 	uint32_t value;
 };
 
-#define CONFIG_LIST_TOK(_token_, _flags_)          \
-	{                                          \
-		.token = _token_, .value = _flags_ \
-	}
+#define CONFIG_LIST_TOK(_token_, _flags_) { .token = _token_, .value = _flags_ }
 
-#define CONFIG_LIST_EOL                   \
-	{                                 \
-		.token = NULL, .value = 0 \
-	}
+#define CONFIG_LIST_EOL { .token = NULL, .value = 0 }
 /**
  * @brief A config file parameter
  *
@@ -475,80 +469,86 @@ struct config_item {
  *
  */
 
-#define CONF_ITEM_NOOP(_name_)                       \
-	{                                            \
-		.name = _name_, .type = CONFIG_NULL, \
+#define CONF_ITEM_NOOP(_name_)       \
+	{                            \
+		.name = _name_,      \
+		.type = CONFIG_NULL, \
 	}
 
 #define CONF_ITEM_FSID_SET(_name_, _def_maj_, _def_min_, _struct_, _mem_, \
 			   _bit_, _set_)                                  \
-	{                                                                 \
-		.name = _name_, .type = CONFIG_FSID,                      \
-		.flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                 \
-		.u.fsid.def_maj = _def_maj_, .u.fsid.def_min = _def_min_, \
-		.u.fsid.bit = _bit_,                                      \
-		.u.fsid.set_off = offsetof(struct _struct_, _set_),       \
-		.off = offsetof(struct _struct_, _mem_)                   \
-	}
+	{ .name = _name_,                                                 \
+	  .type = CONFIG_FSID,                                            \
+	  .flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                       \
+	  .u.fsid.def_maj = _def_maj_,                                    \
+	  .u.fsid.def_min = _def_min_,                                    \
+	  .u.fsid.bit = _bit_,                                            \
+	  .u.fsid.set_off = offsetof(struct _struct_, _set_),             \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_BLOCK_MULT(_name_, _params_, _init_, _commit_, _struct_,  \
-			     _mem_)                                         \
-	{                                                                   \
-		.name = _name_, .type = CONFIG_BLOCK, .u.blk.init = _init_, \
-		.u.blk.params = _params_, .u.blk.commit = _commit_,         \
-		.off = offsetof(struct _struct_, _mem_)                     \
-	}
+#define CONF_ITEM_BLOCK_MULT(_name_, _params_, _init_, _commit_, _struct_, \
+			     _mem_)                                        \
+	{ .name = _name_,                                                  \
+	  .type = CONFIG_BLOCK,                                            \
+	  .u.blk.init = _init_,                                            \
+	  .u.blk.params = _params_,                                        \
+	  .u.blk.commit = _commit_,                                        \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_BLOCK(_name_, _params_, _init_, _commit_, _struct_, _mem_)  \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_BLOCK, .flags = CONFIG_UNIQUE, \
-		.u.blk.init = _init_, .u.blk.params = _params_,               \
-		.u.blk.commit = _commit_,                                     \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+#define CONF_ITEM_BLOCK(_name_, _params_, _init_, _commit_, _struct_, _mem_) \
+	{ .name = _name_,                                                    \
+	  .type = CONFIG_BLOCK,                                              \
+	  .flags = CONFIG_UNIQUE,                                            \
+	  .u.blk.init = _init_,                                              \
+	  .u.blk.params = _params_,                                          \
+	  .u.blk.commit = _commit_,                                          \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 #define CONF_RELAX_BLOCK(_name_, _params_, _init_, _commit_, _struct_, _mem_) \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_BLOCK,                         \
-		.flags = CONFIG_RELAX | CONFIG_UNIQUE, .u.blk.init = _init_,  \
-		.u.blk.params = _params_, .u.blk.commit = _commit_,           \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+	{ .name = _name_,                                                     \
+	  .type = CONFIG_BLOCK,                                               \
+	  .flags = CONFIG_RELAX | CONFIG_UNIQUE,                              \
+	  .u.blk.init = _init_,                                               \
+	  .u.blk.params = _params_,                                           \
+	  .u.blk.commit = _commit_,                                           \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_PROC_MULT(_name_, _init_, _handler_, _struct_, _mem_)     \
-	{                                                                   \
-		.name = _name_, .type = CONFIG_PROC, .u.proc.init = _init_, \
-		.u.proc.handler = _handler_,                                \
-		.off = offsetof(struct _struct_, _mem_)                     \
-	}
+#define CONF_ITEM_PROC_MULT(_name_, _init_, _handler_, _struct_, _mem_) \
+	{ .name = _name_,                                               \
+	  .type = CONFIG_PROC,                                          \
+	  .u.proc.init = _init_,                                        \
+	  .u.proc.handler = _handler_,                                  \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_LIST(_name_, _def_, _tokens_, _struct_, _mem_)             \
-	{                                                                    \
-		.name = _name_, .type = CONFIG_LIST, .flags = CONFIG_UNIQUE, \
-		.u.lst.def = _def_, .u.lst.mask = UINT32_MAX,                \
-		.u.lst.set_off = UINT32_MAX, .u.lst.tokens = _tokens_,       \
-		.off = offsetof(struct _struct_, _mem_)                      \
-	}
+#define CONF_ITEM_LIST(_name_, _def_, _tokens_, _struct_, _mem_) \
+	{ .name = _name_,                                        \
+	  .type = CONFIG_LIST,                                   \
+	  .flags = CONFIG_UNIQUE,                                \
+	  .u.lst.def = _def_,                                    \
+	  .u.lst.mask = UINT32_MAX,                              \
+	  .u.lst.set_off = UINT32_MAX,                           \
+	  .u.lst.tokens = _tokens_,                              \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_LIST_BITS_SET(_name_, _def_, _mask_, _tokens_, _struct_,    \
-				_mem_, _set_)                                 \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_LIST,                          \
-		.flags = CONFIG_MARK_SET | CONFIG_UNIQUE, .u.lst.def = _def_, \
-		.u.lst.mask = _mask_,                                         \
-		.u.lst.set_off = offsetof(struct _struct_, _set_),            \
-		.u.lst.tokens = _tokens_,                                     \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+#define CONF_ITEM_LIST_BITS_SET(_name_, _def_, _mask_, _tokens_, _struct_, \
+				_mem_, _set_)                              \
+	{ .name = _name_,                                                  \
+	  .type = CONFIG_LIST,                                             \
+	  .flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                        \
+	  .u.lst.def = _def_,                                              \
+	  .u.lst.mask = _mask_,                                            \
+	  .u.lst.set_off = offsetof(struct _struct_, _set_),               \
+	  .u.lst.tokens = _tokens_,                                        \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_BOOLBIT_SET(_name_, _def_, _bit_, _struct_, _mem_, _set_)   \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_BOOLBIT,                       \
-		.flags = CONFIG_MARK_SET | CONFIG_UNIQUE, .u.bit.def = _def_, \
-		.u.bit.bit = _bit_,                                           \
-		.u.bit.set_off = offsetof(struct _struct_, _set_),            \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+#define CONF_ITEM_BOOLBIT_SET(_name_, _def_, _bit_, _struct_, _mem_, _set_) \
+	{ .name = _name_,                                                   \
+	  .type = CONFIG_BOOLBIT,                                           \
+	  .flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                         \
+	  .u.bit.def = _def_,                                               \
+	  .u.bit.bit = _bit_,                                               \
+	  .u.bit.set_off = offsetof(struct _struct_, _set_),                \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 /* Use CONF_ITEM_TOKEN for a variable that is set to a single enum
  * value. The CONF_ITEM_ENUM_* macros are for setting one or more
@@ -556,237 +556,270 @@ struct config_item {
  */
 
 #define CONF_ITEM_ENUM_BITS(_name_, _def_, _mask_, _tokens_, _struct_, _mem_) \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_ENUM, .flags = CONFIG_UNIQUE,  \
-		.u.lst.def = _def_, .u.lst.mask = _mask_,                     \
-		.u.lst.tokens = _tokens_,                                     \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+	{ .name = _name_,                                                     \
+	  .type = CONFIG_ENUM,                                                \
+	  .flags = CONFIG_UNIQUE,                                             \
+	  .u.lst.def = _def_,                                                 \
+	  .u.lst.mask = _mask_,                                               \
+	  .u.lst.tokens = _tokens_,                                           \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_ENUM_BITS_SET(_name_, _def_, _mask_, _tokens_, _struct_,    \
-				_mem_, _set_)                                 \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_ENUM,                          \
-		.flags = CONFIG_MARK_SET | CONFIG_UNIQUE, .u.lst.def = _def_, \
-		.u.lst.mask = _mask_,                                         \
-		.u.lst.set_off = offsetof(struct _struct_, _set_),            \
-		.u.lst.tokens = _tokens_,                                     \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+#define CONF_ITEM_ENUM_BITS_SET(_name_, _def_, _mask_, _tokens_, _struct_, \
+				_mem_, _set_)                              \
+	{ .name = _name_,                                                  \
+	  .type = CONFIG_ENUM,                                             \
+	  .flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                        \
+	  .u.lst.def = _def_,                                              \
+	  .u.lst.mask = _mask_,                                            \
+	  .u.lst.set_off = offsetof(struct _struct_, _set_),               \
+	  .u.lst.tokens = _tokens_,                                        \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_TOKEN(_name_, _def_, _tokens_, _struct_, _mem_)             \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_TOKEN, .flags = CONFIG_UNIQUE, \
-		.u.lst.def = _def_, .u.lst.tokens = _tokens_,                 \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+#define CONF_ITEM_TOKEN(_name_, _def_, _tokens_, _struct_, _mem_) \
+	{ .name = _name_,                                         \
+	  .type = CONFIG_TOKEN,                                   \
+	  .flags = CONFIG_UNIQUE,                                 \
+	  .u.lst.def = _def_,                                     \
+	  .u.lst.tokens = _tokens_,                               \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_INDEX_TOKEN(_name_, _def_, _tokens_, _idx_, _sizeof_)            \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_TOKEN, .flags = CONFIG_UNIQUE, \
-		.u.lst.def = _def_, .u.lst.tokens = _tokens_,                 \
-		.off = (sizeof(_sizeof_) * _idx_)                             \
-	}
+#define CONF_INDEX_TOKEN(_name_, _def_, _tokens_, _idx_, _sizeof_) \
+	{ .name = _name_,                                          \
+	  .type = CONFIG_TOKEN,                                    \
+	  .flags = CONFIG_UNIQUE,                                  \
+	  .u.lst.def = _def_,                                      \
+	  .u.lst.tokens = _tokens_,                                \
+	  .off = (sizeof(_sizeof_) * _idx_) }
 
-#define CONF_ITEM_BOOL(_name_, _def_, _struct_, _mem_)                       \
-	{                                                                    \
-		.name = _name_, .type = CONFIG_BOOL, .flags = CONFIG_UNIQUE, \
-		.u.b.def = _def_, .off = offsetof(struct _struct_, _mem_)    \
-	}
+#define CONF_ITEM_BOOL(_name_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                              \
+	  .type = CONFIG_BOOL,                         \
+	  .flags = CONFIG_UNIQUE,                      \
+	  .u.b.def = _def_,                            \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_STR(_name_, _minsize_, _maxsize_, _def_, _struct_, _mem_)    \
-	{                                                                      \
-		.name = _name_, .type = CONFIG_STRING, .flags = CONFIG_UNIQUE, \
-		.u.str.minsize = _minsize_, .u.str.maxsize = _maxsize_,        \
-		.u.str.def = _def_, .off = offsetof(struct _struct_, _mem_)    \
-	}
+#define CONF_ITEM_STR(_name_, _minsize_, _maxsize_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                                   \
+	  .type = CONFIG_STRING,                                            \
+	  .flags = CONFIG_UNIQUE,                                           \
+	  .u.str.minsize = _minsize_,                                       \
+	  .u.str.maxsize = _maxsize_,                                       \
+	  .u.str.def = _def_,                                               \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 #define CONF_MAND_STR(_name_, _minsize_, _maxsize_, _def_, _struct_, _mem_) \
-	{                                                                   \
-		.name = _name_, .type = CONFIG_STRING,                      \
-		.flags = CONFIG_UNIQUE | CONFIG_MANDATORY,                  \
-		.u.str.minsize = _minsize_, .u.str.maxsize = _maxsize_,     \
-		.u.str.def = _def_, .off = offsetof(struct _struct_, _mem_) \
-	}
+	{ .name = _name_,                                                   \
+	  .type = CONFIG_STRING,                                            \
+	  .flags = CONFIG_UNIQUE | CONFIG_MANDATORY,                        \
+	  .u.str.minsize = _minsize_,                                       \
+	  .u.str.maxsize = _maxsize_,                                       \
+	  .u.str.def = _def_,                                               \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 #define CONF_ITEM_PATH(_name_, _minsize_, _maxsize_, _def_, _struct_, _mem_) \
-	{                                                                    \
-		.name = _name_, .type = CONFIG_PATH, .flags = CONFIG_UNIQUE, \
-		.u.str.minsize = _minsize_, .u.str.maxsize = _maxsize_,      \
-		.u.str.def = _def_, .off = offsetof(struct _struct_, _mem_)  \
-	}
+	{ .name = _name_,                                                    \
+	  .type = CONFIG_PATH,                                               \
+	  .flags = CONFIG_UNIQUE,                                            \
+	  .u.str.minsize = _minsize_,                                        \
+	  .u.str.maxsize = _maxsize_,                                        \
+	  .u.str.def = _def_,                                                \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 #define CONF_MAND_PATH(_name_, _minsize_, _maxsize_, _def_, _struct_, _mem_) \
-	{                                                                    \
-		.name = _name_, .type = CONFIG_PATH,                         \
-		.flags = CONFIG_UNIQUE | CONFIG_MANDATORY,                   \
-		.u.str.minsize = _minsize_, .u.str.maxsize = _maxsize_,      \
-		.u.str.def = _def_, .off = offsetof(struct _struct_, _mem_)  \
-	}
+	{ .name = _name_,                                                    \
+	  .type = CONFIG_PATH,                                               \
+	  .flags = CONFIG_UNIQUE | CONFIG_MANDATORY,                         \
+	  .u.str.minsize = _minsize_,                                        \
+	  .u.str.maxsize = _maxsize_,                                        \
+	  .u.str.def = _def_,                                                \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_IP_ADDR(_name_, _def_, _struct_, _mem_)  \
-	{                                                  \
-		.name = _name_, .type = CONFIG_IP_ADDR,    \
-		.flags = CONFIG_UNIQUE, .u.ip.def = _def_, \
-		.off = offsetof(struct _struct_, _mem_)    \
-	}
+#define CONF_ITEM_IP_ADDR(_name_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                 \
+	  .type = CONFIG_IP_ADDR,                         \
+	  .flags = CONFIG_UNIQUE,                         \
+	  .u.ip.def = _def_,                              \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_MAND_IP_ADDR(_name_, _def_, _struct_, _mem_)                     \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_IP_ADDR,                       \
-		.flags = CONFIG_UNIQUE | CONFIG_MANDATORY, .u.ip.def = _def_, \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+#define CONF_MAND_IP_ADDR(_name_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                 \
+	  .type = CONFIG_IP_ADDR,                         \
+	  .flags = CONFIG_UNIQUE | CONFIG_MANDATORY,      \
+	  .u.ip.def = _def_,                              \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_I16(_name_, _min_, _max_, _def_, _struct_, _mem_)           \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_INT16, .flags = CONFIG_UNIQUE, \
-		.u.i16.minval = _min_, .u.i16.maxval = _max_,                 \
-		.u.i16.def = _def_, .u.i16.zero_ok = (_min_ <= 0),            \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+#define CONF_ITEM_I16(_name_, _min_, _max_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                           \
+	  .type = CONFIG_INT16,                                     \
+	  .flags = CONFIG_UNIQUE,                                   \
+	  .u.i16.minval = _min_,                                    \
+	  .u.i16.maxval = _max_,                                    \
+	  .u.i16.def = _def_,                                       \
+	  .u.i16.zero_ok = (_min_ <= 0),                            \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_UI16(_name_, _min_, _max_, _def_, _struct_, _mem_)           \
-	{                                                                      \
-		.name = _name_, .type = CONFIG_UINT16, .flags = CONFIG_UNIQUE, \
-		.u.ui16.minval = _min_, .u.ui16.maxval = _max_,                \
-		.u.ui16.def = _def_, .u.ui16.zero_ok = (_min_ == 0),           \
-		.off = offsetof(struct _struct_, _mem_)                        \
-	}
+#define CONF_ITEM_UI16(_name_, _min_, _max_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                            \
+	  .type = CONFIG_UINT16,                                     \
+	  .flags = CONFIG_UNIQUE,                                    \
+	  .u.ui16.minval = _min_,                                    \
+	  .u.ui16.maxval = _max_,                                    \
+	  .u.ui16.def = _def_,                                       \
+	  .u.ui16.zero_ok = (_min_ == 0),                            \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 #define CONF_MAND_UI16(_name_, _min_, _max_, _def_, _struct_, _mem_) \
-	{                                                            \
-		.name = _name_, .type = CONFIG_UINT16,               \
-		.flags = CONFIG_UNIQUE | CONFIG_MANDATORY,           \
-		.u.ui16.minval = _min_, .u.ui16.maxval = _max_,      \
-		.u.ui16.def = _def_, .u.ui16.zero_ok = (_min_ == 0), \
-		.off = offsetof(struct _struct_, _mem_)              \
-	}
+	{ .name = _name_,                                            \
+	  .type = CONFIG_UINT16,                                     \
+	  .flags = CONFIG_UNIQUE | CONFIG_MANDATORY,                 \
+	  .u.ui16.minval = _min_,                                    \
+	  .u.ui16.maxval = _max_,                                    \
+	  .u.ui16.def = _def_,                                       \
+	  .u.ui16.zero_ok = (_min_ == 0),                            \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_I32(_name_, _min_, _max_, _def_, _struct_, _mem_)           \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_INT32, .flags = CONFIG_UNIQUE, \
-		.u.i32.minval = _min_, .u.i32.maxval = _max_,                 \
-		.u.i32.def = _def_, .u.i32.zero_ok = (_min_ <= 0),            \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+#define CONF_ITEM_I32(_name_, _min_, _max_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                           \
+	  .type = CONFIG_INT32,                                     \
+	  .flags = CONFIG_UNIQUE,                                   \
+	  .u.i32.minval = _min_,                                    \
+	  .u.i32.maxval = _max_,                                    \
+	  .u.i32.def = _def_,                                       \
+	  .u.i32.zero_ok = (_min_ <= 0),                            \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 #define CONF_ITEM_I32_SET(_name_, _min_, _max_, _def_, _struct_, _mem_, _bit_, \
 			  _set_)                                               \
-	{                                                                      \
-		.name = _name_, .type = CONFIG_INT32,                          \
-		.flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                      \
-		.u.i32.minval = _min_, .u.i32.maxval = _max_,                  \
-		.u.i32.def = _def_, .u.i32.zero_ok = (_min_ <= 0),             \
-		.u.i32.bit = _bit_,                                            \
-		.u.i32.set_off = offsetof(struct _struct_, _set_),             \
-		.off = offsetof(struct _struct_, _mem_)                        \
-	}
+	{ .name = _name_,                                                      \
+	  .type = CONFIG_INT32,                                                \
+	  .flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                            \
+	  .u.i32.minval = _min_,                                               \
+	  .u.i32.maxval = _max_,                                               \
+	  .u.i32.def = _def_,                                                  \
+	  .u.i32.zero_ok = (_min_ <= 0),                                       \
+	  .u.i32.bit = _bit_,                                                  \
+	  .u.i32.set_off = offsetof(struct _struct_, _set_),                   \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_ANON_ID_SET(_name_, _def_, _struct_, _mem_, _bit_, _set_)    \
-	{                                                                      \
-		.name = _name_, .type = CONFIG_ANON_ID,                        \
-		.flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                      \
-		.u.i64.minval = INT32_MIN, .u.i64.maxval = UINT32_MAX,         \
-		.u.i64.def = _def_, .u.i64.zero_ok = true, .u.i64.bit = _bit_, \
-		.u.i64.set_off = offsetof(struct _struct_, _set_),             \
-		.off = offsetof(struct _struct_, _mem_)                        \
-	}
+#define CONF_ITEM_ANON_ID_SET(_name_, _def_, _struct_, _mem_, _bit_, _set_) \
+	{ .name = _name_,                                                   \
+	  .type = CONFIG_ANON_ID,                                           \
+	  .flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                         \
+	  .u.i64.minval = INT32_MIN,                                        \
+	  .u.i64.maxval = UINT32_MAX,                                       \
+	  .u.i64.def = _def_,                                               \
+	  .u.i64.zero_ok = true,                                            \
+	  .u.i64.bit = _bit_,                                               \
+	  .u.i64.set_off = offsetof(struct _struct_, _set_),                \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_UI32(_name_, _min_, _max_, _def_, _struct_, _mem_)           \
-	{                                                                      \
-		.name = _name_, .type = CONFIG_UINT32, .flags = CONFIG_UNIQUE, \
-		.u.ui32.minval = _min_, .u.ui32.maxval = _max_,                \
-		.u.ui32.def = _def_, .u.ui32.zero_ok = (_min_ == 0),           \
-		.off = offsetof(struct _struct_, _mem_)                        \
-	}
+#define CONF_ITEM_UI32(_name_, _min_, _max_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                            \
+	  .type = CONFIG_UINT32,                                     \
+	  .flags = CONFIG_UNIQUE,                                    \
+	  .u.ui32.minval = _min_,                                    \
+	  .u.ui32.maxval = _max_,                                    \
+	  .u.ui32.def = _def_,                                       \
+	  .u.ui32.zero_ok = (_min_ == 0),                            \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_UI32_ZERO(_name_, _min_, _max_, _def_, _struct_, _mem_)      \
-	{                                                                      \
-		.name = _name_, .type = CONFIG_UINT32, .flags = CONFIG_UNIQUE, \
-		.u.ui32.minval = _min_, .u.ui32.maxval = _max_,                \
-		.u.ui32.def = _def_, .u.ui32.zero_ok = true,                   \
-		.off = offsetof(struct _struct_, _mem_)                        \
-	}
+#define CONF_ITEM_UI32_ZERO(_name_, _min_, _max_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                                 \
+	  .type = CONFIG_UINT32,                                          \
+	  .flags = CONFIG_UNIQUE,                                         \
+	  .u.ui32.minval = _min_,                                         \
+	  .u.ui32.maxval = _max_,                                         \
+	  .u.ui32.def = _def_,                                            \
+	  .u.ui32.zero_ok = true,                                         \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 #define CONF_MAND_UI32(_name_, _min_, _max_, _def_, _struct_, _mem_) \
-	{                                                            \
-		.name = _name_, .type = CONFIG_UINT32,               \
-		.flags = CONFIG_UNIQUE | CONFIG_MANDATORY,           \
-		.u.ui32.minval = _min_, .u.ui32.maxval = _max_,      \
-		.u.ui32.def = _def_, .u.ui32.zero_ok = (_min_ == 0), \
-		.off = offsetof(struct _struct_, _mem_)              \
-	}
+	{ .name = _name_,                                            \
+	  .type = CONFIG_UINT32,                                     \
+	  .flags = CONFIG_UNIQUE | CONFIG_MANDATORY,                 \
+	  .u.ui32.minval = _min_,                                    \
+	  .u.ui32.maxval = _max_,                                    \
+	  .u.ui32.def = _def_,                                       \
+	  .u.ui32.zero_ok = (_min_ == 0),                            \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_MODE(_name_, _def_, _struct_, _mem_)                    \
-	{                                                                 \
-		.name = _name_, .type = CONFIG_UINT32,                    \
-		.flags = CONFIG_MODE | CONFIG_UNIQUE, .u.ui32.minval = 0, \
-		.u.ui32.maxval = 0777, .u.ui32.def = _def_,               \
-		.u.ui32.zero_ok = true,                                   \
-		.off = offsetof(struct _struct_, _mem_)                   \
-	}
+#define CONF_ITEM_MODE(_name_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                              \
+	  .type = CONFIG_UINT32,                       \
+	  .flags = CONFIG_MODE | CONFIG_UNIQUE,        \
+	  .u.ui32.minval = 0,                          \
+	  .u.ui32.maxval = 0777,                       \
+	  .u.ui32.def = _def_,                         \
+	  .u.ui32.zero_ok = true,                      \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_I64(_name_, _min_, _max_, _def_, _struct_, _mem_)           \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_INT64, .flags = CONFIG_UNIQUE, \
-		.u.i64.minval = _min_, .u.i64.maxval = _max_,                 \
-		.u.i64.def = _def_, .u.i64.zero_ok = (_min_ <= 0),            \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+#define CONF_ITEM_I64(_name_, _min_, _max_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                           \
+	  .type = CONFIG_INT64,                                     \
+	  .flags = CONFIG_UNIQUE,                                   \
+	  .u.i64.minval = _min_,                                    \
+	  .u.i64.maxval = _max_,                                    \
+	  .u.i64.def = _def_,                                       \
+	  .u.i64.zero_ok = (_min_ <= 0),                            \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 /* The following exists because I64 is used for time_t which are likely
  * parameters to have a non-zero min but also allow 0.
  */
-#define CONF_ITEM_I64_ZERO(_name_, _min_, _max_, _def_, _struct_, _mem_)      \
-	{                                                                     \
-		.name = _name_, .type = CONFIG_INT64, .flags = CONFIG_UNIQUE, \
-		.u.i64.minval = _min_, .u.i64.maxval = _max_,                 \
-		.u.i64.def = _def_, .u.i64.zero_ok = true,                    \
-		.off = offsetof(struct _struct_, _mem_)                       \
-	}
+#define CONF_ITEM_I64_ZERO(_name_, _min_, _max_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                                \
+	  .type = CONFIG_INT64,                                          \
+	  .flags = CONFIG_UNIQUE,                                        \
+	  .u.i64.minval = _min_,                                         \
+	  .u.i64.maxval = _max_,                                         \
+	  .u.i64.def = _def_,                                            \
+	  .u.i64.zero_ok = true,                                         \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_UI64(_name_, _min_, _max_, _def_, _struct_, _mem_)           \
-	{                                                                      \
-		.name = _name_, .type = CONFIG_UINT64, .flags = CONFIG_UNIQUE, \
-		.u.ui64.minval = _min_, .u.ui64.maxval = _max_,                \
-		.u.ui64.def = _def_, .u.ui64.zero_ok = (_min_ == 0),           \
-		.off = offsetof(struct _struct_, _mem_)                        \
-	}
+#define CONF_ITEM_UI64(_name_, _min_, _max_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                            \
+	  .type = CONFIG_UINT64,                                     \
+	  .flags = CONFIG_UNIQUE,                                    \
+	  .u.ui64.minval = _min_,                                    \
+	  .u.ui64.maxval = _max_,                                    \
+	  .u.ui64.def = _def_,                                       \
+	  .u.ui64.zero_ok = (_min_ == 0),                            \
+	  .off = offsetof(struct _struct_, _mem_) }
 
-#define CONF_ITEM_UI64_ZERO(_name_, _min_, _max_, _def_, _struct_, _mem_)      \
-	{                                                                      \
-		.name = _name_, .type = CONFIG_UINT64, .flags = CONFIG_UNIQUE, \
-		.u.ui64.minval = _min_, .u.ui64.maxval = _max_,                \
-		.u.ui64.def = _def_, .u.ui64.zero_ok = true,                   \
-		.off = offsetof(struct _struct_, _mem_)                        \
-	}
+#define CONF_ITEM_UI64_ZERO(_name_, _min_, _max_, _def_, _struct_, _mem_) \
+	{ .name = _name_,                                                 \
+	  .type = CONFIG_UINT64,                                          \
+	  .flags = CONFIG_UNIQUE,                                         \
+	  .u.ui64.minval = _min_,                                         \
+	  .u.ui64.maxval = _max_,                                         \
+	  .u.ui64.def = _def_,                                            \
+	  .u.ui64.zero_ok = true,                                         \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 #define CONF_ITEM_UI64_SET(_name_, _min_, _max_, _def_, _struct_, _mem_, \
 			   _bit_, _set_)                                 \
-	{                                                                \
-		.name = _name_, .type = CONFIG_UINT64,                   \
-		.flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                \
-		.u.ui64.minval = _min_, .u.ui64.maxval = _max_,          \
-		.u.ui64.def = _def_, .u.ui64.zero_ok = (_min_ == 0),     \
-		.u.ui64.bit = _bit_,                                     \
-		.u.ui64.set_off = offsetof(struct _struct_, _set_),      \
-		.off = offsetof(struct _struct_, _mem_)                  \
-	}
+	{ .name = _name_,                                                \
+	  .type = CONFIG_UINT64,                                         \
+	  .flags = CONFIG_MARK_SET | CONFIG_UNIQUE,                      \
+	  .u.ui64.minval = _min_,                                        \
+	  .u.ui64.maxval = _max_,                                        \
+	  .u.ui64.def = _def_,                                           \
+	  .u.ui64.zero_ok = (_min_ == 0),                                \
+	  .u.ui64.bit = _bit_,                                           \
+	  .u.ui64.set_off = offsetof(struct _struct_, _set_),            \
+	  .off = offsetof(struct _struct_, _mem_) }
 
 /**
  * Note that message can be NULL.
  */
-#define CONF_ITEM_DEPRECATED(_name_, _message_)            \
-	{                                                  \
-		.name = _name_, .type = CONFIG_DEPRECATED, \
-		.u.deprecated.message = _message_,         \
+#define CONF_ITEM_DEPRECATED(_name_, _message_)    \
+	{                                          \
+		.name = _name_,                    \
+		.type = CONFIG_DEPRECATED,         \
+		.u.deprecated.message = _message_, \
 	}
 
-#define CONFIG_EOL                                \
-	{                                         \
-		.name = NULL, .type = CONFIG_NULL \
-	}
+#define CONFIG_EOL { .name = NULL, .type = CONFIG_NULL }
 
 /**
  * @brief Configuration Block
@@ -817,7 +850,7 @@ static inline bool is_prime(int v)
 		return true;
 	if (v % 2 == 0)
 		return false;
-		/* dont link with libm just for this */
+	/* dont link with libm just for this */
 #ifdef LINK_LIBM
 	m = (int)sqrt(v);
 #else
