@@ -230,6 +230,15 @@ typedef enum protos {
 #define UDP_LISTENER_MOUNT 0x00000002
 #define UDP_LISTENER_MASK (UDP_LISTENER_ALL | UDP_LISTENER_MOUNT)
 
+#define ROOT_KERBEROS_PRINCIPAL_NONE (1 << 0)
+#define ROOT_KERBEROS_PRINCIPAL_NFS (1 << 1)
+#define ROOT_KERBEROS_PRINCIPAL_ROOT (1 << 2)
+#define ROOT_KERBEROS_PRINCIPAL_HOST (1 << 3)
+#define ROOT_KERBEROS_PRINCIPAL_ALL                                   \
+	(ROOT_KERBEROS_PRINCIPAL_NFS | ROOT_KERBEROS_PRINCIPAL_ROOT | \
+	 ROOT_KERBEROS_PRINCIPAL_HOST)
+#define ROOT_KERBEROS_PRINCIPAL_DEFAULT ROOT_KERBEROS_PRINCIPAL_ALL
+
 #ifdef _USE_NFS_RDMA
 #define NFS_RDMA_ENABLE_FOR_NONE 0
 #define NFS_RDMA_ENABLE_FOR_NFSV3 0x00000001
@@ -395,7 +404,7 @@ typedef struct nfs_core_param {
 		} gss;
 	} rpc;
 	/** Polling interval for blocked lock polling thread. */
-	time_t blocked_lock_poller_interval;
+	int64_t blocked_lock_poller_interval;
 	/** Protocols to support.  Should probably be renamed.
 	    Defaults to CORE_OPTION_ALL_VERS and is settable with
 	    NFS_Protocols (as a comma-separated list of 3 and 4.) */
@@ -456,7 +465,7 @@ typedef struct nfs_core_param {
 	/** How long the server will trust information it got by
 	    calling getgroups() when "Manage_Gids = TRUE" is
 	    used in a export entry. */
-	time_t manage_gids_expiration;
+	int64_t manage_gids_expiration;
 	/** Path to the directory containing server specific
 	    modules.  In particular, this is where FSALs live. */
 	char *ganesha_modules_loc;
@@ -541,6 +550,16 @@ typedef struct nfs_core_param {
 	    (as a comma-separated list of 3,4.0,4.1,4.2) */
 	unsigned int nfs_rdma_supported_protocol_versions;
 #endif
+	/** In linux, we need to set PR_SET_IO_FLUSHER to avoid a potential
+	 * deadlock when mounting ganesha locally in a system that nears out
+	 * memory. This is not possible due to lacking permissions in some
+	 * environments (specifically unprivileged containers). If you are
+	 * running in an unprivileged environment and you are sure your use
+	 * case doesn't require setting PR_SET_IO_FLUSHER, you can enable this
+	 * option and Ganesha will not fail on startup if it can't set it.
+	 * For more info, see:
+	 * https://git.kernel.org/torvalds/p/8d19f1c8e1937baf74e1962aae9f90fa3aeab463 */
+	bool allow_set_io_flusher_fail;
 } nfs_core_parameter_t;
 
 /** @} */
@@ -587,6 +606,9 @@ typedef struct nfs_core_param {
 	 NFSV4_MINOR_VERSION_TWO)
 
 typedef struct nfs_version4_parameter {
+	/** Whether to disable sticky grace. Defaults to true and
+		can be disabled with sticky_grace*/
+	bool sticky_grace;
 	/** Whether to disable the NFSv4 grace period.  Defaults to
 	    false and settable with Graceless. */
 	bool graceless;
@@ -675,9 +697,11 @@ typedef struct directory_services_param {
 	/** Whether to enable idmapping. Defaults to true. */
 	bool idmapping_active;
 	/** Cache validity in seconds for idmapped user entries */
-	time_t idmapped_user_time_validity;
+	int64_t idmapped_user_time_validity;
 	/** Cache validity in seconds for idmapped group entries */
-	time_t idmapped_group_time_validity;
+	int64_t idmapped_group_time_validity;
+	/** Controls principals that will be assigned root privilege */
+	uint32_t root_kerberos_principal;
 	/** Max number of cached idmapped users */
 	uint32_t cache_users_max_count;
 	/** Max number of cached idmapped groups */
@@ -685,13 +709,13 @@ typedef struct directory_services_param {
 	/** Max number of cached user-groups entries */
 	uint32_t cache_user_groups_max_count;
 	/** Cache validity in seconds for negative entries */
-	time_t negative_cache_time_validity;
+	int64_t negative_cache_time_validity;
 	/** Max number of negative cache users (that failed idmapping) */
 	uint32_t negative_cache_users_max_count;
 	/** Max number of negative cache groups (that failed idmapping) */
 	uint32_t negative_cache_groups_max_count;
 	/** Cache reaping interval in seconds for idmapped users and groups */
-	time_t cache_reaping_interval;
+	int64_t cache_reaping_interval;
 	/** Whether to use fully qualified names for idmapping with pw-utils.
 	    Defaults to false. */
 	bool pwutils_use_fully_qualified_names;
