@@ -59,7 +59,7 @@ extern "C" {
 #include <rpc/svc_auth.h>
 #ifdef _HAVE_GSSAPI
 #include <rpc/auth_gss.h>
-#include <rpc/gss_internal.h>	/* XXX */
+#include <rpc/gss_internal.h> /* XXX */
 #endif
 #include <rpc/svc_rqst.h>
 #include <rpc/rpc_msg.h>
@@ -89,7 +89,7 @@ extern "C" {
 #define NFS_LOOKAHEAD_LAYOUTCOMMIT 0x0040
 #define NFS_LOOKAHEAD_SETATTR 0x0080
 #define NFS_LOOKAHEAD_SETCLIENTID 0x0100
-#define NFS_LOOKAHEAD_SETCLIENTID_CONFIRM  0x0200
+#define NFS_LOOKAHEAD_SETCLIENTID_CONFIRM 0x0200
 #define NFS_LOOKAHEAD_LOOKUP 0x0400
 #define NFS_LOOKAHEAD_READLINK 0x0800
 /* ... */
@@ -100,18 +100,15 @@ struct nfs_request_lookahead {
 	uint16_t write;
 };
 
-#define NFS_LOOKAHEAD_HIGH_LATENCY(lkhd)		\
-	(((lkhd).flags & (NFS_LOOKAHEAD_READ |		\
-			  NFS_LOOKAHEAD_WRITE |		\
-			  NFS_LOOKAHEAD_COMMIT |	\
-			  NFS_LOOKAHEAD_LAYOUTCOMMIT |	\
-			  NFS_LOOKAHEAD_READDIR)))
-
+#define NFS_LOOKAHEAD_HIGH_LATENCY(lkhd)                                     \
+	(((lkhd).flags &                                                     \
+	  (NFS_LOOKAHEAD_READ | NFS_LOOKAHEAD_WRITE | NFS_LOOKAHEAD_COMMIT | \
+	   NFS_LOOKAHEAD_LAYOUTCOMMIT | NFS_LOOKAHEAD_READDIR)))
 
 #define XDR_ARRAY_MAXLEN 1024
-#define XDR_BYTES_MAXLEN (1024*1024)
-#define XDR_BYTES_MAXLEN_IO (64*1024*1024)
-#define XDR_STRING_MAXLEN (8*1024)
+#define XDR_BYTES_MAXLEN (1024 * 1024)
+#define XDR_BYTES_MAXLEN_IO (64 * 1024 * 1024)
+#define XDR_STRING_MAXLEN (8 * 1024)
 
 typedef struct sockaddr_storage sockaddr_t;
 
@@ -185,23 +182,39 @@ const char *str_gc_proc(rpc_gss_proc_t);
 
 void copy_xprt_addr(sockaddr_t *, SVCXPRT *);
 
-int display_sockaddr_port(struct display_buffer *dspbuf, sockaddr_t *addr,
+int display_sockaddr_port(struct display_buffer *dspbuf, const sockaddr_t *addr,
 			  bool ignore_port);
 
-static inline
-int display_sockaddr(struct display_buffer *dspbuf, sockaddr_t *addr)
+static inline int display_sockaddr(struct display_buffer *dspbuf,
+				   const sockaddr_t *addr)
 {
 	return display_sockaddr_port(dspbuf, addr, false);
 }
 
-static inline
-int display_sockip(struct display_buffer *dspbuf, sockaddr_t *addr)
+static inline int display_sockip(struct display_buffer *dspbuf,
+				 const sockaddr_t *addr)
 {
 	return display_sockaddr_port(dspbuf, addr, true);
 }
 
-static inline
-void *socket_addr(sockaddr_t *addr)
+/* Displays xprt's remote address if non-empty. Otherwise displays
+ * local address.
+ */
+static inline int display_xprt_sockaddr(struct display_buffer *db,
+					const SVCXPRT *xprt)
+{
+	const sockaddr_t *addr;
+	const struct netbuf *hostaddr = svc_getcaller_netbuf(xprt);
+
+	if (hostaddr->len == 0)
+		hostaddr = svc_getlocal_netbuf(xprt);
+	assert(hostaddr->len <= sizeof(sockaddr_t) && hostaddr->buf != NULL);
+	addr = (const sockaddr_t *)hostaddr->buf;
+
+	return display_sockaddr(db, addr);
+}
+
+static inline void *socket_addr(sockaddr_t *addr)
 {
 	switch (addr->ss_family) {
 	case AF_INET:
@@ -217,8 +230,7 @@ void *socket_addr(sockaddr_t *addr)
 	}
 }
 
-static inline
-size_t socket_addr_len(sockaddr_t *addr)
+static inline size_t socket_addr_len(sockaddr_t *addr)
 {
 	switch (addr->ss_family) {
 	case AF_INET:
@@ -234,8 +246,7 @@ size_t socket_addr_len(sockaddr_t *addr)
 	}
 }
 
-static inline
-bool sprint_sockip(sockaddr_t *addr, char *buf, int len)
+static inline bool sprint_sockip(sockaddr_t *addr, char *buf, int len)
 {
 #ifdef RPC_VSOCK
 	if (addr->ss_family == AF_VSOCK) {
@@ -267,6 +278,29 @@ extern tirpc_pkg_params ntirpc_pp;
 sockaddr_t *convert_ipv6_to_ipv4(sockaddr_t *ipv6, sockaddr_t *ipv4);
 bool is_loopback(sockaddr_t *addr);
 
+struct io_data {
+	/** Release function if needed. */
+	void (*release)(void *);
+	/** Data hook for release function to use if needed */
+	void *release_data;
+	/** Total length of iovec data */
+	u_int data_len;
+	/** Count of iovec structures in the io vector */
+	u_int iovcnt;
+	/** Size of last iov buffer */
+	size_t last_iov_buf_size;
+	/** The actual io vector */
+	struct iovec *iov;
+};
+typedef struct io_data io_data;
+
+bool xdr_io_data(XDR *xdrs, io_data *objp);
+
+/**
+ * API to get the buffer to fill the IO Payloads
+ */
+void *get_buffer_for_io_response(uint64_t size, size_t *buffer_size);
+
 #ifdef __cplusplus
 }
 #endif
