@@ -47,6 +47,9 @@
 
 /* Arbitrary string buffer lengths */
 #define PWENT_BEST_GUESS_LEN 1024
+/* Maintain 64MB as the max buffer length for passwd and group entries */
+#define PWENT_MAX_SIZE (64 * 1024 * 1024)
+#define GROUP_MAX_SIZE PWENT_MAX_SIZE
 
 /**
  * @brief Shared between idmapper.c and idmapper_cache.c.  If you
@@ -57,10 +60,12 @@
 
 extern pthread_rwlock_t idmapper_user_lock;
 extern pthread_rwlock_t idmapper_group_lock;
+extern pthread_rwlock_t idmapper_negative_cache_user_lock;
+extern pthread_rwlock_t idmapper_negative_cache_group_lock;
 
 void idmapper_cache_init(void);
-bool idmapper_add_user(const struct gsh_buffdesc *, uid_t, const gid_t *,
-		       bool);
+void idmapper_cache_reap(void);
+bool idmapper_add_user(const struct gsh_buffdesc *, uid_t, const gid_t *, bool);
 bool idmapper_add_group(const struct gsh_buffdesc *, gid_t);
 bool idmapper_lookup_by_uname(const struct gsh_buffdesc *, uid_t *,
 			      const gid_t **, bool);
@@ -68,10 +73,23 @@ bool idmapper_lookup_by_uid(const uid_t, const struct gsh_buffdesc **,
 			    const gid_t **);
 bool idmapper_lookup_by_gname(const struct gsh_buffdesc *, uid_t *);
 bool idmapper_lookup_by_gid(const gid_t, const struct gsh_buffdesc **);
+
+void idmapper_negative_cache_init(void);
+void idmapper_negative_cache_add_user_by_name(const struct gsh_buffdesc *);
+void idmapper_negative_cache_add_group_by_name(const struct gsh_buffdesc *);
+bool idmapper_negative_cache_lookup_user_by_name(const struct gsh_buffdesc *);
+bool idmapper_negative_cache_lookup_group_by_name(const struct gsh_buffdesc *);
+void idmapper_negative_cache_clear(void);
+void idmapper_negative_cache_destroy(void);
+void idmapper_negative_cache_reap(void);
+
 /** @} */
 
 bool idmapper_init(void);
 void idmapper_clear_cache(void);
+void idmapper_destroy_cache(void);
+
+bool set_idmapping_status(bool status_enabled);
 
 bool xdr_encode_nfs4_owner(XDR *, uid_t);
 bool xdr_encode_nfs4_group(XDR *, gid_t);
@@ -96,5 +114,5 @@ extern struct gsh_dbus_method cachemgr_show_idmapper;
 extern struct gsh_dbus_method auth_statistics;
 #endif
 
-#endif				/* IDMAPPER_H */
+#endif /* IDMAPPER_H */
 /** @} */
