@@ -50,14 +50,14 @@
 #endif
 
 /* Delegation client cache limits */
-#define DELEG_SPACE_LIMIT_FILESZ 102400  /* just 100K, revisit? */
+#define DELEG_SPACE_LIMIT_FILESZ 102400 /* just 100K, revisit? */
 #define DELEG_SPACE_LIMIT_BLOCKS 200
 
 #define XATTR_BUFFERSIZE 4096
 
 extern char *nfs_host_name;
 
-extern char cid_server_owner[MAXNAMLEN+1]; /* max hostname length */
+extern char cid_server_owner[MAXNAMLEN + 1]; /* max hostname length */
 extern char *cid_server_scope;
 
 /*
@@ -77,7 +77,7 @@ typedef struct __nfs4_compound {
 
 typedef struct _rpc_call rpc_call_t;
 
-typedef void (*rpc_call_func) (rpc_call_t *call);
+typedef void (*rpc_call_func)(rpc_call_t *call);
 
 #ifdef _HAVE_GSSAPI
 extern gss_OID_desc krb5oid;
@@ -101,6 +101,15 @@ struct _nfs_health {
 	uint64_t dequeued_reqs;
 };
 
+enum evchan {
+	UDP_UREG_CHAN, /*< Put UDP on a dedicated channel */
+	TCP_UREG_CHAN, /*< Accepts new TCP connections */
+#ifdef _USE_NFS_RDMA
+	RDMA_UREG_CHAN, /*< Accepts new RDMA connections */
+#endif
+	EVCHAN_SIZE
+};
+
 extern struct _nfs_health nfs_health_;
 bool nfs_health(void);
 
@@ -108,8 +117,8 @@ bool nfs_health(void);
 extern struct timespec nfs_ServerBootTime;
 extern time_t nfs_ServerEpoch;
 
-extern verifier4 NFS4_write_verifier;	/*< NFS V4 write verifier */
-extern writeverf3 NFS3_write_verifier;	/*< NFS V3 write verifier */
+extern verifier4 NFS4_write_verifier; /*< NFS V4 write verifier */
+extern writeverf3 NFS3_write_verifier; /*< NFS V3 write verifier */
 
 extern char *nfs_config_path;
 extern char *nfs_pidfile_path;
@@ -140,6 +149,7 @@ void _9p_rdma_cleanup_conn(msk_trans_t *trans);
 void Clean_RPC(void);
 void nfs_Init_svc(void);
 void nfs_rpc_dispatch_stop(void);
+uint32_t nfs_get_evchannel_id(enum evchan);
 
 /* Config parsing routines */
 extern config_file_t nfs_config_struct;
@@ -149,6 +159,7 @@ extern struct config_block nfs_ip_name;
 extern struct config_block krb5_param;
 #endif
 extern struct config_block version4_param;
+extern struct config_block directory_services_param;
 
 /* in nfs_admin_thread.c */
 
@@ -171,9 +182,10 @@ unsigned int nfs_core_select_worker_queue(unsigned int avoid_index);
 int nfs_Init_ip_name(void);
 
 void nfs_rpc_destroy_chan(rpc_call_channel_t *chan);
+void nfs_rpc_destroy_chan_no_lock(rpc_call_channel_t *chan);
 
 int reaper_init(void);
 void reaper_wake(void);
 int reaper_shutdown(void);
 
-#endif				/* !NFS_CORE_H */
+#endif /* !NFS_CORE_H */
