@@ -53,6 +53,7 @@ extern struct nfs_init nfs_init;
 
 extern pthread_t gsh_dbus_thrid;
 
+void nfs_prereq_init_mutexes(void);
 void nfs_init_init(void);
 void nfs_init_cleanup(void);
 void nfs_init_complete(void);
@@ -109,13 +110,15 @@ static inline void nfs_check_malloc(void)
 
 	p = malloc(0);
 	if (p == NULL)
-		LogFatal(COMPONENT_MAIN,
-			 "Ganesha's assumption that malloc(0) returns a non-NULL pointer is not true, Ganesha can not work with the memory allocator in use. Aborting.");
+		LogFatal(
+			COMPONENT_MAIN,
+			"Ganesha's assumption that malloc(0) returns a non-NULL pointer is not true, Ganesha can not work with the memory allocator in use. Aborting.");
 	free(p);
 	p = calloc(0, 0);
 	if (p == NULL)
-		LogFatal(COMPONENT_MAIN,
-			 "Ganesha's assumption that calloc(0, 0) returns a non-NULL pointer is not true, Ganesha can not work with the memory allocator in use. Aborting.");
+		LogFatal(
+			COMPONENT_MAIN,
+			"Ganesha's assumption that calloc(0, 0) returns a non-NULL pointer is not true, Ganesha can not work with the memory allocator in use. Aborting.");
 	free(p);
 }
 
@@ -134,5 +137,8 @@ enum xprt_stat nfs_rpc_valid_RQUOTA(struct svc_req *);
 #ifdef USE_NFSACL3
 enum xprt_stat nfs_rpc_valid_NFSACL(struct svc_req *);
 #endif
+#ifdef _USE_NFS_RDMA
+enum xprt_stat nfs_rpc_valid_NFS_RDMA(struct svc_req *);
+#endif
 
-#endif				/* !NFS_INIT_H */
+#endif /* !NFS_INIT_H */
