@@ -36,12 +36,10 @@
 
 extern char *nfs_config_path;
 
-extern int nfs_libmain(
-	const char *config_path,
-	const char *log_path,
-	const int debug_level);
+extern int nfs_libmain(const char *config_path, const char *log_path,
+		       const int debug_level);
 
 extern bool reread_config(void);
 
-#endif				/* !NFS_LIB_H */
+#endif /* !NFS_LIB_H */
 /** @} */
