@@ -1,3 +1,4 @@
+/* SPDX-License-Identifier: LGPL-3.0-or-later */
 /*
  * Copyright IBM Corporation, 2010
  *  Contributor: Aneesh Kumar K.v  <aneesh.kumar@linux.vnet.ibm.com>
@@ -46,24 +47,24 @@ extern void netobj_to_string(netobj *obj, char *buffer, int maxlen);
  * alock:        nlm4_lock request structure
  * plock:        cache_lock_desc_t to fill in from alock
  * ppobj:        FSAL obj pointer to fill in
- * pexport:      the export of interest
- * pclient:      cache inode client
  * care:         TRUE if this caller cares if an owner is found (otherwise
  *               return NLM4_GRANTED
  *               because the caller will have nothing to do)
+ * ppnsm_client  NSM Client to fill in, returns a reference to the client
  * ppnlm_client: NLM Client to fill in, returns a reference to the client
  * ppowner:      NLM Owner to fill in, returns a reference to the owner
- * ppblock_data: Data required to make a call back to the client to grant a
+ * block_data:   Data required to make a call back to the client to grant a
  *               blocked lock
+ * nsm_state:    nsm_state value
+ * state:        state_t to fill in
  */
 int nlm_process_parameters(struct svc_req *req, bool exclusive,
 			   nlm4_lock *alock, fsal_lock_param_t *plock,
-			   struct fsal_obj_handle **ppobj,
-			   care_t care, state_nsm_client_t **ppnsm_client,
+			   struct fsal_obj_handle **ppobj, care_t care,
+			   state_nsm_client_t **ppnsm_client,
 			   state_nlm_client_t **ppnlm_client,
 			   state_owner_t **ppowner,
-			   state_block_data_t **block_data,
-			   int32_t nsm_state,
+			   state_block_data_t **block_data, int32_t nsm_state,
 			   state_t **state);
 
 int nlm_process_share_parms(struct svc_req *req, nlm4_share *share,
@@ -71,8 +72,7 @@ int nlm_process_share_parms(struct svc_req *req, nlm4_share *share,
 			    struct fsal_obj_handle **ppobj, care_t care,
 			    state_nsm_client_t **ppnsm_client,
 			    state_nlm_client_t **ppnlm_client,
-			    state_owner_t **ppowner,
-			    state_t **state);
+			    state_owner_t **ppowner, state_t **state);
 
 void nlm_process_conflict(nlm4_holder *nlm_holder, state_owner_t *holder,
 			  fsal_lock_param_t *conflict);
@@ -82,4 +82,4 @@ nlm4_stats nlm_convert_state_error(state_status_t status);
 state_status_t nlm_granted_callback(struct fsal_obj_handle *obj,
 				    state_lock_entry_t *lock_entry);
 
-#endif				/* NLM_UTIL_H */
+#endif /* NLM_UTIL_H */
