@@ -48,15 +48,15 @@ void server_stats_nfs_done(nfs_request_t *reqdata, int rc, bool dup);
 void server_stats_9p_done(u8 msgtype, struct _9p_request_data *req9p);
 #endif
 
-void server_stats_io_done(size_t requested,
-			  size_t transferred, bool success, bool is_write);
+void server_stats_io_done(size_t requested, size_t transferred, bool success,
+			  bool is_write);
 void server_stats_compound_done(int num_ops, int status);
-void server_stats_nfsv4_op_done(int proto_op,
-				struct timespec *start_time, int status);
-void server_stats_transport_done(struct gsh_client *client,
-				uint64_t rx_bytes, uint64_t rx_pkt,
-				uint64_t rx_err, uint64_t tx_bytes,
-				uint64_t tx_pkt, uint64_t tx_err);
+void server_stats_nfsv4_op_done(int proto_op, struct timespec *start_time,
+				int status);
+void server_stats_transport_done(struct gsh_client *client, uint64_t rx_bytes,
+				 uint64_t rx_pkt, uint64_t rx_err,
+				 uint64_t tx_bytes, uint64_t tx_pkt,
+				 uint64_t tx_err);
 
 /* For delegations */
 void inc_grants(struct gsh_client *client);
@@ -65,5 +65,5 @@ void inc_revokes(struct gsh_client *client);
 void inc_recalls(struct gsh_client *client);
 void inc_failed_recalls(struct gsh_client *client);
 
-#endif				/* !SERVER_STATS_H */
+#endif /* !SERVER_STATS_H */
 /** @} */
