@@ -31,7 +31,8 @@ def dbus_to_std(v):
 
     if (isinstance(v, dbus.UInt16)
         or isinstance(v, dbus.UInt32)
-        or isinstance(v, dbus.UInt64)):
+        or isinstance(v, dbus.UInt64)
+        or isinstance(v, int)):
         ctor = int
     elif isinstance(v, dbus.Boolean):
         ctor = bool
@@ -123,9 +124,9 @@ class RetrieveExportStats():
         stats_op = self.exportmgrobj.get_dbus_method("GetGlobalOPS",
                                                      self.dbus_exportstats_name)
         return GlobalStats(stats_op())
-    # cache inode stats
+    # mdcache stats
     def inode_stats(self):
-        stats_op = self.exportmgrobj.get_dbus_method("ShowCacheInode",
+        stats_op = self.exportmgrobj.get_dbus_method("ShowMDCache",
                                                      self.dbus_exportstats_name)
         return InodeStats(stats_op())
     # list of all exports
@@ -852,7 +853,8 @@ class InodeStats(Report):
         self.stats = stats
 
     def fill_report(self, report):
-        report_key_value(self.result[3], report)
+        values = self.result[3] + self.result[4]
+        report_key_value(values, report)
 
     def __str__(self):
         output = ""
@@ -1087,22 +1089,23 @@ def export_io_stats_report(header, stats):
 
     for exportid, export_stats in stats.items():
         report, success = header(export_stats)
-        reports.append(report)
         report['id'] = exportid
 
         if not success:
+            reports.append(report)
             continue
 
-        ops_stats = export_stats[3]
+        op_stat_start = 3
         for i, op in enumerate(ops):
+            ops_stats = export_stats[op_stat_start + i]
             result = {}
 
 
-            for i, counter in enumerate(counters):
-                result[counter] = dbus_to_std(ops_stats[i])
+            for j, counter in enumerate(counters):
+                result[counter] = dbus_to_std(ops_stats[j])
 
             report[op] = result
-
+        reports.append(report)
     return reports
 
 class TotalStats(Report):
@@ -1118,6 +1121,7 @@ class TotalStats(Report):
         for exportid in self.result:
             export = self.result[exportid]
             report, success = super()._header(export)
+            report['id'] = exportid
             reports.append(report)
 
             if not success:
