@@ -214,6 +214,22 @@ class ServerAdmin():
         else:
             self.status_message(status, msg)
 
+    def trim_enable(self):
+        status, msg = self.admin.trim_enable()
+        self.status_message(status, msg)
+
+    def trim_disable(self):
+        status, msg = self.admin.trim_disable()
+        self.status_message(status, msg)
+
+    def trim_call(self):
+        status, msg = self.admin.trim_call()
+        self.status_message(status, msg)
+
+    def trim_status(self):
+        status, msg = self.admin.trim_status()
+        self.status_message(status, msg)
+
     def status_message(self, status, errormsg):
         print("Returns: status = %s, %s" % (str(status), errormsg))
 
@@ -355,6 +371,11 @@ if __name__ == '__main__':
        "      idmap: Displays the idmapper cache\n\n"                              \
        "   grace: \n"                                                              \
        "      ipaddr: Begins grace for the given IP\n\n"                           \
+       "   trim:\n"                                                                \
+       "      enable: Enable malloc trim\n"                                        \
+       "      disable: Disable malloc trim\n"                                      \
+       "      call: Call malloc trim\n"                                            \
+       "      status: Get current malloc trim status\n\n"                          \
        "   get: \n"                                                                \
        "      log component: Gets the log level for the given component\n\n"       \
        "   set: \n"                                                                \
@@ -484,6 +505,25 @@ if __name__ == '__main__':
             sys.exit(1)
         ganesha.grace(sys.argv[2])
 
+    #malloc trim
+    elif sys.argv[1] == "trim":
+        if len(sys.argv) < 3:
+            print("trim requires enable/disable/call/status arg. "
+                  "Try \"ganesha_mgr.py help\" for more info")
+            sys.exit(1)
+
+        if sys.argv[2] == 'enable':
+            ganesha.trim_enable()
+        elif sys.argv[2] == 'disable':
+            ganesha.trim_disable()
+        elif sys.argv[2] == 'status':
+            ganesha.trim_status()
+        elif sys.argv[2] == 'call':
+            ganesha.trim_call()
+        else:
+            msg = "trim '%s' is unknown" % sys.argv[2]
+            sys.exit(msg)
+
     # set
     elif sys.argv[1] == "set":
         if len(sys.argv) < 5:
