@@ -345,22 +345,26 @@ restart:
 	PTHREAD_MUTEX_lock(&fe->ctx.fre_mtx);
 	fe->frozen = true;
 	fe->flags |= fridgethr_flag_available;
-	PTHREAD_MUTEX_unlock(&fr->frt_mtx);
 
 	/* It is a state machine, keep going until we have a
 	   transition that gets us out. */
 	while (true) {
+		bool fre_mtx_locked = true;
 		if ((fr->p.wake_threads == NULL) ||
 		    (fr->command != fridgethr_comm_run)) {
 			if (fr->p.thread_delay > 0) {
 				clock_gettime(CLOCK_REALTIME, &fe->timeout);
 				fe->timeout.tv_sec += fr->p.thread_delay;
+				PTHREAD_MUTEX_unlock(&fr->frt_mtx);
 				rc = pthread_cond_timedwait(&fe->ctx.fre_cv,
 							    &fe->ctx.fre_mtx,
 							    &fe->timeout);
-			} else
+			} else {
+				PTHREAD_MUTEX_unlock(&fr->frt_mtx);
 				rc = pthread_cond_wait(&fe->ctx.fre_cv,
 						       &fe->ctx.fre_mtx);
+			}
+			fre_mtx_locked = false;
 		}
 
 		if (rc == ETIMEDOUT)
@@ -378,6 +382,8 @@ restart:
 			fe->flags &= ~(fridgethr_flag_available |
 				       fridgethr_flag_dispatched);
 			PTHREAD_MUTEX_unlock(&fe->ctx.fre_mtx);
+			if (fre_mtx_locked)
+				PTHREAD_MUTEX_unlock(&fr->frt_mtx);
 			break;
 		}
 
@@ -385,7 +391,9 @@ restart:
 		   we're acquiring the fridge lock. */
 		fe->flags &= ~fridgethr_flag_available;
 		PTHREAD_MUTEX_unlock(&fe->ctx.fre_mtx);
-		PTHREAD_MUTEX_lock(&fr->frt_mtx);
+
+		if (!fre_mtx_locked)
+			PTHREAD_MUTEX_lock(&fr->frt_mtx);
 
 		/* Nothing to do, loop around. */
 		if (fr->command != fridgethr_comm_stop &&
@@ -395,7 +403,6 @@ restart:
 			PTHREAD_MUTEX_lock(&fe->ctx.fre_mtx);
 			fe->frozen = true;
 			fe->flags |= fridgethr_flag_available;
-			PTHREAD_MUTEX_unlock(&fr->frt_mtx);
 			continue;
 		}
 
@@ -451,7 +458,7 @@ static void *fridgethr_start_routine(void *arg)
 	struct fridgethr_entry *fe = arg;
 	struct fridgethr *fr = fe->fr;
 	bool reschedule;
-	int rc = 0;
+	int __attribute__((unused)) rc = 0;
 	int old_type = 0;
 	int old_state = 0;
 
@@ -1321,6 +1328,7 @@ void fridgethr_cancel(struct fridgethr *fr)
 		   Which means the thread isn't running.  Which is
 		   good enough for me. */
 		pthread_cancel(t->ctx.id);
+		pthread_join(t->ctx.id, NULL);
 		glist_del(&t->thread_link);
 		gsh_free(t);
 		--(fr->nthreads);
