@@ -39,11 +39,13 @@ char options[] = "c:qdx:s:n:p:h?C:";
 char usage[] =
 	"Usage: ml_cephfs_client -C ceph-config -s server -p port -n name [-q] [-d] [-c path]\n"
 	"       ml_cephfs_client -C ceph-config -x script [-q] [-d] [-c path]\n"
-	"       ml_cephfs_client -C ceph-config [-q] [-d] [-c path]\n" "\n"
+	"       ml_cephfs_client -C ceph-config [-q] [-d] [-c path]\n"
+	"\n"
 	"  ml_cephfs_client may be run in three modes\n"
 	"  - In the first mode, the client will be driven by a console.\n"
 	"  - In the second mode, the client is driven by a script.\n"
-	"  - In the third mode, the client interractive.\n" "\n"
+	"  - In the third mode, the client interractive.\n"
+	"\n"
 	"  -s server      - specify the console's hostname or IP address\n"
 	"  -p port        - specify the console's port number\n"
 	"  -n name        - specify the client's name\n"
@@ -140,16 +142,14 @@ void openserver(void)
 	input = fdopen(sock, "r");
 
 	if (input == NULL)
-		fatal(
-		     "Could not create input stream from socket ERROr %d \"%s\"\n",
-		     errno, strerror(errno));
+		fatal("Could not create input stream from socket ERROr %d \"%s\"\n",
+		      errno, strerror(errno));
 
 	output = fdopen(sock, "w");
 
 	if (output == NULL)
-		fatal(
-		     "Could not create output stream from socket ERROr %d \"%s\"\n",
-		     errno, strerror(errno));
+		fatal("Could not create output stream from socket ERROr %d \"%s\"\n",
+		      errno, strerror(errno));
 
 	if (!quiet)
 		fprintf(stdout, "connected to server %s:%d\n", server, port);
@@ -179,7 +179,7 @@ bool do_fork(struct response *resp, bool use_server)
 
 		if (!quiet)
 			fprintf(stdout, "fork failed %d (%s)\n",
-				(int) resp->r_errno, strerror(resp->r_errno));
+				(int)resp->r_errno, strerror(resp->r_errno));
 
 		return true;
 	} else if (forked == 0) {
@@ -328,7 +328,7 @@ void do_open(struct response *resp)
 
 	inodes[resp->r_fpos] = inode;
 	filehandles[resp->r_fpos] = filehandle;
-	lock_mode[resp->r_fpos] = (enum lock_mode) resp->r_lock_type;
+	lock_mode[resp->r_fpos] = (enum lock_mode)resp->r_lock_type;
 	resp->r_fno = resp->r_fpos;
 	resp->r_status = STATUS_OK;
 }
@@ -382,8 +382,8 @@ void do_read(struct response *resp)
 	if (resp->r_length > MAXSTR)
 		resp->r_length = MAXSTR;
 
-	rc = ceph_ll_read(cmount, filehandles[resp->r_fpos], -1,
-			  resp->r_length, resp->r_data);
+	rc = ceph_ll_read(cmount, filehandles[resp->r_fpos], -1, resp->r_length,
+			  resp->r_data);
 
 	if (rc < 0) {
 		resp->r_status = STATUS_ERRNO;
@@ -410,8 +410,8 @@ void do_seek(struct response *resp)
 		return;
 	}
 
-	rc = ceph_ll_lseek(cmount, filehandles[resp->r_fpos],
-			   resp->r_start, SEEK_SET);
+	rc = ceph_ll_lseek(cmount, filehandles[resp->r_fpos], resp->r_start,
+			   SEEK_SET);
 
 	if (rc < 0) {
 		resp->r_status = STATUS_ERRNO;
@@ -478,7 +478,8 @@ void cancel_work(struct response *req)
 	while (start_over) {
 		start_over = false;
 
-		glist_for_each(glist, fno_work + req->r_fpos) {
+		glist_for_each(glist, fno_work + req->r_fpos)
+		{
 			work = glist_entry(glist, struct work_item, fno_work);
 			if (work->resp.r_start >= req->r_start &&
 			    lock_end(&work->resp) <= lock_end(req)) {
@@ -572,8 +573,8 @@ bool do_lock(struct response *resp, enum thread_type thread_type)
 	lock.l_len = resp->r_length;
 	lock.l_pid = 0;
 
-	rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos],
-			   &lock, owner, sleep);
+	rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos], &lock, owner,
+			   sleep);
 
 	if (rc == -EAGAIN && retry && thread_type == THREAD_MAIN) {
 		/* We need to schedule OFD blocked lock */
@@ -647,8 +648,8 @@ void do_hop(struct response *resp)
 		lock.l_len = 1;
 		lock.l_pid = 0;
 
-		rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos],
-				   &lock, owner, false);
+		rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos], &lock,
+				   owner, false);
 
 		if (rc < 0) {
 			if (rc == -EAGAIN) {
@@ -676,8 +677,8 @@ void do_hop(struct response *resp)
 		lock.l_len = resp->r_length;
 		lock.l_pid = 0;
 
-		rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos],
-				   &lock, owner, false);
+		rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos], &lock,
+				   owner, false);
 
 		if (rc < 0) {
 			resp->r_status = STATUS_ERRNO;
@@ -727,8 +728,8 @@ void do_unhop(struct response *resp)
 		lock.l_len = 1;
 		lock.l_pid = 0;
 
-		rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos],
-				   &lock, owner, false);
+		rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos], &lock,
+				   owner, false);
 
 		if (rc < 0) {
 			resp->r_status = STATUS_ERRNO;
@@ -749,8 +750,8 @@ void do_unhop(struct response *resp)
 		lock.l_len = resp->r_length;
 		lock.l_pid = 0;
 
-		rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos],
-				   &lock, owner, false);
+		rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos], &lock,
+				   owner, false);
 
 		if (rc < 0) {
 			resp->r_status = STATUS_ERRNO;
@@ -795,15 +796,15 @@ void do_unlock(struct response *resp)
 	lock.l_len = resp->r_length;
 	lock.l_pid = 0;
 
-	rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos],
-			   &lock, owner, false);
+	rc = ceph_ll_setlk(cmount, filehandles[resp->r_fpos], &lock, owner,
+			   false);
 
 	if (rc < 0) {
 		resp->r_status = STATUS_ERRNO;
 		resp->r_errno = -rc;
 		array_strcpy(errdetail, "Unlock failed");
-		array_sprintf(badtoken, "%lld %lld",
-			      resp->r_start, resp->r_length);
+		array_sprintf(badtoken, "%lld %lld", resp->r_start,
+			      resp->r_length);
 		return;
 	}
 
@@ -849,8 +850,8 @@ void do_test(struct response *resp)
 		resp->r_errno = -rc;
 		array_strcpy(errdetail, "Test failed");
 		array_sprintf(badtoken, "%s %lld %lld",
-			      str_lock_type(lock.l_type),
-			      resp->r_start, resp->r_length);
+			      str_lock_type(lock.l_type), resp->r_start,
+			      resp->r_length);
 		return;
 	}
 
@@ -964,8 +965,8 @@ int list_locks(long long start, long long end, struct response *resp)
 		resp->r_errno = -rc;
 		array_strcpy(errdetail, "Test failed");
 		array_sprintf(badtoken, "%s %lld %lld",
-			      str_lock_type(lock.l_type),
-			      resp->r_start, resp->r_length);
+			      str_lock_type(lock.l_type), resp->r_start,
+			      resp->r_length);
 		respond(resp);
 		return false;
 	}
@@ -1013,7 +1014,7 @@ void do_list(struct response *resp)
 
 	while (tl_head != NULL) {
 		conflict |=
-		    list_locks(tl_head->tl_start, tl_head->tl_end, resp);
+			list_locks(tl_head->tl_start, tl_head->tl_end, resp);
 		remove_test_list_head();
 	}
 
@@ -1040,12 +1041,10 @@ struct work_item *get_work(enum thread_type thread_type)
 		 * thread and the work on the poll list isn't due for polling
 		 * yet, then look for work on the work list.
 		 */
-		if (work == NULL ||
-		    (thread_type == THREAD_POLL &&
-		     work->next_poll > time(NULL))) {
+		if (work == NULL || (thread_type == THREAD_POLL &&
+				     work->next_poll > time(NULL))) {
 			/* Check work list now */
-			work = glist_first_entry(&work_queue,
-						 struct work_item,
+			work = glist_first_entry(&work_queue, struct work_item,
 						 queue);
 		}
 
@@ -1064,12 +1063,10 @@ struct work_item *get_work(enum thread_type thread_type)
 			/* Since there is polling work to do, determine next
 			 * time to poll and wait that long for signal.
 			 */
-			struct timespec twait = {poll->next_poll - time(NULL),
-						 0};
+			struct timespec twait = { poll->next_poll - time(NULL),
+						  0 };
 
-			pthread_cond_timedwait(&work_cond,
-					       &work_mutex,
-					       &twait);
+			pthread_cond_timedwait(&work_cond, &work_mutex, &twait);
 		} else {
 			/* Wait for signal */
 			pthread_cond_wait(&work_cond, &work_mutex);
@@ -1081,7 +1078,7 @@ void *worker(void *t_type)
 {
 	struct work_item *work = NULL;
 	bool complete, cancelled = false;
-	enum thread_type thread_type = *((enum thread_type *) t_type);
+	enum thread_type thread_type = *((enum thread_type *)t_type);
 
 	pthread_mutex_lock(&work_mutex);
 
@@ -1171,13 +1168,10 @@ int main(int argc, char **argv)
 
 	/* Start the worker and polling threads */
 	for (i = 0; i <= NUM_WORKER; i++) {
-		rc = pthread_create(&threads[i],
-				    NULL,
-				    worker,
+		rc = pthread_create(&threads[i], NULL, worker,
 				    i == 0 ? &a_poller : &a_worker);
 		if (rc == -1) {
-			fprintf(stderr,
-				"pthread_create failed %s\n",
+			fprintf(stderr, "pthread_create failed %s\n",
 				strerror(errno));
 			exit(1);
 		}
@@ -1333,8 +1327,8 @@ int main(int argc, char **argv)
 
 				if (*rest != '\0' && *rest != '#')
 					fprintf_stderr(
-					     "Command line not consumed, rest=\"%s\"\n",
-					     rest);
+						"Command line not consumed, rest=\"%s\"\n",
+						rest);
 
 				switch (resp.r_cmd) {
 				case CMD_OPEN:
