@@ -98,8 +98,7 @@ enum thread_type a_poller = THREAD_POLL;
 /* The CephFS mount */
 struct ceph_mount_info *cmount;
 
-
-glfs_t  *fs;
+glfs_t *fs;
 struct glusterfs_fs *gl_fs;
 
 void openserver(void)
@@ -140,16 +139,14 @@ void openserver(void)
 	input = fdopen(sock, "r");
 
 	if (input == NULL)
-		fatal(
-		     "Could not create input stream from socket ERROr %d \"%s\"\n",
-		     errno, strerror(errno));
+		fatal("Could not create input stream from socket ERROr %d \"%s\"\n",
+		      errno, strerror(errno));
 
 	output = fdopen(sock, "w");
 
 	if (output == NULL)
-		fatal(
-		     "Could not create output stream from socket ERROr %d \"%s\"\n",
-		     errno, strerror(errno));
+		fatal("Could not create output stream from socket ERROr %d \"%s\"\n",
+		      errno, strerror(errno));
 
 	if (!quiet)
 		fprintf(stdout, "connected to server %s:%d\n", server, port);
@@ -179,7 +176,7 @@ bool do_fork(struct response *resp, bool use_server)
 
 		if (!quiet)
 			fprintf(stdout, "fork failed %d (%s)\n",
-				(int) resp->r_errno, strerror(resp->r_errno));
+				(int)resp->r_errno, strerror(resp->r_errno));
 
 		return true;
 	} else if (forked == 0) {
@@ -330,7 +327,7 @@ void do_open(struct response *resp)
 
 	fds[resp->r_fpos] = glfd;
 	handles[resp->r_fpos] = glhandle;
-	lock_mode[resp->r_fpos] = (enum lock_mode) resp->r_lock_type;
+	lock_mode[resp->r_fpos] = (enum lock_mode)resp->r_lock_type;
 	resp->r_fno = resp->r_fpos;
 	resp->r_status = STATUS_OK;
 }
@@ -383,8 +380,8 @@ void do_read(struct response *resp)
 	if (resp->r_length > MAXSTR)
 		resp->r_length = MAXSTR;
 #ifdef USE_GLUSTER_STAT_FETCH_API
-	rc = glfs_read(fds[resp->r_fpos], resp->r_data, resp->r_length,
-			0, NULL);
+	rc = glfs_read(fds[resp->r_fpos], resp->r_data, resp->r_length, 0,
+		       NULL);
 #else
 	rc = glfs_read(fds[resp->r_fpos], resp->r_data, resp->r_length, 0);
 #endif
@@ -480,7 +477,8 @@ void cancel_work(struct response *req)
 	while (start_over) {
 		start_over = false;
 
-		glist_for_each(glist, fno_work + req->r_fpos) {
+		glist_for_each(glist, fno_work + req->r_fpos)
+		{
 			work = glist_entry(glist, struct work_item, fno_work);
 			if (work->resp.r_start >= req->r_start &&
 			    lock_end(&work->resp) <= lock_end(req)) {
@@ -851,8 +849,8 @@ void do_unlock(struct response *resp)
 		resp->r_status = STATUS_ERRNO;
 		resp->r_errno = -rc;
 		array_strcpy(errdetail, "Unlock failed");
-		array_sprintf(badtoken, "%lld %lld",
-			      resp->r_start, resp->r_length);
+		array_sprintf(badtoken, "%lld %lld", resp->r_start,
+			      resp->r_length);
 		return;
 	}
 
@@ -911,8 +909,8 @@ void do_test(struct response *resp)
 		resp->r_errno = -rc;
 		array_strcpy(errdetail, "Test failed");
 		array_sprintf(badtoken, "%s %lld %lld",
-			      str_lock_type(lock.l_type),
-			      resp->r_start, resp->r_length);
+			      str_lock_type(lock.l_type), resp->r_start,
+			      resp->r_length);
 		return;
 	}
 
@@ -1028,8 +1026,8 @@ int list_locks(long long start, long long end, struct response *resp)
 		resp->r_errno = -rc;
 		array_strcpy(errdetail, "Test failed");
 		array_sprintf(badtoken, "%s %lld %lld",
-			      str_lock_type(lock.l_type),
-			      resp->r_start, resp->r_length);
+			      str_lock_type(lock.l_type), resp->r_start,
+			      resp->r_length);
 		respond(resp);
 		return false;
 	}
@@ -1077,7 +1075,7 @@ void do_list(struct response *resp)
 
 	while (tl_head != NULL) {
 		conflict |=
-		    list_locks(tl_head->tl_start, tl_head->tl_end, resp);
+			list_locks(tl_head->tl_start, tl_head->tl_end, resp);
 		remove_test_list_head();
 	}
 
@@ -1104,12 +1102,10 @@ struct work_item *get_work(enum thread_type thread_type)
 		 * thread and the work on the poll list isn't due for polling
 		 * yet, then look for work on the work list.
 		 */
-		if (work == NULL ||
-		    (thread_type == THREAD_POLL &&
-		     work->next_poll > time(NULL))) {
+		if (work == NULL || (thread_type == THREAD_POLL &&
+				     work->next_poll > time(NULL))) {
 			/* Check work list now */
-			work = glist_first_entry(&work_queue,
-						 struct work_item,
+			work = glist_first_entry(&work_queue, struct work_item,
 						 queue);
 		}
 
@@ -1128,12 +1124,10 @@ struct work_item *get_work(enum thread_type thread_type)
 			/* Since there is polling work to do, determine next
 			 * time to poll and wait that long for signal.
 			 */
-			struct timespec twait = {poll->next_poll - time(NULL),
-						 0};
+			struct timespec twait = { poll->next_poll - time(NULL),
+						  0 };
 
-			pthread_cond_timedwait(&work_cond,
-					       &work_mutex,
-					       &twait);
+			pthread_cond_timedwait(&work_cond, &work_mutex, &twait);
 		} else {
 			/* Wait for signal */
 			pthread_cond_wait(&work_cond, &work_mutex);
@@ -1145,7 +1139,7 @@ void *worker(void *t_type)
 {
 	struct work_item *work = NULL;
 	bool complete, cancelled = false;
-	enum thread_type thread_type = *((enum thread_type *) t_type);
+	enum thread_type thread_type = *((enum thread_type *)t_type);
 
 	pthread_mutex_lock(&work_mutex);
 
@@ -1235,13 +1229,10 @@ int main(int argc, char **argv)
 
 	/* Start the worker and polling threads */
 	for (i = 0; i <= NUM_WORKER; i++) {
-		rc = pthread_create(&threads[i],
-				    NULL,
-				    worker,
+		rc = pthread_create(&threads[i], NULL, worker,
 				    i == 0 ? &a_poller : &a_worker);
 		if (rc == -1) {
-			fprintf(stderr,
-				"pthread_create failed %s\n",
+			fprintf(stderr, "pthread_create failed %s\n",
 				strerror(errno));
 			exit(1);
 		}
@@ -1294,8 +1285,9 @@ int main(int argc, char **argv)
 
 		case 'x':
 			if ((oflags & 31) != 0)
-				show_usage(1,
-					   "Can not combine -x and -s/-p/-n/-g/-v\n");
+				show_usage(
+					1,
+					"Can not combine -x and -s/-p/-n/-g/-v\n");
 
 			oflags |= 32;
 			script = true;
@@ -1354,26 +1346,22 @@ int main(int argc, char **argv)
 
 	fs = glfs_new(volname);
 	if (!fs) {
-		fatal("Unable to create new glfs. Volume: %s",
-		      volname);
+		fatal("Unable to create new glfs. Volume: %s", volname);
 	}
 
 	rc = glfs_set_volfile_server(fs, "tcp", glusterserver, 24007);
 	if (rc != 0) {
-		fatal("Unable to set volume file. Volume: %s",
-		      volname);
+		fatal("Unable to set volume file. Volume: %s", volname);
 	}
 
 	rc = glfs_set_logging(fs, "stdout", 7);
 	if (rc != 0) {
-		fatal("Unable to set logging. Volume: %s",
-		      volname);
+		fatal("Unable to set logging. Volume: %s", volname);
 	}
 
 	rc = glfs_init(fs);
 	if (rc != 0) {
-		fatal("Unable to initialize volume. Volume: %s",
-		      volname);
+		fatal("Unable to initialize volume. Volume: %s", volname);
 	}
 
 	while (1) {
@@ -1415,8 +1403,8 @@ int main(int argc, char **argv)
 
 				if (*rest != '\0' && *rest != '#')
 					fprintf_stderr(
-					     "Command line not consumed, rest=\"%s\"\n",
-					     rest);
+						"Command line not consumed, rest=\"%s\"\n",
+						rest);
 
 				switch (resp.r_cmd) {
 				case CMD_OPEN:
